Class: Google::Apis::ContainerV1beta1::Autopilot

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Autopilot is the configuration for Autopilot settings on the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Autopilot

Returns a new instance of Autopilot.



621
622
623
# File 'lib/google/apis/container_v1beta1/classes.rb', line 621

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_policy_configGoogle::Apis::ContainerV1beta1::ClusterPolicyConfig

ClusterPolicyConfig stores the configuration for cluster wide policies. Corresponds to the JSON property clusterPolicyConfig



597
598
599
# File 'lib/google/apis/container_v1beta1/classes.rb', line 597

def cluster_policy_config
  @cluster_policy_config
end

#conversion_statusGoogle::Apis::ContainerV1beta1::AutopilotConversionStatus

AutopilotConversionStatus represents conversion status. Corresponds to the JSON property conversionStatus



602
603
604
# File 'lib/google/apis/container_v1beta1/classes.rb', line 602

def conversion_status
  @conversion_status
end

#enabledBoolean Also known as: enabled?

Enable Autopilot Corresponds to the JSON property enabled

Returns:

  • (Boolean)


607
608
609
# File 'lib/google/apis/container_v1beta1/classes.rb', line 607

def enabled
  @enabled
end

#privileged_admission_configGoogle::Apis::ContainerV1beta1::PrivilegedAdmissionConfig

PrivilegedAdmissionConfig stores the list of authorized allowlist paths for the cluster. Corresponds to the JSON property privilegedAdmissionConfig



614
615
616
# File 'lib/google/apis/container_v1beta1/classes.rb', line 614

def privileged_admission_config
  @privileged_admission_config
end

#workload_policy_configGoogle::Apis::ContainerV1beta1::WorkloadPolicyConfig

WorkloadPolicyConfig is the configuration related to GCW workload policy Corresponds to the JSON property workloadPolicyConfig



619
620
621
# File 'lib/google/apis/container_v1beta1/classes.rb', line 619

def workload_policy_config
  @workload_policy_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



626
627
628
629
630
631
632
# File 'lib/google/apis/container_v1beta1/classes.rb', line 626

def update!(**args)
  @cluster_policy_config = args[:cluster_policy_config] if args.key?(:cluster_policy_config)
  @conversion_status = args[:conversion_status] if args.key?(:conversion_status)
  @enabled = args[:enabled] if args.key?(:enabled)
  @privileged_admission_config = args[:privileged_admission_config] if args.key?(:privileged_admission_config)
  @workload_policy_config = args[:workload_policy_config] if args.key?(:workload_policy_config)
end