Class: Google::Apis::ContainerV1beta1::AutopilotConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

AutopilotConfig contains configuration of autopilot feature for this node pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutopilotConfig

Returns a new instance of AutopilotConfig.



695
696
697
# File 'lib/google/apis/container_v1beta1/classes.rb', line 695

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Denotes that nodes belonging to this node pool are Autopilot nodes. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


692
693
694
# File 'lib/google/apis/container_v1beta1/classes.rb', line 692

def enabled
  @enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



700
701
702
# File 'lib/google/apis/container_v1beta1/classes.rb', line 700

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
end