Class: Google::Apis::ContainerV1beta1::BestEffortProvisioning
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::BestEffortProvisioning
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
Best effort provisioning.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
When this is enabled, cluster/node pool creations will ignore non-fatal errors like stockout to best provision as many nodes as possible right now and eventually bring up all target number of nodes Corresponds to the JSON property
enabled. -
#min_provision_nodes ⇒ Fixnum
Minimum number of nodes to be provisioned to be considered as succeeded, and the rest of nodes will be provisioned gradually and eventually when stockout issue has been resolved.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BestEffortProvisioning
constructor
A new instance of BestEffortProvisioning.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BestEffortProvisioning
Returns a new instance of BestEffortProvisioning.
861 862 863 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 861 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
When this is enabled, cluster/node pool creations will ignore non-fatal errors
like stockout to best provision as many nodes as possible right now and
eventually bring up all target number of nodes
Corresponds to the JSON property enabled
851 852 853 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 851 def enabled @enabled end |
#min_provision_nodes ⇒ Fixnum
Minimum number of nodes to be provisioned to be considered as succeeded, and
the rest of nodes will be provisioned gradually and eventually when stockout
issue has been resolved.
Corresponds to the JSON property minProvisionNodes
859 860 861 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 859 def min_provision_nodes @min_provision_nodes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
866 867 868 869 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 866 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @min_provision_nodes = args[:min_provision_nodes] if args.key?(:min_provision_nodes) end |