Class: Google::Apis::ContainerV1beta1::BootDiskProfile
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::BootDiskProfile
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
Swap on the node's boot disk.
Instance Attribute Summary collapse
-
#swap_size_gib ⇒ Fixnum
Specifies the size of the swap space in gibibytes (GiB).
-
#swap_size_percent ⇒ Fixnum
Specifies the size of the swap space as a percentage of the boot disk size.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BootDiskProfile
constructor
A new instance of BootDiskProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BootDiskProfile
Returns a new instance of BootDiskProfile.
1121 1122 1123 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1121 def initialize(**args) update!(**args) end |
Instance Attribute Details
#swap_size_gib ⇒ Fixnum
Specifies the size of the swap space in gibibytes (GiB).
Corresponds to the JSON property swapSizeGib
1114 1115 1116 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1114 def swap_size_gib @swap_size_gib end |
#swap_size_percent ⇒ Fixnum
Specifies the size of the swap space as a percentage of the boot disk size.
Corresponds to the JSON property swapSizePercent
1119 1120 1121 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1119 def swap_size_percent @swap_size_percent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1126 1127 1128 1129 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1126 def update!(**args) @swap_size_gib = args[:swap_size_gib] if args.key?(:swap_size_gib) @swap_size_percent = args[:swap_size_percent] if args.key?(:swap_size_percent) end |