Class: Google::Apis::ContainerV1beta1::CancelOperationRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

CancelOperationRequest cancels a single operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CancelOperationRequest

Returns a new instance of CancelOperationRequest.



1162
1163
1164
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1162

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name (project, location, operation id) of the operation to cancel. Specified in the format projects/*/locations/*/operations/*. Corresponds to the JSON property name

Returns:

  • (String)


1140
1141
1142
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1140

def name
  @name
end

#operation_idString

Deprecated. The server-assigned name of the operation. This field has been deprecated and replaced by the name field. Corresponds to the JSON property operationId

Returns:

  • (String)


1146
1147
1148
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1146

def operation_id
  @operation_id
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


1153
1154
1155
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1153

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the operation resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


1160
1161
1162
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1160

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1167
1168
1169
1170
1171
1172
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1167

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @operation_id = args[:operation_id] if args.key?(:operation_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end