Class: Google::Apis::ContainerV1beta1::CertificateConfigPair
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::CertificateConfigPair
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
CertificateConfigPair configures pairs of certificates, which is used for client certificate and key pairs under a registry.
Instance Attribute Summary collapse
-
#cert ⇒ Google::Apis::ContainerV1beta1::CertificateConfig
CertificateConfig configures certificate for the registry.
-
#key ⇒ Google::Apis::ContainerV1beta1::CertificateConfig
CertificateConfig configures certificate for the registry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CertificateConfigPair
constructor
A new instance of CertificateConfigPair.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CertificateConfigPair
Returns a new instance of CertificateConfigPair.
1242 1243 1244 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1242 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cert ⇒ Google::Apis::ContainerV1beta1::CertificateConfig
CertificateConfig configures certificate for the registry.
Corresponds to the JSON property cert
1235 1236 1237 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1235 def cert @cert end |
#key ⇒ Google::Apis::ContainerV1beta1::CertificateConfig
CertificateConfig configures certificate for the registry.
Corresponds to the JSON property key
1240 1241 1242 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1240 def key @key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1247 1248 1249 1250 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1247 def update!(**args) @cert = args[:cert] if args.key?(:cert) @key = args[:key] if args.key?(:key) end |