Class: Google::Apis::ContainerV1beta1::ClusterAutoscaling

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

ClusterAutoscaling contains global, per-cluster information required by Cluster Autoscaler to automatically adjust the size of the cluster and create/ delete node pools based on the current needs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterAutoscaling

Returns a new instance of ClusterAutoscaling.



2122
2123
2124
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2122

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autopilot_general_profileString

Autopilot general profile for the cluster, which defines the configuration for the cluster. Corresponds to the JSON property autopilotGeneralProfile

Returns:

  • (String)


2086
2087
2088
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2086

def autopilot_general_profile
  @autopilot_general_profile
end

#autoprovisioning_locationsArray<String>

The list of Google Compute Engine zones in which the NodePool's nodes can be created by NAP. Corresponds to the JSON property autoprovisioningLocations

Returns:

  • (Array<String>)


2092
2093
2094
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2092

def autoprovisioning_locations
  @autoprovisioning_locations
end

#autoprovisioning_node_pool_defaultsGoogle::Apis::ContainerV1beta1::AutoprovisioningNodePoolDefaults

AutoprovisioningNodePoolDefaults contains defaults for a node pool created by NAP. Corresponds to the JSON property autoprovisioningNodePoolDefaults



2098
2099
2100
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2098

def autoprovisioning_node_pool_defaults
  @autoprovisioning_node_pool_defaults
end

#autoscaling_profileString

Defines autoscaling behaviour. Corresponds to the JSON property autoscalingProfile

Returns:

  • (String)


2103
2104
2105
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2103

def autoscaling_profile
  @autoscaling_profile
end

#default_compute_class_configGoogle::Apis::ContainerV1beta1::DefaultComputeClassConfig

DefaultComputeClassConfig defines default compute class configuration. Corresponds to the JSON property defaultComputeClassConfig



2108
2109
2110
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2108

def default_compute_class_config
  @default_compute_class_config
end

#enable_node_autoprovisioningBoolean Also known as: enable_node_autoprovisioning?

Enables automatic node pool creation and deletion. Corresponds to the JSON property enableNodeAutoprovisioning

Returns:

  • (Boolean)


2113
2114
2115
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2113

def enable_node_autoprovisioning
  @enable_node_autoprovisioning
end

#resource_limitsArray<Google::Apis::ContainerV1beta1::ResourceLimit>

Contains global constraints regarding minimum and maximum amount of resources in the cluster. Corresponds to the JSON property resourceLimits



2120
2121
2122
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2120

def resource_limits
  @resource_limits
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2127
2128
2129
2130
2131
2132
2133
2134
2135
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2127

def update!(**args)
  @autopilot_general_profile = args[:autopilot_general_profile] if args.key?(:autopilot_general_profile)
  @autoprovisioning_locations = args[:autoprovisioning_locations] if args.key?(:autoprovisioning_locations)
  @autoprovisioning_node_pool_defaults = args[:autoprovisioning_node_pool_defaults] if args.key?(:autoprovisioning_node_pool_defaults)
  @autoscaling_profile = args[:autoscaling_profile] if args.key?(:autoscaling_profile)
  @default_compute_class_config = args[:default_compute_class_config] if args.key?(:default_compute_class_config)
  @enable_node_autoprovisioning = args[:enable_node_autoprovisioning] if args.key?(:enable_node_autoprovisioning)
  @resource_limits = args[:resource_limits] if args.key?(:resource_limits)
end