Class: Google::Apis::ContainerV1beta1::ClusterPolicyConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

ClusterPolicyConfig stores the configuration for cluster wide policies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterPolicyConfig

Returns a new instance of ClusterPolicyConfig.



2186
2187
2188
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2186

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#no_standard_node_poolsBoolean Also known as: no_standard_node_pools?

Denotes preventing standard node pools and requiring only autopilot node pools. Corresponds to the JSON property noStandardNodePools

Returns:

  • (Boolean)


2164
2165
2166
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2164

def no_standard_node_pools
  @no_standard_node_pools
end

#no_system_impersonationBoolean Also known as: no_system_impersonation?

Denotes preventing impersonation and CSRs for GKE System users. Corresponds to the JSON property noSystemImpersonation

Returns:

  • (Boolean)


2170
2171
2172
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2170

def no_system_impersonation
  @no_system_impersonation
end

#no_system_mutationBoolean Also known as: no_system_mutation?

Denotes that preventing creation and mutation of resources in GKE managed namespaces and cluster-scoped GKE managed resources . Corresponds to the JSON property noSystemMutation

Returns:

  • (Boolean)


2177
2178
2179
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2177

def no_system_mutation
  @no_system_mutation
end

#no_unsafe_webhooksBoolean Also known as: no_unsafe_webhooks?

Denotes preventing unsafe webhooks. Corresponds to the JSON property noUnsafeWebhooks

Returns:

  • (Boolean)


2183
2184
2185
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2183

def no_unsafe_webhooks
  @no_unsafe_webhooks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2191
2192
2193
2194
2195
2196
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2191

def update!(**args)
  @no_standard_node_pools = args[:no_standard_node_pools] if args.key?(:no_standard_node_pools)
  @no_system_impersonation = args[:no_system_impersonation] if args.key?(:no_system_impersonation)
  @no_system_mutation = args[:no_system_mutation] if args.key?(:no_system_mutation)
  @no_unsafe_webhooks = args[:no_unsafe_webhooks] if args.key?(:no_unsafe_webhooks)
end