Class: Google::Apis::ContainerV1beta1::ConfidentialNodes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

ConfidentialNodes is configuration for the confidential nodes feature, which makes nodes run on confidential VMs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfidentialNodes

Returns a new instance of ConfidentialNodes.



2931
2932
2933
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2931

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidential_instance_typeString

Defines the type of technology used by the confidential node. Corresponds to the JSON property confidentialInstanceType

Returns:

  • (String)


2923
2924
2925
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2923

def confidential_instance_type
  @confidential_instance_type
end

#enabledBoolean Also known as: enabled?

Whether Confidential Nodes feature is enabled. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


2928
2929
2930
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2928

def enabled
  @enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2936
2937
2938
2939
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2936

def update!(**args)
  @confidential_instance_type = args[:confidential_instance_type] if args.key?(:confidential_instance_type)
  @enabled = args[:enabled] if args.key?(:enabled)
end