Class: Google::Apis::ContainerV1beta1::CrashLoopBackOffConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Contains config to modify node-level parameters for container restart behavior.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CrashLoopBackOffConfig

Returns a new instance of CrashLoopBackOffConfig.



3077
3078
3079
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3077

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_container_restart_periodString

Optional. The maximum duration the backoff delay can accrue to for container restarts, minimum 1 second, maximum 300 seconds. If not set, defaults to the internal crashloopbackoff maximum. The string must be a sequence of decimal numbers, each with optional fraction and a unit suffix, such as "300ms". Valid time units are "ns", "us" (or "µs"), "ms", "s", "m", "h". See https:// kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#configurable- container-restart-delay for more details. Corresponds to the JSON property maxContainerRestartPeriod

Returns:

  • (String)


3075
3076
3077
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3075

def max_container_restart_period
  @max_container_restart_period
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3082
3083
3084
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3082

def update!(**args)
  @max_container_restart_period = args[:max_container_restart_period] if args.key?(:max_container_restart_period)
end