Class: Google::Apis::ContainerV1beta1::CreateClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

CreateClusterRequest creates a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateClusterRequest

Returns a new instance of CreateClusterRequest.



3336
3337
3338
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3336

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusterGoogle::Apis::ContainerV1beta1::Cluster

A Google Kubernetes Engine cluster. Corresponds to the JSON property cluster



3314
3315
3316
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3314

def cluster
  @cluster
end

#parentString

The parent (project and location) where the cluster will be created. Specified in the format projects/*/locations/*. Corresponds to the JSON property parent

Returns:

  • (String)


3320
3321
3322
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3320

def parent
  @parent
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property projectId

Returns:

  • (String)


3327
3328
3329
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3327

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property zone

Returns:

  • (String)


3334
3335
3336
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3334

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3341
3342
3343
3344
3345
3346
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3341

def update!(**args)
  @cluster = args[:cluster] if args.key?(:cluster)
  @parent = args[:parent] if args.key?(:parent)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end