Class: Google::Apis::ContainerV1beta1::CreateNodePoolRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

CreateNodePoolRequest creates a node pool for a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateNodePoolRequest

Returns a new instance of CreateNodePoolRequest.



3389
3390
3391
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3389

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property clusterId

Returns:

  • (String)


3357
3358
3359
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3357

def cluster_id
  @cluster_id
end

#node_poolGoogle::Apis::ContainerV1beta1::NodePool

NodePool contains the name and configuration for a cluster's node pool. Node pools are a set of nodes (i.e. VM's), with a common configuration and specification, under the control of the cluster master. They may have a set of Kubernetes labels applied to them, which may be used to reference them during pod scheduling. They may also be resized up or down, to accommodate the workload. Corresponds to the JSON property nodePool



3367
3368
3369
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3367

def node_pool
  @node_pool
end

#parentString

The parent (project, location, cluster name) where the node pool will be created. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property parent

Returns:

  • (String)


3373
3374
3375
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3373

def parent
  @parent
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property projectId

Returns:

  • (String)


3380
3381
3382
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3380

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property zone

Returns:

  • (String)


3387
3388
3389
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3387

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3394
3395
3396
3397
3398
3399
3400
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3394

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @node_pool = args[:node_pool] if args.key?(:node_pool)
  @parent = args[:parent] if args.key?(:parent)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end