Class: Google::Apis::ContainerV1beta1::CustomImageConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

CustomImageConfig contains the information r

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomImageConfig

Returns a new instance of CustomImageConfig.



3417
3418
3419
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3417

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#imageString

The name of the image to use for this node. Corresponds to the JSON property image

Returns:

  • (String)


3410
3411
3412
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3410

def image
  @image
end

#image_projectString

The project containing the image to use for this node. Corresponds to the JSON property imageProject

Returns:

  • (String)


3415
3416
3417
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3415

def image_project
  @image_project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3422
3423
3424
3425
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3422

def update!(**args)
  @image = args[:image] if args.key?(:image)
  @image_project = args[:image_project] if args.key?(:image_project)
end