Class: Google::Apis::ContainerV1beta1::DatabaseEncryption

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Configuration of etcd encryption.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseEncryption

Returns a new instance of DatabaseEncryption.



3599
3600
3601
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3599

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_stateString

Output only. The current state of etcd encryption. Corresponds to the JSON property currentState

Returns:

  • (String)


3575
3576
3577
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3575

def current_state
  @current_state
end

#decryption_keysArray<String>

Output only. Keys in use by the cluster for decrypting existing objects, in addition to the key in key_name. Each item is a CloudKMS key resource. Corresponds to the JSON property decryptionKeys

Returns:

  • (Array<String>)


3581
3582
3583
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3581

def decryption_keys
  @decryption_keys
end

#key_nameString

Name of CloudKMS key to use for the encryption of secrets in etcd. Ex. projects/my-project/locations/global/keyRings/my-ring/cryptoKeys/my-key Corresponds to the JSON property keyName

Returns:

  • (String)


3587
3588
3589
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3587

def key_name
  @key_name
end

#last_operation_errorsArray<Google::Apis::ContainerV1beta1::OperationError>

Output only. Records errors seen during DatabaseEncryption update operations. Corresponds to the JSON property lastOperationErrors



3592
3593
3594
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3592

def last_operation_errors
  @last_operation_errors
end

#stateString

The desired state of etcd encryption. Corresponds to the JSON property state

Returns:

  • (String)


3597
3598
3599
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3597

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3604
3605
3606
3607
3608
3609
3610
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3604

def update!(**args)
  @current_state = args[:current_state] if args.key?(:current_state)
  @decryption_keys = args[:decryption_keys] if args.key?(:decryption_keys)
  @key_name = args[:key_name] if args.key?(:key_name)
  @last_operation_errors = args[:last_operation_errors] if args.key?(:last_operation_errors)
  @state = args[:state] if args.key?(:state)
end