Class: Google::Apis::ContainerV1beta1::EphemeralLocalSsdProfile

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Swap on the local SSD shared with pod ephemeral storage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EphemeralLocalSsdProfile

Returns a new instance of EphemeralLocalSsdProfile.



3956
3957
3958
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3956

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#swap_size_gibFixnum

Specifies the size of the swap space in gibibytes (GiB). Corresponds to the JSON property swapSizeGib

Returns:

  • (Fixnum)


3948
3949
3950
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3948

def swap_size_gib
  @swap_size_gib
end

#swap_size_percentFixnum

Specifies the size of the swap space as a percentage of the ephemeral local SSD capacity. Corresponds to the JSON property swapSizePercent

Returns:

  • (Fixnum)


3954
3955
3956
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3954

def swap_size_percent
  @swap_size_percent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3961
3962
3963
3964
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3961

def update!(**args)
  @swap_size_gib = args[:swap_size_gib] if args.key?(:swap_size_gib)
  @swap_size_percent = args[:swap_size_percent] if args.key?(:swap_size_percent)
end