Class: Google::Apis::ContainerV1beta1::EvictionMinimumReclaim

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Eviction minimum reclaims are the resource amounts of minimum reclaims for each eviction signal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EvictionMinimumReclaim

Returns a new instance of EvictionMinimumReclaim.



4183
4184
4185
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4183

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#imagefs_availableString

Optional. Minimum reclaim for eviction due to imagefs available signal. Only take percentage value for now. Sample format: "10%". Must be <=10%. See https:/ /kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/# eviction-signals Corresponds to the JSON property imagefsAvailable

Returns:

  • (String)


4141
4142
4143
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4141

def imagefs_available
  @imagefs_available
end

#imagefs_inodes_freeString

Optional. Minimum reclaim for eviction due to imagefs inodes free signal. Only take percentage value for now. Sample format: "10%". Must be <=10%. See https:/ /kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/# eviction-signals Corresponds to the JSON property imagefsInodesFree

Returns:

  • (String)


4149
4150
4151
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4149

def imagefs_inodes_free
  @imagefs_inodes_free
end

#memory_availableString

Optional. Minimum reclaim for eviction due to memory available signal. Only take percentage value for now. Sample format: "10%". Must be <=10%. See https:/ /kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/# eviction-signals Corresponds to the JSON property memoryAvailable

Returns:

  • (String)


4157
4158
4159
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4157

def memory_available
  @memory_available
end

#nodefs_availableString

Optional. Minimum reclaim for eviction due to nodefs available signal. Only take percentage value for now. Sample format: "10%". Must be <=10%. See https:/ /kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/# eviction-signals Corresponds to the JSON property nodefsAvailable

Returns:

  • (String)


4165
4166
4167
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4165

def nodefs_available
  @nodefs_available
end

#nodefs_inodes_freeString

Optional. Minimum reclaim for eviction due to nodefs inodes free signal. Only take percentage value for now. Sample format: "10%". Must be <=10%. See https:/ /kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/# eviction-signals Corresponds to the JSON property nodefsInodesFree

Returns:

  • (String)


4173
4174
4175
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4173

def nodefs_inodes_free
  @nodefs_inodes_free
end

#pid_availableString

Optional. Minimum reclaim for eviction due to pid available signal. Only take percentage value for now. Sample format: "10%". Must be <=10%. See https:// kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/# eviction-signals Corresponds to the JSON property pidAvailable

Returns:

  • (String)


4181
4182
4183
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4181

def pid_available
  @pid_available
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4188
4189
4190
4191
4192
4193
4194
4195
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4188

def update!(**args)
  @imagefs_available = args[:imagefs_available] if args.key?(:imagefs_available)
  @imagefs_inodes_free = args[:imagefs_inodes_free] if args.key?(:imagefs_inodes_free)
  @memory_available = args[:memory_available] if args.key?(:memory_available)
  @nodefs_available = args[:nodefs_available] if args.key?(:nodefs_available)
  @nodefs_inodes_free = args[:nodefs_inodes_free] if args.key?(:nodefs_inodes_free)
  @pid_available = args[:pid_available] if args.key?(:pid_available)
end