Class: Google::Apis::ContainerV1beta1::GetJsonWebKeysResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

GetJSONWebKeysResponse is a valid JSON Web Key Set as specified in rfc 7517

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GetJsonWebKeysResponse

Returns a new instance of GetJsonWebKeysResponse.



4230
4231
4232
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4230

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cache_headerGoogle::Apis::ContainerV1beta1::HttpCacheControlResponseHeader

RFC-2616: cache control support Corresponds to the JSON property cacheHeader



4223
4224
4225
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4223

def cache_header
  @cache_header
end

#keysArray<Google::Apis::ContainerV1beta1::Jwk>

The public component of the keys used by the cluster to sign token requests. Corresponds to the JSON property keys



4228
4229
4230
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4228

def keys
  @keys
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4235
4236
4237
4238
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4235

def update!(**args)
  @cache_header = args[:cache_header] if args.key?(:cache_header)
  @keys = args[:keys] if args.key?(:keys)
end