Class: Google::Apis::ContainerV1beta1::HighScaleCheckpointingConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::HighScaleCheckpointingConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
Configuration for the High Scale Checkpointing.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Whether the High Scale Checkpointing is enabled for this cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HighScaleCheckpointingConfig
constructor
A new instance of HighScaleCheckpointingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HighScaleCheckpointingConfig
Returns a new instance of HighScaleCheckpointingConfig.
4242 4243 4244 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4242 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Whether the High Scale Checkpointing is enabled for this cluster.
Corresponds to the JSON property enabled
4239 4240 4241 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4239 def enabled @enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4247 4248 4249 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4247 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) end |