Class: Google::Apis::ContainerV1beta1::HttpCacheControlResponseHeader
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::HttpCacheControlResponseHeader
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
RFC-2616: cache control support
Instance Attribute Summary collapse
-
#age ⇒ Fixnum
14.6 response cache age, in seconds since the response is generated Corresponds to the JSON property
age. -
#directive ⇒ String
14.9 request and response directives Corresponds to the JSON property
directive. -
#expires ⇒ String
14.21 response cache expires, in RFC 1123 date format Corresponds to the JSON property
expires.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpCacheControlResponseHeader
constructor
A new instance of HttpCacheControlResponseHeader.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpCacheControlResponseHeader
Returns a new instance of HttpCacheControlResponseHeader.
4497 4498 4499 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4497 def initialize(**args) update!(**args) end |
Instance Attribute Details
#age ⇒ Fixnum
14.6 response cache age, in seconds since the response is generated
Corresponds to the JSON property age
4485 4486 4487 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4485 def age @age end |
#directive ⇒ String
14.9 request and response directives
Corresponds to the JSON property directive
4490 4491 4492 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4490 def directive @directive end |
#expires ⇒ String
14.21 response cache expires, in RFC 1123 date format
Corresponds to the JSON property expires
4495 4496 4497 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4495 def expires @expires end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4502 4503 4504 4505 4506 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4502 def update!(**args) @age = args[:age] if args.key?(:age) @directive = args[:directive] if args.key?(:directive) @expires = args[:expires] if args.key?(:expires) end |