Class: Google::Apis::ContainerV1beta1::HttpLoadBalancing

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Configuration options for the HTTP (L7) load balancing controller addon, which makes it easy to set up HTTP load balancers for services in a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpLoadBalancing

Returns a new instance of HttpLoadBalancing.



4887
4888
4889
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disabledBoolean Also known as: disabled?

Whether the HTTP Load Balancing controller is enabled in the cluster. When enabled, it runs a small pod in the cluster that manages the load balancers. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


4884
4885
4886
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4884

def disabled
  @disabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4892
4893
4894
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4892

def update!(**args)
  @disabled = args[:disabled] if args.key?(:disabled)
end