Class: Google::Apis::ContainerV1beta1::IpEndpointsConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

IP endpoints configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IpEndpointsConfig

Returns a new instance of IpEndpointsConfig.



5214
5215
5216
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5214

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorized_networks_configGoogle::Apis::ContainerV1beta1::MasterAuthorizedNetworksConfig

Configuration options for the master authorized networks feature. Enabled master authorized networks will disallow all external traffic to access Kubernetes master through HTTPS except traffic from the given CIDR blocks, Google Compute Engine Public IPs and Google Prod IPs. Corresponds to the JSON property authorizedNetworksConfig



5170
5171
5172
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5170

def authorized_networks_config
  @authorized_networks_config
end

#enable_public_endpointBoolean Also known as: enable_public_endpoint?

Controls whether the control plane allows access through a public IP. It is invalid to specify both PrivateClusterConfig.enablePrivateEndpoint and this field at the same time. Corresponds to the JSON property enablePublicEndpoint

Returns:

  • (Boolean)


5177
5178
5179
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5177

def enable_public_endpoint
  @enable_public_endpoint
end

#enabledBoolean Also known as: enabled?

Controls whether to allow direct IP access. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


5183
5184
5185
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5183

def enabled
  @enabled
end

#global_accessBoolean Also known as: global_access?

Controls whether the control plane's private endpoint is accessible from sources in other regions. It is invalid to specify both PrivateClusterMasterGlobalAccessConfig.enabled and this field at the same time. Corresponds to the JSON property globalAccess

Returns:

  • (Boolean)


5191
5192
5193
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5191

def global_access
  @global_access
end

#private_endpointString

Output only. The internal IP address of this cluster's control plane. Only populated if enabled. Corresponds to the JSON property privateEndpoint

Returns:

  • (String)


5198
5199
5200
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5198

def private_endpoint
  @private_endpoint
end

#private_endpoint_subnetworkString

Subnet to provision the master's private endpoint during cluster creation. Specified in projects//regions//subnetworks/* format. It is invalid to specify both PrivateClusterConfig.privateEndpointSubnetwork and this field at the same time. Corresponds to the JSON property privateEndpointSubnetwork

Returns:

  • (String)


5206
5207
5208
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5206

def private_endpoint_subnetwork
  @private_endpoint_subnetwork
end

#public_endpointString

Output only. The external IP address of this cluster's control plane. Only populated if enabled. Corresponds to the JSON property publicEndpoint

Returns:

  • (String)


5212
5213
5214
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5212

def public_endpoint
  @public_endpoint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5219
5220
5221
5222
5223
5224
5225
5226
5227
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5219

def update!(**args)
  @authorized_networks_config = args[:authorized_networks_config] if args.key?(:authorized_networks_config)
  @enable_public_endpoint = args[:enable_public_endpoint] if args.key?(:enable_public_endpoint)
  @enabled = args[:enabled] if args.key?(:enabled)
  @global_access = args[:global_access] if args.key?(:global_access)
  @private_endpoint = args[:private_endpoint] if args.key?(:private_endpoint)
  @private_endpoint_subnetwork = args[:private_endpoint_subnetwork] if args.key?(:private_endpoint_subnetwork)
  @public_endpoint = args[:public_endpoint] if args.key?(:public_endpoint)
end