Class: Google::Apis::ContainerV1beta1::KubernetesDashboard
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::KubernetesDashboard
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
Configuration for the Kubernetes Dashboard.
Instance Attribute Summary collapse
-
#disabled ⇒ Boolean
(also: #disabled?)
Whether the Kubernetes Dashboard is enabled for this cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KubernetesDashboard
constructor
A new instance of KubernetesDashboard.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KubernetesDashboard
Returns a new instance of KubernetesDashboard.
5488 5489 5490 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5488 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disabled ⇒ Boolean Also known as: disabled?
Whether the Kubernetes Dashboard is enabled for this cluster.
Corresponds to the JSON property disabled
5485 5486 5487 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5485 def disabled @disabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5493 5494 5495 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5493 def update!(**args) @disabled = args[:disabled] if args.key?(:disabled) end |