Class: Google::Apis::ContainerV1beta1::ListClustersResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

ListClustersResponse is the result of ListClustersRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListClustersResponse

Returns a new instance of ListClustersResponse.



5644
5645
5646
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5644

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clustersArray<Google::Apis::ContainerV1beta1::Cluster>

A list of clusters in the project in the specified zone, or across all ones. Corresponds to the JSON property clusters



5636
5637
5638
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5636

def clusters
  @clusters
end

#missing_zonesArray<String>

If any zones are listed here, the list of clusters returned may be missing those zones. Corresponds to the JSON property missingZones

Returns:

  • (Array<String>)


5642
5643
5644
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5642

def missing_zones
  @missing_zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5649
5650
5651
5652
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5649

def update!(**args)
  @clusters = args[:clusters] if args.key?(:clusters)
  @missing_zones = args[:missing_zones] if args.key?(:missing_zones)
end