Class: Google::Apis::ContainerV1beta1::LustreCsiDriverConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Configuration for the Lustre CSI driver.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LustreCsiDriverConfig

Returns a new instance of LustreCsiDriverConfig.



5911
5912
5913
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5911

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disable_multi_nicBoolean Also known as: disable_multi_nic?

When set to true, this disables multi-NIC support for the Lustre CSI driver. By default, GKE enables multi-NIC support, which allows the Lustre CSI driver to automatically detect and configure all suitable network interfaces on a node to maximize I/O performance for demanding workloads. Corresponds to the JSON property disableMultiNic

Returns:

  • (Boolean)


5889
5890
5891
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5889

def disable_multi_nic
  @disable_multi_nic
end

#enable_legacy_lustre_portBoolean Also known as: enable_legacy_lustre_port?

If set to true, the Lustre CSI driver will install Lustre kernel modules using port 6988. This serves as a workaround for a port conflict with the gke- metadata-server. This field is required ONLY under the following conditions: 1. The GKE node version is older than 1.33.2-gke.4655000. 2. You're connecting to a Lustre instance that has the 'gke-support-enabled' flag. Deprecated: This flag is no longer required as of GKE node version 1.33.2-gke.4655000, unless you are connecting to a Lustre instance that has the gke-support-enabled flag. Corresponds to the JSON property enableLegacyLustrePort

Returns:

  • (Boolean)


5902
5903
5904
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5902

def enable_legacy_lustre_port
  @enable_legacy_lustre_port
end

#enabledBoolean Also known as: enabled?

Whether the Lustre CSI driver is enabled for this cluster. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


5908
5909
5910
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5908

def enabled
  @enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5916
5917
5918
5919
5920
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5916

def update!(**args)
  @disable_multi_nic = args[:disable_multi_nic] if args.key?(:disable_multi_nic)
  @enable_legacy_lustre_port = args[:enable_legacy_lustre_port] if args.key?(:enable_legacy_lustre_port)
  @enabled = args[:enabled] if args.key?(:enabled)
end