Class: Google::Apis::ContainerV1beta1::NetworkPolicyConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Configuration for NetworkPolicy. This only tracks whether the addon is enabled or not on the Master, it does not track whether network policy is enabled for the nodes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyConfig

Returns a new instance of NetworkPolicyConfig.



6580
6581
6582
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6580

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disabledBoolean Also known as: disabled?

Whether NetworkPolicy is enabled for this cluster. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


6577
6578
6579
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6577

def disabled
  @disabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6585
6586
6587
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6585

def update!(**args)
  @disabled = args[:disabled] if args.key?(:disabled)
end