Class: Google::Apis::ContainerV1beta1::NodeKernelModuleLoading
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::NodeKernelModuleLoading
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
Configuration for kernel module loading on nodes.
Instance Attribute Summary collapse
-
#policy ⇒ String
Set the node module loading policy for nodes in the node pool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeKernelModuleLoading
constructor
A new instance of NodeKernelModuleLoading.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeKernelModuleLoading
Returns a new instance of NodeKernelModuleLoading.
6489 6490 6491 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6489 def initialize(**args) update!(**args) end |
Instance Attribute Details
#policy ⇒ String
Set the node module loading policy for nodes in the node pool.
Corresponds to the JSON property policy
6487 6488 6489 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6487 def policy @policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6494 6495 6496 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6494 def update!(**args) @policy = args[:policy] if args.key?(:policy) end |