Class: Google::Apis::ContainerV1beta1::PodSnapshotConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::PodSnapshotConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
PodSnapshotConfig is the configuration for GKE Pod Snapshots feature.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Whether or not the Pod Snapshots feature is enabled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PodSnapshotConfig
constructor
A new instance of PodSnapshotConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PodSnapshotConfig
Returns a new instance of PodSnapshotConfig.
8480 8481 8482 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8480 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Whether or not the Pod Snapshots feature is enabled.
Corresponds to the JSON property enabled
8477 8478 8479 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8477 def enabled @enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8485 8486 8487 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8485 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) end |