Class: Google::Apis::ContainerV1beta1::RecurringTimeWindow
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::RecurringTimeWindow
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
Represents an arbitrary window of time that recurs.
Instance Attribute Summary collapse
-
#recurrence ⇒ String
An RRULE (https://tools.ietf.org/html/rfc5545#section-3.8.5.3) for how this window reccurs.
-
#window ⇒ Google::Apis::ContainerV1beta1::TimeWindow
Represents an arbitrary window of time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RecurringTimeWindow
constructor
A new instance of RecurringTimeWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RecurringTimeWindow
Returns a new instance of RecurringTimeWindow.
9080 9081 9082 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9080 def initialize(**args) update!(**args) end |
Instance Attribute Details
#recurrence ⇒ String
An RRULE (https://tools.ietf.org/html/rfc5545#section-3.8.5.3) for how this
window reccurs. They go on for the span of time between the start and end time.
For example, to have something repeat every weekday, you'd use: FREQ=WEEKLY;
BYDAY=MO,TU,WE,TH,FR To repeat some window daily (equivalent to the
DailyMaintenanceWindow): FREQ=DAILY For the first weekend of every month:
FREQ=MONTHLY;BYSETPOS=1;BYDAY=SA,SU This specifies how frequently the window
starts. Eg, if you wanted to have a 9-5 UTC-4 window every weekday, you'd use
something like: start time = 2019-01-01T09:00:00-0400 end time = 2019-01-
01T17:00:00-0400 recurrence = FREQ=WEEKLY;BYDAY=MO,TU,WE,TH,FR Windows can
span multiple days. Eg, to make the window encompass every weekend from
midnight Saturday till the last minute of Sunday UTC: start time = 2019-01-
05T00:00:00Z end time = 2019-01-07T23:59:00Z recurrence = FREQ=WEEKLY;BYDAY=SA
Note the start and end time's specific dates are largely arbitrary except
to specify duration of the window and when it first starts. The FREQ values of
HOURLY, MINUTELY, and SECONDLY are not supported.
Corresponds to the JSON property recurrence
9073 9074 9075 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9073 def recurrence @recurrence end |
#window ⇒ Google::Apis::ContainerV1beta1::TimeWindow
Represents an arbitrary window of time.
Corresponds to the JSON property window
9078 9079 9080 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9078 def window @window end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9085 9086 9087 9088 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9085 def update!(**args) @recurrence = args[:recurrence] if args.key?(:recurrence) @window = args[:window] if args.key?(:window) end |