Class: Google::Apis::ContainerV1beta1::RollbackSafeUpgradeStatus
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::RollbackSafeUpgradeStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
RollbackSafeUpgradeStatus contains the rollback-safe upgrade status of a cluster.
Instance Attribute Summary collapse
-
#control_plane_upgrade_rollback_end_time ⇒ String
The rollback-safe mode expiration time.
-
#mode ⇒ String
The mode of the rollback-safe upgrade.
-
#previous_version ⇒ String
The GKE version that the cluster previously used before step-one upgrade.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RollbackSafeUpgradeStatus
constructor
A new instance of RollbackSafeUpgradeStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RollbackSafeUpgradeStatus
Returns a new instance of RollbackSafeUpgradeStatus.
9331 9332 9333 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9331 def initialize(**args) update!(**args) end |
Instance Attribute Details
#control_plane_upgrade_rollback_end_time ⇒ String
The rollback-safe mode expiration time.
Corresponds to the JSON property controlPlaneUpgradeRollbackEndTime
9319 9320 9321 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9319 def control_plane_upgrade_rollback_end_time @control_plane_upgrade_rollback_end_time end |
#mode ⇒ String
The mode of the rollback-safe upgrade.
Corresponds to the JSON property mode
9324 9325 9326 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9324 def mode @mode end |
#previous_version ⇒ String
The GKE version that the cluster previously used before step-one upgrade.
Corresponds to the JSON property previousVersion
9329 9330 9331 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9329 def previous_version @previous_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9336 9337 9338 9339 9340 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9336 def update!(**args) @control_plane_upgrade_rollback_end_time = args[:control_plane_upgrade_rollback_end_time] if args.key?(:control_plane_upgrade_rollback_end_time) @mode = args[:mode] if args.key?(:mode) @previous_version = args[:previous_version] if args.key?(:previous_version) end |