Class: Google::Apis::ContainerV1beta1::SecurityBulletinEvent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

SecurityBulletinEvent is a notification sent to customers when a security bulletin has been posted that they are vulnerable to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityBulletinEvent

Returns a new instance of SecurityBulletinEvent.



9576
9577
9578
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9576

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affected_supported_minorsArray<String>

The GKE minor versions affected by this vulnerability. Corresponds to the JSON property affectedSupportedMinors

Returns:

  • (Array<String>)


9515
9516
9517
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9515

def affected_supported_minors
  @affected_supported_minors
end

#brief_descriptionString

A brief description of the bulletin. See the bulletin pointed to by the bulletin_uri field for an expanded description. Corresponds to the JSON property briefDescription

Returns:

  • (String)


9521
9522
9523
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9521

def brief_description
  @brief_description
end

#bulletin_idString

The ID of the bulletin corresponding to the vulnerability. Corresponds to the JSON property bulletinId

Returns:

  • (String)


9526
9527
9528
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9526

def bulletin_id
  @bulletin_id
end

#bulletin_uriString

The URI link to the bulletin on the website for more information. Corresponds to the JSON property bulletinUri

Returns:

  • (String)


9531
9532
9533
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9531

def bulletin_uri
  @bulletin_uri
end

#cve_idsArray<String>

The CVEs associated with this bulletin. Corresponds to the JSON property cveIds

Returns:

  • (Array<String>)


9536
9537
9538
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9536

def cve_ids
  @cve_ids
end

#manual_steps_requiredBoolean Also known as: manual_steps_required?

If this field is specified, it means there are manual steps that the user must take to make their clusters safe. Corresponds to the JSON property manualStepsRequired

Returns:

  • (Boolean)


9542
9543
9544
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9542

def manual_steps_required
  @manual_steps_required
end

#mitigated_versionsArray<String>

The GKE versions where this vulnerability is mitigated. Corresponds to the JSON property mitigatedVersions

Returns:

  • (Array<String>)


9548
9549
9550
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9548

def mitigated_versions
  @mitigated_versions
end

#patched_versionsArray<String>

The GKE versions where this vulnerability is patched. Corresponds to the JSON property patchedVersions

Returns:

  • (Array<String>)


9553
9554
9555
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9553

def patched_versions
  @patched_versions
end

#resource_type_affectedString

The resource type (node/control plane) that has the vulnerability. Multiple notifications (1 notification per resource type) will be sent for a vulnerability that affects > 1 resource type. Corresponds to the JSON property resourceTypeAffected

Returns:

  • (String)


9560
9561
9562
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9560

def resource_type_affected
  @resource_type_affected
end

#severityString

The severity of this bulletin as it relates to GKE. Corresponds to the JSON property severity

Returns:

  • (String)


9565
9566
9567
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9565

def severity
  @severity
end

#suggested_upgrade_targetString

This represents a version selected from the patched_versions field that the cluster receiving this notification should most likely want to upgrade to based on its current version. Note that if this notification is being received by a given cluster, it means that this version is currently available as an upgrade target in that cluster's location. Corresponds to the JSON property suggestedUpgradeTarget

Returns:

  • (String)


9574
9575
9576
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9574

def suggested_upgrade_target
  @suggested_upgrade_target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9581
9582
9583
9584
9585
9586
9587
9588
9589
9590
9591
9592
9593
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9581

def update!(**args)
  @affected_supported_minors = args[:affected_supported_minors] if args.key?(:affected_supported_minors)
  @brief_description = args[:brief_description] if args.key?(:brief_description)
  @bulletin_id = args[:bulletin_id] if args.key?(:bulletin_id)
  @bulletin_uri = args[:bulletin_uri] if args.key?(:bulletin_uri)
  @cve_ids = args[:cve_ids] if args.key?(:cve_ids)
  @manual_steps_required = args[:manual_steps_required] if args.key?(:manual_steps_required)
  @mitigated_versions = args[:mitigated_versions] if args.key?(:mitigated_versions)
  @patched_versions = args[:patched_versions] if args.key?(:patched_versions)
  @resource_type_affected = args[:resource_type_affected] if args.key?(:resource_type_affected)
  @severity = args[:severity] if args.key?(:severity)
  @suggested_upgrade_target = args[:suggested_upgrade_target] if args.key?(:suggested_upgrade_target)
end