Class: Google::Apis::ContainerV1beta1::SetLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

SetLabelsRequest sets the Google Cloud Platform labels on a Google Container Engine cluster, which will in turn set them for Google Compute Engine resources used by that cluster

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetLabelsRequest

Returns a new instance of SetLabelsRequest.



9927
9928
9929
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9927

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9891
9892
9893
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9891

def cluster_id
  @cluster_id
end

#label_fingerprintString

Required. The fingerprint of the previous set of labels for this resource, used to detect conflicts. The fingerprint is initially generated by Kubernetes Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash when updating or changing labels. Make a get() request to the resource to get the latest fingerprint. Corresponds to the JSON property labelFingerprint

Returns:

  • (String)


9900
9901
9902
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9900

def label_fingerprint
  @label_fingerprint
end

#nameString

The name (project, location, cluster name) of the cluster to set labels. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


9906
9907
9908
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9906

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9913
9914
9915
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9913

def project_id
  @project_id
end

#resource_labelsHash<String,String>

Required. The labels to set for that cluster. Corresponds to the JSON property resourceLabels

Returns:

  • (Hash<String,String>)


9918
9919
9920
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9918

def resource_labels
  @resource_labels
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9925
9926
9927
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9925

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9932
9933
9934
9935
9936
9937
9938
9939
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9932

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @resource_labels = args[:resource_labels] if args.key?(:resource_labels)
  @zone = args[:zone] if args.key?(:zone)
end