Class: Google::Apis::ContainerV1beta1::SetLegacyAbacRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

SetLegacyAbacRequest enables or disables the ABAC authorization mechanism for a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetLegacyAbacRequest

Returns a new instance of SetLegacyAbacRequest.



9979
9980
9981
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9979

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to update. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9951
9952
9953
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9951

def cluster_id
  @cluster_id
end

#enabledBoolean Also known as: enabled?

Required. Whether ABAC authorization will be enabled in the cluster. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


9956
9957
9958
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9956

def enabled
  @enabled
end

#nameString

The name (project, location, cluster name) of the cluster to set legacy abac. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


9963
9964
9965
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9963

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9970
9971
9972
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9970

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9977
9978
9979
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9977

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9984
9985
9986
9987
9988
9989
9990
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9984

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @enabled = args[:enabled] if args.key?(:enabled)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end