Class: Google::Apis::ContainerV1beta1::SetLoggingServiceRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

SetLoggingServiceRequest sets the logging service of a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetLoggingServiceRequest

Returns a new instance of SetLoggingServiceRequest.



10088
10089
10090
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10088

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


10055
10056
10057
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10055

def cluster_id
  @cluster_id
end

#logging_serviceString

Required. The logging service the cluster should use to write logs. Currently available options: * logging.googleapis.com/kubernetes - The Cloud Logging service with a Kubernetes-native resource model * logging.googleapis.com - The legacy Cloud Logging service (no longer available as of GKE 1.15). * none

  • no logs will be exported from the cluster. If left as an empty string, logging.googleapis.com/kubernetes will be used for GKE 1.14+ or logging. googleapis.com for earlier versions. Corresponds to the JSON property loggingService

Returns:

  • (String)


10066
10067
10068
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10066

def logging_service
  @logging_service
end

#nameString

The name (project, location, cluster) of the cluster to set logging. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


10072
10073
10074
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10072

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


10079
10080
10081
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10079

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


10086
10087
10088
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10086

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10093
10094
10095
10096
10097
10098
10099
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10093

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @logging_service = args[:logging_service] if args.key?(:logging_service)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end