Class: Google::Apis::ContainerV1beta1::SetMaintenancePolicyRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

SetMaintenancePolicyRequest sets the maintenance policy for a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetMaintenancePolicyRequest

Returns a new instance of SetMaintenancePolicyRequest.



10019
10020
10021
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10019

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Required. The name of the cluster to update. Corresponds to the JSON property clusterId

Returns:

  • (String)


9994
9995
9996
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9994

def cluster_id
  @cluster_id
end

#maintenance_policyGoogle::Apis::ContainerV1beta1::MaintenancePolicy

MaintenancePolicy defines the maintenance policy to be used for the cluster. Corresponds to the JSON property maintenancePolicy



9999
10000
10001
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9999

def maintenance_policy
  @maintenance_policy
end

#nameString

The name (project, location, cluster name) of the cluster to set maintenance policy. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


10005
10006
10007
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10005

def name
  @name
end

#project_idString

Required. The Google Developers Console project ID or project number. Corresponds to the JSON property projectId

Returns:

  • (String)


10011
10012
10013
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10011

def project_id
  @project_id
end

#zoneString

Required. The name of the Google Compute Engine zone in which the cluster resides. Corresponds to the JSON property zone

Returns:

  • (String)


10017
10018
10019
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10017

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10024
10025
10026
10027
10028
10029
10030
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10024

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end