Class: Google::Apis::ContainerV1beta1::SlurmOperatorConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::SlurmOperatorConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
Configuration for the Slurm Operator.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Whether the Slurm Operator is enabled in the cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SlurmOperatorConfig
constructor
A new instance of SlurmOperatorConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SlurmOperatorConfig
Returns a new instance of SlurmOperatorConfig.
10432 10433 10434 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10432 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Whether the Slurm Operator is enabled in the cluster.
Corresponds to the JSON property enabled
10429 10430 10431 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10429 def enabled @enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10437 10438 10439 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10437 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) end |