Class: Google::Apis::ContainerV1beta1::StartIpRotationRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

StartIPRotationRequest creates a new IP for the cluster and then performs a node upgrade on each node pool to point to the new IP.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StartIpRotationRequest

Returns a new instance of StartIpRotationRequest.



10673
10674
10675
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10673

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


10645
10646
10647
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10645

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster name) of the cluster to start IP rotation. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


10651
10652
10653
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10651

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


10658
10659
10660
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10658

def project_id
  @project_id
end

#rotate_credentialsBoolean Also known as: rotate_credentials?

Whether to rotate credentials during IP rotation. Corresponds to the JSON property rotateCredentials

Returns:

  • (Boolean)


10663
10664
10665
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10663

def rotate_credentials
  @rotate_credentials
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


10671
10672
10673
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10671

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10678
10679
10680
10681
10682
10683
10684
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10678

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @rotate_credentials = args[:rotate_credentials] if args.key?(:rotate_credentials)
  @zone = args[:zone] if args.key?(:zone)
end