Class: Google::Apis::ContainerV1beta1::TimeOfDay

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimeOfDay

Returns a new instance of TimeOfDay.



10901
10902
10903
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10901

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hoursFixnum

Hours of a day in 24 hour format. Must be greater than or equal to 0 and typically must be less than or equal to 23. An API may choose to allow the value "24:00:00" for scenarios like business closing time. Corresponds to the JSON property hours

Returns:

  • (Fixnum)


10880
10881
10882
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10880

def hours
  @hours
end

#minutesFixnum

Minutes of an hour. Must be greater than or equal to 0 and less than or equal to 59. Corresponds to the JSON property minutes

Returns:

  • (Fixnum)


10886
10887
10888
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10886

def minutes
  @minutes
end

#nanosFixnum

Fractions of seconds, in nanoseconds. Must be greater than or equal to 0 and less than or equal to 999,999,999. Corresponds to the JSON property nanos

Returns:

  • (Fixnum)


10892
10893
10894
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10892

def nanos
  @nanos
end

#secondsFixnum

Seconds of a minute. Must be greater than or equal to 0 and typically must be less than or equal to 59. An API may allow the value 60 if it allows leap- seconds. Corresponds to the JSON property seconds

Returns:

  • (Fixnum)


10899
10900
10901
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10899

def seconds
  @seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10906
10907
10908
10909
10910
10911
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10906

def update!(**args)
  @hours = args[:hours] if args.key?(:hours)
  @minutes = args[:minutes] if args.key?(:minutes)
  @nanos = args[:nanos] if args.key?(:nanos)
  @seconds = args[:seconds] if args.key?(:seconds)
end