Class: Google::Apis::ContainerV1beta1::UpdateClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

UpdateClusterRequest updates the settings of a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateClusterRequest

Returns a new instance of UpdateClusterRequest.



11062
11063
11064
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11062

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


11034
11035
11036
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11034

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster) of the cluster to update. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


11040
11041
11042
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11040

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


11047
11048
11049
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11047

def project_id
  @project_id
end

#updateGoogle::Apis::ContainerV1beta1::ClusterUpdate

ClusterUpdate describes an update to the cluster. Exactly one update can be applied to a cluster with each request, so at most one field can be provided. Corresponds to the JSON property update



11053
11054
11055
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11053

def update
  @update
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


11060
11061
11062
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11060

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11067
11068
11069
11070
11071
11072
11073
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11067

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @update = args[:update] if args.key?(:update)
  @zone = args[:zone] if args.key?(:zone)
end