Class: Google::Apis::ContainerV1beta1::UpdateMasterRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

UpdateMasterRequest updates the master of the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateMasterRequest

Returns a new instance of UpdateMasterRequest.



11137
11138
11139
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11137

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


11104
11105
11106
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11104

def cluster_id
  @cluster_id
end

#master_versionString

Required. The Kubernetes version to change the master to. Users may specify either explicit versions offered by Kubernetes Engine or version aliases, which have the following behavior: - "latest": picks the highest valid Kubernetes version - "1.X": picks the highest valid patch+gke.N patch in the 1. X version - "1.X.Y": picks the highest valid gke.N patch in the 1.X.Y version - "1.X.Y-gke.N": picks an explicit Kubernetes version - "-": picks the default Kubernetes version Corresponds to the JSON property masterVersion

Returns:

  • (String)


11115
11116
11117
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11115

def master_version
  @master_version
end

#nameString

The name (project, location, cluster) of the cluster to update. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


11121
11122
11123
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11121

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


11128
11129
11130
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11128

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


11135
11136
11137
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11135

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11142
11143
11144
11145
11146
11147
11148
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11142

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @master_version = args[:master_version] if args.key?(:master_version)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end