Class: Google::Apis::ContainerV1beta1::UpgradeEvent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

UpgradeEvent is a notification sent to customers by the cluster server when a resource is upgrading.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeEvent

Returns a new instance of UpgradeEvent.



11532
11533
11534
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_emulated_versionString

The current emulated version before the upgrade. Corresponds to the JSON property currentEmulatedVersion

Returns:

  • (String)


11494
11495
11496
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11494

def current_emulated_version
  @current_emulated_version
end

#current_versionString

The current version before the upgrade. Corresponds to the JSON property currentVersion

Returns:

  • (String)


11499
11500
11501
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11499

def current_version
  @current_version
end

#operationString

The operation associated with this upgrade. Corresponds to the JSON property operation

Returns:

  • (String)


11504
11505
11506
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11504

def operation
  @operation
end

#operation_start_timeString

The time when the operation was started. Corresponds to the JSON property operationStartTime

Returns:

  • (String)


11509
11510
11511
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11509

def operation_start_time
  @operation_start_time
end

#resourceString

Optional relative path to the resource. For example in node pool upgrades, the relative path of the node pool. Corresponds to the JSON property resource

Returns:

  • (String)


11515
11516
11517
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11515

def resource
  @resource
end

#resource_typeString

The resource type that is upgrading. Corresponds to the JSON property resourceType

Returns:

  • (String)


11520
11521
11522
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11520

def resource_type
  @resource_type
end

#target_emulated_versionString

The target emulated version for the upgrade. Corresponds to the JSON property targetEmulatedVersion

Returns:

  • (String)


11525
11526
11527
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11525

def target_emulated_version
  @target_emulated_version
end

#target_versionString

The target version for the upgrade. Corresponds to the JSON property targetVersion

Returns:

  • (String)


11530
11531
11532
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11530

def target_version
  @target_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11537
11538
11539
11540
11541
11542
11543
11544
11545
11546
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11537

def update!(**args)
  @current_emulated_version = args[:current_emulated_version] if args.key?(:current_emulated_version)
  @current_version = args[:current_version] if args.key?(:current_version)
  @operation = args[:operation] if args.key?(:operation)
  @operation_start_time = args[:operation_start_time] if args.key?(:operation_start_time)
  @resource = args[:resource] if args.key?(:resource)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @target_emulated_version = args[:target_emulated_version] if args.key?(:target_emulated_version)
  @target_version = args[:target_version] if args.key?(:target_version)
end