Class: Google::Apis::ContainerV1beta1::UpgradeInfoEvent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

UpgradeInfoEvent is a notification sent to customers about the upgrade information of a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeInfoEvent

Returns a new instance of UpgradeInfoEvent.



11744
11745
11746
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_emulated_versionString

The current emulated version before the upgrade. Corresponds to the JSON property currentEmulatedVersion

Returns:

  • (String)


11670
11671
11672
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11670

def current_emulated_version
  @current_emulated_version
end

#current_versionString

The current version before the upgrade. Corresponds to the JSON property currentVersion

Returns:

  • (String)


11675
11676
11677
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11675

def current_version
  @current_version
end

#descriptionString

A brief description of the event. Corresponds to the JSON property description

Returns:

  • (String)


11680
11681
11682
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11680

def description
  @description
end

#disruption_eventGoogle::Apis::ContainerV1beta1::DisruptionEvent

DisruptionEvent is a notification sent to customers about the disruption event of a resource. Corresponds to the JSON property disruptionEvent



11686
11687
11688
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11686

def disruption_event
  @disruption_event
end

#end_timeString

The time when the operation ended. Corresponds to the JSON property endTime

Returns:

  • (String)


11691
11692
11693
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11691

def end_time
  @end_time
end

#event_typeString

The type of the event. Corresponds to the JSON property eventType

Returns:

  • (String)


11696
11697
11698
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11696

def event_type
  @event_type
end

#extended_support_end_timeString

The end of extended support timestamp. Corresponds to the JSON property extendedSupportEndTime

Returns:

  • (String)


11701
11702
11703
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11701

def extended_support_end_time
  @extended_support_end_time
end

#operationString

The operation associated with this upgrade. Corresponds to the JSON property operation

Returns:

  • (String)


11706
11707
11708
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11706

def operation
  @operation
end

#resourceString

Optional relative path to the resource. For example in node pool upgrades, the relative path of the node pool. Corresponds to the JSON property resource

Returns:

  • (String)


11712
11713
11714
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11712

def resource
  @resource
end

#resource_typeString

The resource type associated with the upgrade. Corresponds to the JSON property resourceType

Returns:

  • (String)


11717
11718
11719
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11717

def resource_type
  @resource_type
end

#standard_support_end_timeString

The end of standard support timestamp. Corresponds to the JSON property standardSupportEndTime

Returns:

  • (String)


11722
11723
11724
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11722

def standard_support_end_time
  @standard_support_end_time
end

#start_timeString

The time when the operation was started. Corresponds to the JSON property startTime

Returns:

  • (String)


11727
11728
11729
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11727

def start_time
  @start_time
end

#stateString

Output only. The state of the upgrade. Corresponds to the JSON property state

Returns:

  • (String)


11732
11733
11734
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11732

def state
  @state
end

#target_emulated_versionString

The target emulated version for the upgrade. Corresponds to the JSON property targetEmulatedVersion

Returns:

  • (String)


11737
11738
11739
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11737

def target_emulated_version
  @target_emulated_version
end

#target_versionString

The target version for the upgrade. Corresponds to the JSON property targetVersion

Returns:

  • (String)


11742
11743
11744
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11742

def target_version
  @target_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11749
11750
11751
11752
11753
11754
11755
11756
11757
11758
11759
11760
11761
11762
11763
11764
11765
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11749

def update!(**args)
  @current_emulated_version = args[:current_emulated_version] if args.key?(:current_emulated_version)
  @current_version = args[:current_version] if args.key?(:current_version)
  @description = args[:description] if args.key?(:description)
  @disruption_event = args[:disruption_event] if args.key?(:disruption_event)
  @end_time = args[:end_time] if args.key?(:end_time)
  @event_type = args[:event_type] if args.key?(:event_type)
  @extended_support_end_time = args[:extended_support_end_time] if args.key?(:extended_support_end_time)
  @operation = args[:operation] if args.key?(:operation)
  @resource = args[:resource] if args.key?(:resource)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @standard_support_end_time = args[:standard_support_end_time] if args.key?(:standard_support_end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @target_emulated_version = args[:target_emulated_version] if args.key?(:target_emulated_version)
  @target_version = args[:target_version] if args.key?(:target_version)
end