Class: Google::Apis::ContainerV1beta1::UsableSubnetworkSecondaryRange

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Secondary IP range of a usable subnetwork.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsableSubnetworkSecondaryRange

Returns a new instance of UsableSubnetworkSecondaryRange.



11911
11912
11913
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11911

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_cidr_rangeString

The range of IP addresses belonging to this subnetwork secondary range. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


11898
11899
11900
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11898

def ip_cidr_range
  @ip_cidr_range
end

#range_nameString

The name associated with this subnetwork secondary range, used when adding an alias IP range to a VM instance. Corresponds to the JSON property rangeName

Returns:

  • (String)


11904
11905
11906
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11904

def range_name
  @range_name
end

#statusString

This field is to determine the status of the secondary range programmably. Corresponds to the JSON property status

Returns:

  • (String)


11909
11910
11911
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11909

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11916
11917
11918
11919
11920
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11916

def update!(**args)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @range_name = args[:range_name] if args.key?(:range_name)
  @status = args[:status] if args.key?(:status)
end