Class: Google::Apis::ContainerV1beta1::WorkloadConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::WorkloadConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
WorkloadConfig defines the flags to enable or disable the workload configurations for the cluster.
Instance Attribute Summary collapse
-
#audit_mode ⇒ String
Sets which mode of auditing should be used for the cluster's workloads.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadConfig
constructor
A new instance of WorkloadConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadConfig
Returns a new instance of WorkloadConfig.
11120 11121 11122 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11120 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audit_mode ⇒ String
Sets which mode of auditing should be used for the cluster's workloads.
Corresponds to the JSON property auditMode
11118 11119 11120 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11118 def audit_mode @audit_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11125 11126 11127 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11125 def update!(**args) @audit_mode = args[:audit_mode] if args.key?(:audit_mode) end |