Class: Google::Apis::ContainerV1beta1::AddonsConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::AddonsConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
Configuration for the addons that can be automatically spun up in the cluster, enabling additional functionality.
Instance Attribute Summary collapse
-
#agent_sandbox_config ⇒ Google::Apis::ContainerV1beta1::AgentSandboxConfig
Configuration for the AgentSandbox addon.
-
#cloud_run_config ⇒ Google::Apis::ContainerV1beta1::CloudRunConfig
Configuration options for the Cloud Run feature.
-
#config_connector_config ⇒ Google::Apis::ContainerV1beta1::ConfigConnectorConfig
Configuration options for the Config Connector add-on.
-
#dns_cache_config ⇒ Google::Apis::ContainerV1beta1::DnsCacheConfig
Configuration for NodeLocal DNSCache Corresponds to the JSON property
dnsCacheConfig. -
#gce_persistent_disk_csi_driver_config ⇒ Google::Apis::ContainerV1beta1::GcePersistentDiskCsiDriverConfig
Configuration for the Compute Engine PD CSI driver.
-
#gcp_filestore_csi_driver_config ⇒ Google::Apis::ContainerV1beta1::GcpFilestoreCsiDriverConfig
Configuration for the Filestore CSI driver.
-
#gcs_fuse_csi_driver_config ⇒ Google::Apis::ContainerV1beta1::GcsFuseCsiDriverConfig
Configuration for the Cloud Storage Fuse CSI driver.
-
#gke_backup_agent_config ⇒ Google::Apis::ContainerV1beta1::GkeBackupAgentConfig
Configuration for the Backup for GKE Agent.
-
#high_scale_checkpointing_config ⇒ Google::Apis::ContainerV1beta1::HighScaleCheckpointingConfig
Configuration for the High Scale Checkpointing.
-
#horizontal_pod_autoscaling ⇒ Google::Apis::ContainerV1beta1::HorizontalPodAutoscaling
Configuration options for the horizontal pod autoscaling feature, which increases or decreases the number of replica pods a replication controller has based on the resource usage of the existing pods.
-
#http_load_balancing ⇒ Google::Apis::ContainerV1beta1::HttpLoadBalancing
Configuration options for the HTTP (L7) load balancing controller addon, which makes it easy to set up HTTP load balancers for services in a cluster.
-
#istio_config ⇒ Google::Apis::ContainerV1beta1::IstioConfig
Configuration options for Istio addon.
-
#kalm_config ⇒ Google::Apis::ContainerV1beta1::KalmConfig
Configuration options for the KALM addon.
-
#kubernetes_dashboard ⇒ Google::Apis::ContainerV1beta1::KubernetesDashboard
Configuration for the Kubernetes Dashboard.
-
#lustre_csi_driver_config ⇒ Google::Apis::ContainerV1beta1::LustreCsiDriverConfig
Configuration for the Lustre CSI driver.
-
#network_policy_config ⇒ Google::Apis::ContainerV1beta1::NetworkPolicyConfig
Configuration for NetworkPolicy.
-
#node_readiness_config ⇒ Google::Apis::ContainerV1beta1::NodeReadinessConfig
Configuration for the GKE Node Readiness Controller.
-
#parallelstore_csi_driver_config ⇒ Google::Apis::ContainerV1beta1::ParallelstoreCsiDriverConfig
Configuration for the Cloud Storage Parallelstore CSI driver.
-
#pod_snapshot_config ⇒ Google::Apis::ContainerV1beta1::PodSnapshotConfig
PodSnapshotConfig is the configuration for GKE Pod Snapshots feature.
-
#ray_operator_config ⇒ Google::Apis::ContainerV1beta1::RayOperatorConfig
Configuration options for the Ray Operator add-on.
-
#slice_controller_config ⇒ Google::Apis::ContainerV1beta1::SliceControllerConfig
Configuration for the Slice Controller.
-
#slurm_operator_config ⇒ Google::Apis::ContainerV1beta1::SlurmOperatorConfig
Configuration for the Slurm Operator.
-
#stateful_ha_config ⇒ Google::Apis::ContainerV1beta1::StatefulHaConfig
Configuration for the Stateful HA add-on.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AddonsConfig
constructor
A new instance of AddonsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AddonsConfig
Returns a new instance of AddonsConfig.
352 353 354 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 352 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_sandbox_config ⇒ Google::Apis::ContainerV1beta1::AgentSandboxConfig
Configuration for the AgentSandbox addon.
Corresponds to the JSON property agentSandboxConfig
235 236 237 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 235 def agent_sandbox_config @agent_sandbox_config end |
#cloud_run_config ⇒ Google::Apis::ContainerV1beta1::CloudRunConfig
Configuration options for the Cloud Run feature.
Corresponds to the JSON property cloudRunConfig
240 241 242 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 240 def cloud_run_config @cloud_run_config end |
#config_connector_config ⇒ Google::Apis::ContainerV1beta1::ConfigConnectorConfig
Configuration options for the Config Connector add-on.
Corresponds to the JSON property configConnectorConfig
245 246 247 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 245 def config_connector_config @config_connector_config end |
#dns_cache_config ⇒ Google::Apis::ContainerV1beta1::DnsCacheConfig
Configuration for NodeLocal DNSCache
Corresponds to the JSON property dnsCacheConfig
250 251 252 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 250 def dns_cache_config @dns_cache_config end |
#gce_persistent_disk_csi_driver_config ⇒ Google::Apis::ContainerV1beta1::GcePersistentDiskCsiDriverConfig
Configuration for the Compute Engine PD CSI driver.
Corresponds to the JSON property gcePersistentDiskCsiDriverConfig
255 256 257 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 255 def gce_persistent_disk_csi_driver_config @gce_persistent_disk_csi_driver_config end |
#gcp_filestore_csi_driver_config ⇒ Google::Apis::ContainerV1beta1::GcpFilestoreCsiDriverConfig
Configuration for the Filestore CSI driver.
Corresponds to the JSON property gcpFilestoreCsiDriverConfig
260 261 262 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 260 def gcp_filestore_csi_driver_config @gcp_filestore_csi_driver_config end |
#gcs_fuse_csi_driver_config ⇒ Google::Apis::ContainerV1beta1::GcsFuseCsiDriverConfig
Configuration for the Cloud Storage Fuse CSI driver.
Corresponds to the JSON property gcsFuseCsiDriverConfig
265 266 267 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 265 def gcs_fuse_csi_driver_config @gcs_fuse_csi_driver_config end |
#gke_backup_agent_config ⇒ Google::Apis::ContainerV1beta1::GkeBackupAgentConfig
Configuration for the Backup for GKE Agent.
Corresponds to the JSON property gkeBackupAgentConfig
270 271 272 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 270 def gke_backup_agent_config @gke_backup_agent_config end |
#high_scale_checkpointing_config ⇒ Google::Apis::ContainerV1beta1::HighScaleCheckpointingConfig
Configuration for the High Scale Checkpointing.
Corresponds to the JSON property highScaleCheckpointingConfig
275 276 277 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 275 def high_scale_checkpointing_config @high_scale_checkpointing_config end |
#horizontal_pod_autoscaling ⇒ Google::Apis::ContainerV1beta1::HorizontalPodAutoscaling
Configuration options for the horizontal pod autoscaling feature, which
increases or decreases the number of replica pods a replication controller has
based on the resource usage of the existing pods.
Corresponds to the JSON property horizontalPodAutoscaling
282 283 284 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 282 def horizontal_pod_autoscaling @horizontal_pod_autoscaling end |
#http_load_balancing ⇒ Google::Apis::ContainerV1beta1::HttpLoadBalancing
Configuration options for the HTTP (L7) load balancing controller addon, which
makes it easy to set up HTTP load balancers for services in a cluster.
Corresponds to the JSON property httpLoadBalancing
288 289 290 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 288 def http_load_balancing @http_load_balancing end |
#istio_config ⇒ Google::Apis::ContainerV1beta1::IstioConfig
Configuration options for Istio addon.
Corresponds to the JSON property istioConfig
293 294 295 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 293 def istio_config @istio_config end |
#kalm_config ⇒ Google::Apis::ContainerV1beta1::KalmConfig
Configuration options for the KALM addon.
Corresponds to the JSON property kalmConfig
298 299 300 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 298 def kalm_config @kalm_config end |
#kubernetes_dashboard ⇒ Google::Apis::ContainerV1beta1::KubernetesDashboard
Configuration for the Kubernetes Dashboard.
Corresponds to the JSON property kubernetesDashboard
303 304 305 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 303 def kubernetes_dashboard @kubernetes_dashboard end |
#lustre_csi_driver_config ⇒ Google::Apis::ContainerV1beta1::LustreCsiDriverConfig
Configuration for the Lustre CSI driver.
Corresponds to the JSON property lustreCsiDriverConfig
308 309 310 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 308 def lustre_csi_driver_config @lustre_csi_driver_config end |
#network_policy_config ⇒ Google::Apis::ContainerV1beta1::NetworkPolicyConfig
Configuration for NetworkPolicy. This only tracks whether the addon is enabled
or not on the Master, it does not track whether network policy is enabled for
the nodes.
Corresponds to the JSON property networkPolicyConfig
315 316 317 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 315 def network_policy_config @network_policy_config end |
#node_readiness_config ⇒ Google::Apis::ContainerV1beta1::NodeReadinessConfig
Configuration for the GKE Node Readiness Controller.
Corresponds to the JSON property nodeReadinessConfig
320 321 322 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 320 def node_readiness_config @node_readiness_config end |
#parallelstore_csi_driver_config ⇒ Google::Apis::ContainerV1beta1::ParallelstoreCsiDriverConfig
Configuration for the Cloud Storage Parallelstore CSI driver.
Corresponds to the JSON property parallelstoreCsiDriverConfig
325 326 327 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 325 def parallelstore_csi_driver_config @parallelstore_csi_driver_config end |
#pod_snapshot_config ⇒ Google::Apis::ContainerV1beta1::PodSnapshotConfig
PodSnapshotConfig is the configuration for GKE Pod Snapshots feature.
Corresponds to the JSON property podSnapshotConfig
330 331 332 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 330 def pod_snapshot_config @pod_snapshot_config end |
#ray_operator_config ⇒ Google::Apis::ContainerV1beta1::RayOperatorConfig
Configuration options for the Ray Operator add-on.
Corresponds to the JSON property rayOperatorConfig
335 336 337 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 335 def ray_operator_config @ray_operator_config end |
#slice_controller_config ⇒ Google::Apis::ContainerV1beta1::SliceControllerConfig
Configuration for the Slice Controller.
Corresponds to the JSON property sliceControllerConfig
340 341 342 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 340 def slice_controller_config @slice_controller_config end |
#slurm_operator_config ⇒ Google::Apis::ContainerV1beta1::SlurmOperatorConfig
Configuration for the Slurm Operator.
Corresponds to the JSON property slurmOperatorConfig
345 346 347 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 345 def slurm_operator_config @slurm_operator_config end |
#stateful_ha_config ⇒ Google::Apis::ContainerV1beta1::StatefulHaConfig
Configuration for the Stateful HA add-on.
Corresponds to the JSON property statefulHaConfig
350 351 352 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 350 def stateful_ha_config @stateful_ha_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 357 def update!(**args) @agent_sandbox_config = args[:agent_sandbox_config] if args.key?(:agent_sandbox_config) @cloud_run_config = args[:cloud_run_config] if args.key?(:cloud_run_config) @config_connector_config = args[:config_connector_config] if args.key?(:config_connector_config) @dns_cache_config = args[:dns_cache_config] if args.key?(:dns_cache_config) @gce_persistent_disk_csi_driver_config = args[:gce_persistent_disk_csi_driver_config] if args.key?(:gce_persistent_disk_csi_driver_config) @gcp_filestore_csi_driver_config = args[:gcp_filestore_csi_driver_config] if args.key?(:gcp_filestore_csi_driver_config) @gcs_fuse_csi_driver_config = args[:gcs_fuse_csi_driver_config] if args.key?(:gcs_fuse_csi_driver_config) @gke_backup_agent_config = args[:gke_backup_agent_config] if args.key?(:gke_backup_agent_config) @high_scale_checkpointing_config = args[:high_scale_checkpointing_config] if args.key?(:high_scale_checkpointing_config) @horizontal_pod_autoscaling = args[:horizontal_pod_autoscaling] if args.key?(:horizontal_pod_autoscaling) @http_load_balancing = args[:http_load_balancing] if args.key?(:http_load_balancing) @istio_config = args[:istio_config] if args.key?(:istio_config) @kalm_config = args[:kalm_config] if args.key?(:kalm_config) @kubernetes_dashboard = args[:kubernetes_dashboard] if args.key?(:kubernetes_dashboard) @lustre_csi_driver_config = args[:lustre_csi_driver_config] if args.key?(:lustre_csi_driver_config) @network_policy_config = args[:network_policy_config] if args.key?(:network_policy_config) @node_readiness_config = args[:node_readiness_config] if args.key?(:node_readiness_config) @parallelstore_csi_driver_config = args[:parallelstore_csi_driver_config] if args.key?(:parallelstore_csi_driver_config) @pod_snapshot_config = args[:pod_snapshot_config] if args.key?(:pod_snapshot_config) @ray_operator_config = args[:ray_operator_config] if args.key?(:ray_operator_config) @slice_controller_config = args[:slice_controller_config] if args.key?(:slice_controller_config) @slurm_operator_config = args[:slurm_operator_config] if args.key?(:slurm_operator_config) @stateful_ha_config = args[:stateful_ha_config] if args.key?(:stateful_ha_config) end |