Class: Google::Apis::ContainerV1beta1::AddonsConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::AddonsConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
Configuration for the addons that can be automatically spun up in the cluster, enabling additional functionality.
Instance Attribute Summary collapse
-
#cloud_run_config ⇒ Google::Apis::ContainerV1beta1::CloudRunConfig
Configuration options for the Cloud Run feature.
-
#config_connector_config ⇒ Google::Apis::ContainerV1beta1::ConfigConnectorConfig
Configuration options for the Config Connector add-on.
-
#dns_cache_config ⇒ Google::Apis::ContainerV1beta1::DnsCacheConfig
Configuration for NodeLocal DNSCache Corresponds to the JSON property
dnsCacheConfig. -
#gce_persistent_disk_csi_driver_config ⇒ Google::Apis::ContainerV1beta1::GcePersistentDiskCsiDriverConfig
Configuration for the Compute Engine PD CSI driver.
-
#gcp_filestore_csi_driver_config ⇒ Google::Apis::ContainerV1beta1::GcpFilestoreCsiDriverConfig
Configuration for the Filestore CSI driver.
-
#gcs_fuse_csi_driver_config ⇒ Google::Apis::ContainerV1beta1::GcsFuseCsiDriverConfig
Configuration for the Cloud Storage Fuse CSI driver.
-
#gke_backup_agent_config ⇒ Google::Apis::ContainerV1beta1::GkeBackupAgentConfig
Configuration for the Backup for GKE Agent.
-
#high_scale_checkpointing_config ⇒ Google::Apis::ContainerV1beta1::HighScaleCheckpointingConfig
Configuration for the High Scale Checkpointing.
-
#horizontal_pod_autoscaling ⇒ Google::Apis::ContainerV1beta1::HorizontalPodAutoscaling
Configuration options for the horizontal pod autoscaling feature, which increases or decreases the number of replica pods a replication controller has based on the resource usage of the existing pods.
-
#http_load_balancing ⇒ Google::Apis::ContainerV1beta1::HttpLoadBalancing
Configuration options for the HTTP (L7) load balancing controller addon, which makes it easy to set up HTTP load balancers for services in a cluster.
-
#istio_config ⇒ Google::Apis::ContainerV1beta1::IstioConfig
Configuration options for Istio addon.
-
#kalm_config ⇒ Google::Apis::ContainerV1beta1::KalmConfig
Configuration options for the KALM addon.
-
#kubernetes_dashboard ⇒ Google::Apis::ContainerV1beta1::KubernetesDashboard
Configuration for the Kubernetes Dashboard.
-
#lustre_csi_driver_config ⇒ Google::Apis::ContainerV1beta1::LustreCsiDriverConfig
Configuration for the Lustre CSI driver.
-
#network_policy_config ⇒ Google::Apis::ContainerV1beta1::NetworkPolicyConfig
Configuration for NetworkPolicy.
-
#parallelstore_csi_driver_config ⇒ Google::Apis::ContainerV1beta1::ParallelstoreCsiDriverConfig
Configuration for the Cloud Storage Parallelstore CSI driver.
-
#pod_snapshot_config ⇒ Google::Apis::ContainerV1beta1::PodSnapshotConfig
PodSnapshotConfig is the configuration for GKE Pod Snapshots feature.
-
#ray_operator_config ⇒ Google::Apis::ContainerV1beta1::RayOperatorConfig
Configuration options for the Ray Operator add-on.
-
#slice_controller_config ⇒ Google::Apis::ContainerV1beta1::SliceControllerConfig
Configuration for the Slice Controller.
-
#stateful_ha_config ⇒ Google::Apis::ContainerV1beta1::StatefulHaConfig
Configuration for the Stateful HA add-on.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AddonsConfig
constructor
A new instance of AddonsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AddonsConfig
Returns a new instance of AddonsConfig.
316 317 318 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 316 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_run_config ⇒ Google::Apis::ContainerV1beta1::CloudRunConfig
Configuration options for the Cloud Run feature.
Corresponds to the JSON property cloudRunConfig
214 215 216 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 214 def cloud_run_config @cloud_run_config end |
#config_connector_config ⇒ Google::Apis::ContainerV1beta1::ConfigConnectorConfig
Configuration options for the Config Connector add-on.
Corresponds to the JSON property configConnectorConfig
219 220 221 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 219 def config_connector_config @config_connector_config end |
#dns_cache_config ⇒ Google::Apis::ContainerV1beta1::DnsCacheConfig
Configuration for NodeLocal DNSCache
Corresponds to the JSON property dnsCacheConfig
224 225 226 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 224 def dns_cache_config @dns_cache_config end |
#gce_persistent_disk_csi_driver_config ⇒ Google::Apis::ContainerV1beta1::GcePersistentDiskCsiDriverConfig
Configuration for the Compute Engine PD CSI driver.
Corresponds to the JSON property gcePersistentDiskCsiDriverConfig
229 230 231 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 229 def gce_persistent_disk_csi_driver_config @gce_persistent_disk_csi_driver_config end |
#gcp_filestore_csi_driver_config ⇒ Google::Apis::ContainerV1beta1::GcpFilestoreCsiDriverConfig
Configuration for the Filestore CSI driver.
Corresponds to the JSON property gcpFilestoreCsiDriverConfig
234 235 236 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 234 def gcp_filestore_csi_driver_config @gcp_filestore_csi_driver_config end |
#gcs_fuse_csi_driver_config ⇒ Google::Apis::ContainerV1beta1::GcsFuseCsiDriverConfig
Configuration for the Cloud Storage Fuse CSI driver.
Corresponds to the JSON property gcsFuseCsiDriverConfig
239 240 241 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 239 def gcs_fuse_csi_driver_config @gcs_fuse_csi_driver_config end |
#gke_backup_agent_config ⇒ Google::Apis::ContainerV1beta1::GkeBackupAgentConfig
Configuration for the Backup for GKE Agent.
Corresponds to the JSON property gkeBackupAgentConfig
244 245 246 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 244 def gke_backup_agent_config @gke_backup_agent_config end |
#high_scale_checkpointing_config ⇒ Google::Apis::ContainerV1beta1::HighScaleCheckpointingConfig
Configuration for the High Scale Checkpointing.
Corresponds to the JSON property highScaleCheckpointingConfig
249 250 251 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 249 def high_scale_checkpointing_config @high_scale_checkpointing_config end |
#horizontal_pod_autoscaling ⇒ Google::Apis::ContainerV1beta1::HorizontalPodAutoscaling
Configuration options for the horizontal pod autoscaling feature, which
increases or decreases the number of replica pods a replication controller has
based on the resource usage of the existing pods.
Corresponds to the JSON property horizontalPodAutoscaling
256 257 258 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 256 def horizontal_pod_autoscaling @horizontal_pod_autoscaling end |
#http_load_balancing ⇒ Google::Apis::ContainerV1beta1::HttpLoadBalancing
Configuration options for the HTTP (L7) load balancing controller addon, which
makes it easy to set up HTTP load balancers for services in a cluster.
Corresponds to the JSON property httpLoadBalancing
262 263 264 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 262 def http_load_balancing @http_load_balancing end |
#istio_config ⇒ Google::Apis::ContainerV1beta1::IstioConfig
Configuration options for Istio addon.
Corresponds to the JSON property istioConfig
267 268 269 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 267 def istio_config @istio_config end |
#kalm_config ⇒ Google::Apis::ContainerV1beta1::KalmConfig
Configuration options for the KALM addon.
Corresponds to the JSON property kalmConfig
272 273 274 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 272 def kalm_config @kalm_config end |
#kubernetes_dashboard ⇒ Google::Apis::ContainerV1beta1::KubernetesDashboard
Configuration for the Kubernetes Dashboard.
Corresponds to the JSON property kubernetesDashboard
277 278 279 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 277 def kubernetes_dashboard @kubernetes_dashboard end |
#lustre_csi_driver_config ⇒ Google::Apis::ContainerV1beta1::LustreCsiDriverConfig
Configuration for the Lustre CSI driver.
Corresponds to the JSON property lustreCsiDriverConfig
282 283 284 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 282 def lustre_csi_driver_config @lustre_csi_driver_config end |
#network_policy_config ⇒ Google::Apis::ContainerV1beta1::NetworkPolicyConfig
Configuration for NetworkPolicy. This only tracks whether the addon is enabled
or not on the Master, it does not track whether network policy is enabled for
the nodes.
Corresponds to the JSON property networkPolicyConfig
289 290 291 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 289 def network_policy_config @network_policy_config end |
#parallelstore_csi_driver_config ⇒ Google::Apis::ContainerV1beta1::ParallelstoreCsiDriverConfig
Configuration for the Cloud Storage Parallelstore CSI driver.
Corresponds to the JSON property parallelstoreCsiDriverConfig
294 295 296 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 294 def parallelstore_csi_driver_config @parallelstore_csi_driver_config end |
#pod_snapshot_config ⇒ Google::Apis::ContainerV1beta1::PodSnapshotConfig
PodSnapshotConfig is the configuration for GKE Pod Snapshots feature.
Corresponds to the JSON property podSnapshotConfig
299 300 301 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 299 def pod_snapshot_config @pod_snapshot_config end |
#ray_operator_config ⇒ Google::Apis::ContainerV1beta1::RayOperatorConfig
Configuration options for the Ray Operator add-on.
Corresponds to the JSON property rayOperatorConfig
304 305 306 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 304 def ray_operator_config @ray_operator_config end |
#slice_controller_config ⇒ Google::Apis::ContainerV1beta1::SliceControllerConfig
Configuration for the Slice Controller.
Corresponds to the JSON property sliceControllerConfig
309 310 311 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 309 def slice_controller_config @slice_controller_config end |
#stateful_ha_config ⇒ Google::Apis::ContainerV1beta1::StatefulHaConfig
Configuration for the Stateful HA add-on.
Corresponds to the JSON property statefulHaConfig
314 315 316 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 314 def stateful_ha_config @stateful_ha_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 321 def update!(**args) @cloud_run_config = args[:cloud_run_config] if args.key?(:cloud_run_config) @config_connector_config = args[:config_connector_config] if args.key?(:config_connector_config) @dns_cache_config = args[:dns_cache_config] if args.key?(:dns_cache_config) @gce_persistent_disk_csi_driver_config = args[:gce_persistent_disk_csi_driver_config] if args.key?(:gce_persistent_disk_csi_driver_config) @gcp_filestore_csi_driver_config = args[:gcp_filestore_csi_driver_config] if args.key?(:gcp_filestore_csi_driver_config) @gcs_fuse_csi_driver_config = args[:gcs_fuse_csi_driver_config] if args.key?(:gcs_fuse_csi_driver_config) @gke_backup_agent_config = args[:gke_backup_agent_config] if args.key?(:gke_backup_agent_config) @high_scale_checkpointing_config = args[:high_scale_checkpointing_config] if args.key?(:high_scale_checkpointing_config) @horizontal_pod_autoscaling = args[:horizontal_pod_autoscaling] if args.key?(:horizontal_pod_autoscaling) @http_load_balancing = args[:http_load_balancing] if args.key?(:http_load_balancing) @istio_config = args[:istio_config] if args.key?(:istio_config) @kalm_config = args[:kalm_config] if args.key?(:kalm_config) @kubernetes_dashboard = args[:kubernetes_dashboard] if args.key?(:kubernetes_dashboard) @lustre_csi_driver_config = args[:lustre_csi_driver_config] if args.key?(:lustre_csi_driver_config) @network_policy_config = args[:network_policy_config] if args.key?(:network_policy_config) @parallelstore_csi_driver_config = args[:parallelstore_csi_driver_config] if args.key?(:parallelstore_csi_driver_config) @pod_snapshot_config = args[:pod_snapshot_config] if args.key?(:pod_snapshot_config) @ray_operator_config = args[:ray_operator_config] if args.key?(:ray_operator_config) @slice_controller_config = args[:slice_controller_config] if args.key?(:slice_controller_config) @stateful_ha_config = args[:stateful_ha_config] if args.key?(:stateful_ha_config) end |