Class: Google::Apis::ContainerV1beta1::BootDiskProfile

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Swap on the node's boot disk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BootDiskProfile

Returns a new instance of BootDiskProfile.



1044
1045
1046
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#swap_size_gibFixnum

Specifies the size of the swap space in gibibytes (GiB). Corresponds to the JSON property swapSizeGib

Returns:

  • (Fixnum)


1037
1038
1039
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1037

def swap_size_gib
  @swap_size_gib
end

#swap_size_percentFixnum

Specifies the size of the swap space as a percentage of the boot disk size. Corresponds to the JSON property swapSizePercent

Returns:

  • (Fixnum)


1042
1043
1044
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1042

def swap_size_percent
  @swap_size_percent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1049
1050
1051
1052
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1049

def update!(**args)
  @swap_size_gib = args[:swap_size_gib] if args.key?(:swap_size_gib)
  @swap_size_percent = args[:swap_size_percent] if args.key?(:swap_size_percent)
end