Class: Google::Apis::ContainerV1beta1::CancelOperationRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::CancelOperationRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
CancelOperationRequest cancels a single operation.
Instance Attribute Summary collapse
-
#name ⇒ String
The name (project, location, operation id) of the operation to cancel.
-
#operation_id ⇒ String
Deprecated.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CancelOperationRequest
constructor
A new instance of CancelOperationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CancelOperationRequest
Returns a new instance of CancelOperationRequest.
1097 1098 1099 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1097 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The name (project, location, operation id) of the operation to cancel.
Specified in the format projects/*/locations/*/operations/*.
Corresponds to the JSON property name
1075 1076 1077 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1075 def name @name end |
#operation_id ⇒ String
Deprecated. The server-assigned name of the operation. This field has been
deprecated and replaced by the name field.
Corresponds to the JSON property operationId
1081 1082 1083 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1081 def operation_id @operation_id end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
1088 1089 1090 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1088 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the operation resides. This field
has been deprecated and replaced by the name field.
Corresponds to the JSON property zone
1095 1096 1097 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1095 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1102 1103 1104 1105 1106 1107 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1102 def update!(**args) @name = args[:name] if args.key?(:name) @operation_id = args[:operation_id] if args.key?(:operation_id) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |