Class: Google::Apis::ContainerV1beta1::CertificateConfigPair

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

CertificateConfigPair configures pairs of certificates, which is used for client certificate and key pairs under a registry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CertificateConfigPair

Returns a new instance of CertificateConfigPair.



1176
1177
1178
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1176

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certGoogle::Apis::ContainerV1beta1::CertificateConfig

CertificateConfig configures certificate for the registry. Corresponds to the JSON property cert



1169
1170
1171
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1169

def cert
  @cert
end

#keyGoogle::Apis::ContainerV1beta1::CertificateConfig

CertificateConfig configures certificate for the registry. Corresponds to the JSON property key



1174
1175
1176
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1174

def key
  @key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1181
1182
1183
1184
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1181

def update!(**args)
  @cert = args[:cert] if args.key?(:cert)
  @key = args[:key] if args.key?(:key)
end