Class: Google::Apis::ContainerV1beta1::Cluster
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::Cluster
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
A Google Kubernetes Engine cluster.
Instance Attribute Summary collapse
-
#addons_config ⇒ Google::Apis::ContainerV1beta1::AddonsConfig
Configuration for the addons that can be automatically spun up in the cluster, enabling additional functionality.
-
#alpha_cluster_feature_gates ⇒ Array<String>
The list of user specified Kubernetes feature gates.
-
#anonymous_authentication_config ⇒ Google::Apis::ContainerV1beta1::AnonymousAuthenticationConfig
AnonymousAuthenticationConfig defines the settings needed to limit endpoints that allow anonymous authentication.
-
#authenticator_groups_config ⇒ Google::Apis::ContainerV1beta1::AuthenticatorGroupsConfig
Configuration for returning group information from authenticators.
-
#autopilot ⇒ Google::Apis::ContainerV1beta1::Autopilot
Autopilot is the configuration for Autopilot settings on the cluster.
-
#autoscaling ⇒ Google::Apis::ContainerV1beta1::ClusterAutoscaling
ClusterAutoscaling contains global, per-cluster information required by Cluster Autoscaler to automatically adjust the size of the cluster and create/ delete node pools based on the current needs.
-
#binary_authorization ⇒ Google::Apis::ContainerV1beta1::BinaryAuthorization
Configuration for Binary Authorization.
-
#cluster_ipv4_cidr ⇒ String
The IP address range of the container pods in this cluster, in CIDR notation (e.g.
10.96.0. 0/14). -
#cluster_telemetry ⇒ Google::Apis::ContainerV1beta1::ClusterTelemetry
Telemetry integration for the cluster.
-
#compliance_posture_config ⇒ Google::Apis::ContainerV1beta1::CompliancePostureConfig
Deprecated: Compliance Posture is no longer supported.
-
#conditions ⇒ Array<Google::Apis::ContainerV1beta1::StatusCondition>
Which conditions caused the current cluster state.
-
#confidential_nodes ⇒ Google::Apis::ContainerV1beta1::ConfidentialNodes
ConfidentialNodes is configuration for the confidential nodes feature, which makes nodes run on confidential VMs.
-
#control_plane_endpoints_config ⇒ Google::Apis::ContainerV1beta1::ControlPlaneEndpointsConfig
Configuration for all of the cluster's control plane endpoints.
-
#cost_management_config ⇒ Google::Apis::ContainerV1beta1::CostManagementConfig
Configuration for fine-grained cost management feature.
-
#create_time ⇒ String
Output only.
-
#current_emulated_version ⇒ String
Output only.
-
#current_master_version ⇒ String
Output only.
-
#current_node_count ⇒ Fixnum
Output only.
-
#current_node_version ⇒ String
Output only.
-
#database_encryption ⇒ Google::Apis::ContainerV1beta1::DatabaseEncryption
Configuration of etcd encryption.
-
#default_max_pods_constraint ⇒ Google::Apis::ContainerV1beta1::MaxPodsConstraint
Constraints applied to pods.
-
#description ⇒ String
An optional description of this cluster.
-
#enable_k8s_beta_apis ⇒ Google::Apis::ContainerV1beta1::K8sBetaApiConfig
Kubernetes open source beta apis enabled on the cluster.
-
#enable_kubernetes_alpha ⇒ Boolean
(also: #enable_kubernetes_alpha?)
Kubernetes alpha features are enabled on this cluster.
-
#enable_tpu ⇒ Boolean
(also: #enable_tpu?)
Enable the ability to use Cloud TPUs in this cluster.
-
#endpoint ⇒ String
Output only.
-
#enterprise_config ⇒ Google::Apis::ContainerV1beta1::EnterpriseConfig
EnterpriseConfig is the cluster enterprise configuration.
-
#etag ⇒ String
This checksum is computed by the server based on the value of cluster fields, and may be sent on update requests to ensure the client has an up-to-date value before proceeding.
-
#expire_time ⇒ String
Output only.
-
#fleet ⇒ Google::Apis::ContainerV1beta1::Fleet
Fleet is the fleet configuration for the cluster.
-
#gke_auto_upgrade_config ⇒ Google::Apis::ContainerV1beta1::GkeAutoUpgradeConfig
GkeAutoUpgradeConfig is the configuration for GKE auto upgrades.
-
#id ⇒ String
Output only.
-
#identity_service_config ⇒ Google::Apis::ContainerV1beta1::IdentityServiceConfig
IdentityServiceConfig is configuration for Identity Service which allows customers to use external identity providers with the K8S API Corresponds to the JSON property
identityServiceConfig. -
#initial_cluster_version ⇒ String
The initial Kubernetes version for this cluster.
-
#initial_node_count ⇒ Fixnum
The number of nodes to create in this cluster.
-
#instance_group_urls ⇒ Array<String>
Output only.
-
#ip_allocation_policy ⇒ Google::Apis::ContainerV1beta1::IpAllocationPolicy
Configuration for controlling how IPs are allocated in the cluster.
-
#label_fingerprint ⇒ String
The fingerprint of the set of labels for this cluster.
-
#legacy_abac ⇒ Google::Apis::ContainerV1beta1::LegacyAbac
Configuration for the legacy Attribute Based Access Control authorization mode.
-
#location ⇒ String
Output only.
-
#locations ⇒ Array<String>
The list of Google Compute Engine zones in which the cluster's nodes should be located.
-
#logging_config ⇒ Google::Apis::ContainerV1beta1::LoggingConfig
LoggingConfig is cluster logging configuration.
-
#logging_service ⇒ String
The logging service the cluster should use to write logs.
-
#maintenance_policy ⇒ Google::Apis::ContainerV1beta1::MaintenancePolicy
MaintenancePolicy defines the maintenance policy to be used for the cluster.
-
#managed_opentelemetry_config ⇒ Google::Apis::ContainerV1beta1::ManagedOpenTelemetryConfig
ManagedOpenTelemetryConfig is the configuration for the GKE Managed OpenTelemetry pipeline.
-
#master ⇒ Google::Apis::ContainerV1beta1::Master
Master is the configuration for components on master.
-
#master_auth ⇒ Google::Apis::ContainerV1beta1::MasterAuth
The authentication information for accessing the master endpoint.
-
#master_authorized_networks_config ⇒ Google::Apis::ContainerV1beta1::MasterAuthorizedNetworksConfig
Configuration options for the master authorized networks feature.
-
#master_ipv4_cidr_block ⇒ String
The IP prefix in CIDR notation to use for the hosted master network.
-
#mesh_certificates ⇒ Google::Apis::ContainerV1beta1::MeshCertificates
Configuration for issuance of mTLS keys and certificates to Kubernetes pods.
-
#monitoring_config ⇒ Google::Apis::ContainerV1beta1::MonitoringConfig
MonitoringConfig is cluster monitoring configuration.
-
#monitoring_service ⇒ String
The monitoring service the cluster should use to write metrics.
-
#name ⇒ String
The name of this cluster.
-
#network ⇒ String
The name of the Google Compute Engine network to which the cluster is connected.
-
#network_config ⇒ Google::Apis::ContainerV1beta1::NetworkConfig
NetworkConfig reports the relative names of network & subnetwork.
-
#network_policy ⇒ Google::Apis::ContainerV1beta1::NetworkPolicy
Configuration options for the NetworkPolicy feature.
-
#node_config ⇒ Google::Apis::ContainerV1beta1::NodeConfig
Parameters that describe the nodes in a cluster.
-
#node_ipv4_cidr_size ⇒ Fixnum
Output only.
-
#node_pool_auto_config ⇒ Google::Apis::ContainerV1beta1::NodePoolAutoConfig
node pool configs that apply to all auto-provisioned node pools in autopilot clusters and node auto-provisioning enabled clusters Corresponds to the JSON property
nodePoolAutoConfig. -
#node_pool_defaults ⇒ Google::Apis::ContainerV1beta1::NodePoolDefaults
Subset of Nodepool message that has defaults.
-
#node_pools ⇒ Array<Google::Apis::ContainerV1beta1::NodePool>
The node pools associated with this cluster.
-
#notification_config ⇒ Google::Apis::ContainerV1beta1::NotificationConfig
NotificationConfig is the configuration of notifications.
-
#parent_product_config ⇒ Google::Apis::ContainerV1beta1::ParentProductConfig
ParentProductConfig is the configuration of the parent product of the cluster.
-
#pod_autoscaling ⇒ Google::Apis::ContainerV1beta1::PodAutoscaling
PodAutoscaling is used for configuration of parameters for workload autoscaling.
-
#pod_security_policy_config ⇒ Google::Apis::ContainerV1beta1::PodSecurityPolicyConfig
Configuration for the PodSecurityPolicy feature.
-
#private_cluster ⇒ Boolean
(also: #private_cluster?)
If this is a private cluster setup.
-
#private_cluster_config ⇒ Google::Apis::ContainerV1beta1::PrivateClusterConfig
Configuration options for private clusters.
-
#protect_config ⇒ Google::Apis::ContainerV1beta1::ProtectConfig
ProtectConfig defines the flags needed to enable/disable features for the Protect API.
-
#rbac_binding_config ⇒ Google::Apis::ContainerV1beta1::RbacBindingConfig
RBACBindingConfig allows user to restrict ClusterRoleBindings an RoleBindings that can be created.
-
#release_channel ⇒ Google::Apis::ContainerV1beta1::ReleaseChannel
ReleaseChannel indicates which release channel a cluster is subscribed to.
-
#resource_labels ⇒ Hash<String,String>
The resource labels for the cluster to use to annotate any related Google Compute Engine resources.
-
#resource_usage_export_config ⇒ Google::Apis::ContainerV1beta1::ResourceUsageExportConfig
Configuration for exporting cluster resource usages.
-
#rollback_safe_upgrade ⇒ Google::Apis::ContainerV1beta1::RollbackSafeUpgrade
RollbackSafeUpgrade is the configuration for the rollback safe upgrade.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#secret_manager_config ⇒ Google::Apis::ContainerV1beta1::SecretManagerConfig
SecretManagerConfig is config for secret manager enablement.
-
#secret_sync_config ⇒ Google::Apis::ContainerV1beta1::SecretSyncConfig
Configuration for sync Secret Manager secrets as k8s secrets.
-
#security_posture_config ⇒ Google::Apis::ContainerV1beta1::SecurityPostureConfig
SecurityPostureConfig defines the flags needed to enable/disable features for the Security Posture API.
-
#self_link ⇒ String
Output only.
-
#services_ipv4_cidr ⇒ String
Output only.
-
#shielded_nodes ⇒ Google::Apis::ContainerV1beta1::ShieldedNodes
Configuration of Shielded Nodes feature.
-
#status ⇒ String
Output only.
-
#status_message ⇒ String
Output only.
-
#subnetwork ⇒ String
The name of the Google Compute Engine subnetwork to which the cluster is connected.
-
#tpu_config ⇒ Google::Apis::ContainerV1beta1::TpuConfig
Configuration for Cloud TPU.
-
#tpu_ipv4_cidr_block ⇒ String
Output only.
-
#user_managed_keys_config ⇒ Google::Apis::ContainerV1beta1::UserManagedKeysConfig
UserManagedKeysConfig holds the resource address to Keys which are used for signing certs and token that are used for communication within cluster.
-
#vertical_pod_autoscaling ⇒ Google::Apis::ContainerV1beta1::VerticalPodAutoscaling
VerticalPodAutoscaling contains global, per-cluster information required by Vertical Pod Autoscaler to automatically adjust the resources of pods controlled by it.
-
#workload_alts_config ⇒ Google::Apis::ContainerV1beta1::WorkloadAltsConfig
Configuration for direct-path (via ALTS) with workload identity.
-
#workload_certificates ⇒ Google::Apis::ContainerV1beta1::WorkloadCertificates
Configuration for issuance of mTLS keys and certificates to Kubernetes pods.
-
#workload_identity_config ⇒ Google::Apis::ContainerV1beta1::WorkloadIdentityConfig
Configuration for the use of Kubernetes Service Accounts in IAM policies.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Cluster
constructor
A new instance of Cluster.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Cluster
Returns a new instance of Cluster.
1876 1877 1878 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1876 def initialize(**args) update!(**args) end |
Instance Attribute Details
#addons_config ⇒ Google::Apis::ContainerV1beta1::AddonsConfig
Configuration for the addons that can be automatically spun up in the cluster,
enabling additional functionality.
Corresponds to the JSON property addonsConfig
1291 1292 1293 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1291 def addons_config @addons_config end |
#alpha_cluster_feature_gates ⇒ Array<String>
The list of user specified Kubernetes feature gates. Each string represents
the activation status of a feature gate (e.g. "featureX=true" or "featureX=
false")
Corresponds to the JSON property alphaClusterFeatureGates
1298 1299 1300 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1298 def alpha_cluster_feature_gates @alpha_cluster_feature_gates end |
#anonymous_authentication_config ⇒ Google::Apis::ContainerV1beta1::AnonymousAuthenticationConfig
AnonymousAuthenticationConfig defines the settings needed to limit endpoints
that allow anonymous authentication.
Corresponds to the JSON property anonymousAuthenticationConfig
1304 1305 1306 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1304 def anonymous_authentication_config @anonymous_authentication_config end |
#authenticator_groups_config ⇒ Google::Apis::ContainerV1beta1::AuthenticatorGroupsConfig
Configuration for returning group information from authenticators.
Corresponds to the JSON property authenticatorGroupsConfig
1309 1310 1311 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1309 def authenticator_groups_config @authenticator_groups_config end |
#autopilot ⇒ Google::Apis::ContainerV1beta1::Autopilot
Autopilot is the configuration for Autopilot settings on the cluster.
Corresponds to the JSON property autopilot
1314 1315 1316 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1314 def autopilot @autopilot end |
#autoscaling ⇒ Google::Apis::ContainerV1beta1::ClusterAutoscaling
ClusterAutoscaling contains global, per-cluster information required by
Cluster Autoscaler to automatically adjust the size of the cluster and create/
delete node pools based on the current needs.
Corresponds to the JSON property autoscaling
1321 1322 1323 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1321 def autoscaling @autoscaling end |
#binary_authorization ⇒ Google::Apis::ContainerV1beta1::BinaryAuthorization
Configuration for Binary Authorization.
Corresponds to the JSON property binaryAuthorization
1326 1327 1328 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1326 def @binary_authorization end |
#cluster_ipv4_cidr ⇒ String
The IP address range of the container pods in this cluster, in CIDR notation (e.g. 10.96.0.
0/14). Leave blank to have one automatically chosen or specify a /14 block
in 10.0.0.0/8.
Corresponds to the JSON property clusterIpv4Cidr
1334 1335 1336 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1334 def cluster_ipv4_cidr @cluster_ipv4_cidr end |
#cluster_telemetry ⇒ Google::Apis::ContainerV1beta1::ClusterTelemetry
Telemetry integration for the cluster.
Corresponds to the JSON property clusterTelemetry
1339 1340 1341 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1339 def cluster_telemetry @cluster_telemetry end |
#compliance_posture_config ⇒ Google::Apis::ContainerV1beta1::CompliancePostureConfig
Deprecated: Compliance Posture is no longer supported. For more details, see
https://cloud.google.com/kubernetes-engine/docs/deprecations/posture-
management-deprecation. CompliancePostureConfig defines the settings needed to
enable/disable features for the Compliance Posture.
Corresponds to the JSON property compliancePostureConfig
1347 1348 1349 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1347 def compliance_posture_config @compliance_posture_config end |
#conditions ⇒ Array<Google::Apis::ContainerV1beta1::StatusCondition>
Which conditions caused the current cluster state.
Corresponds to the JSON property conditions
1352 1353 1354 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1352 def conditions @conditions end |
#confidential_nodes ⇒ Google::Apis::ContainerV1beta1::ConfidentialNodes
ConfidentialNodes is configuration for the confidential nodes feature, which
makes nodes run on confidential VMs.
Corresponds to the JSON property confidentialNodes
1358 1359 1360 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1358 def confidential_nodes @confidential_nodes end |
#control_plane_endpoints_config ⇒ Google::Apis::ContainerV1beta1::ControlPlaneEndpointsConfig
Configuration for all of the cluster's control plane endpoints.
Corresponds to the JSON property controlPlaneEndpointsConfig
1363 1364 1365 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1363 def control_plane_endpoints_config @control_plane_endpoints_config end |
#cost_management_config ⇒ Google::Apis::ContainerV1beta1::CostManagementConfig
Configuration for fine-grained cost management feature.
Corresponds to the JSON property costManagementConfig
1368 1369 1370 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1368 def cost_management_config @cost_management_config end |
#create_time ⇒ String
Output only. The time the cluster was created, in RFC3339 text format.
Corresponds to the JSON property createTime
1374 1375 1376 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1374 def create_time @create_time end |
#current_emulated_version ⇒ String
Output only. The current emulated version of the master endpoint. The version
is in minor version format, e.g. 1.30. No value or empty string means the
cluster has no emulated version.
Corresponds to the JSON property currentEmulatedVersion
1381 1382 1383 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1381 def current_emulated_version @current_emulated_version end |
#current_master_version ⇒ String
Output only. The current software version of the master endpoint.
Corresponds to the JSON property currentMasterVersion
1386 1387 1388 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1386 def current_master_version @current_master_version end |
#current_node_count ⇒ Fixnum
Output only. The number of nodes currently in the cluster. Deprecated. Call
Kubernetes API directly to retrieve node information.
Corresponds to the JSON property currentNodeCount
1392 1393 1394 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1392 def current_node_count @current_node_count end |
#current_node_version ⇒ String
Output only. Deprecated, use NodePool.version instead. The current version of the node software components. If
they are currently at multiple versions because they're in the process of
being upgraded, this reflects the minimum version of all nodes.
Corresponds to the JSON property currentNodeVersion
1401 1402 1403 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1401 def current_node_version @current_node_version end |
#database_encryption ⇒ Google::Apis::ContainerV1beta1::DatabaseEncryption
Configuration of etcd encryption.
Corresponds to the JSON property databaseEncryption
1406 1407 1408 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1406 def database_encryption @database_encryption end |
#default_max_pods_constraint ⇒ Google::Apis::ContainerV1beta1::MaxPodsConstraint
Constraints applied to pods.
Corresponds to the JSON property defaultMaxPodsConstraint
1411 1412 1413 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1411 def default_max_pods_constraint @default_max_pods_constraint end |
#description ⇒ String
An optional description of this cluster.
Corresponds to the JSON property description
1416 1417 1418 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1416 def description @description end |
#enable_k8s_beta_apis ⇒ Google::Apis::ContainerV1beta1::K8sBetaApiConfig
Kubernetes open source beta apis enabled on the cluster.
Corresponds to the JSON property enableK8sBetaApis
1421 1422 1423 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1421 def enable_k8s_beta_apis @enable_k8s_beta_apis end |
#enable_kubernetes_alpha ⇒ Boolean Also known as: enable_kubernetes_alpha?
Kubernetes alpha features are enabled on this cluster. This includes alpha API
groups (e.g. v1beta1) and features that may not be production ready in the
kubernetes version of the master and nodes. The cluster has no SLA for uptime
and master/node upgrades are disabled. Alpha enabled clusters are
automatically deleted thirty days after creation.
Corresponds to the JSON property enableKubernetesAlpha
1430 1431 1432 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1430 def enable_kubernetes_alpha @enable_kubernetes_alpha end |
#enable_tpu ⇒ Boolean Also known as: enable_tpu?
Enable the ability to use Cloud TPUs in this cluster. This field is deprecated,
use tpu_config.enabled instead. This field is deprecated due to the
deprecation of 2VM TPU. The end of life date for 2VM TPU is 2025-04-25.
Corresponds to the JSON property enableTpu
1438 1439 1440 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1438 def enable_tpu @enable_tpu end |
#endpoint ⇒ String
Output only. The IP address of this cluster's master endpoint. The endpoint
can be accessed from the internet at https://username:password@endpoint/.
See the masterAuth property of this resource for username and password
information.
Corresponds to the JSON property endpoint
1447 1448 1449 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1447 def endpoint @endpoint end |
#enterprise_config ⇒ Google::Apis::ContainerV1beta1::EnterpriseConfig
EnterpriseConfig is the cluster enterprise configuration. Deprecated: GKE
Enterprise features are now available without an Enterprise tier.
Corresponds to the JSON property enterpriseConfig
1453 1454 1455 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1453 def enterprise_config @enterprise_config end |
#etag ⇒ String
This checksum is computed by the server based on the value of cluster fields,
and may be sent on update requests to ensure the client has an up-to-date
value before proceeding.
Corresponds to the JSON property etag
1460 1461 1462 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1460 def etag @etag end |
#expire_time ⇒ String
Output only. The time the cluster will be automatically deleted in RFC3339 text format.
Corresponds to the JSON property expireTime
1466 1467 1468 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1466 def expire_time @expire_time end |
#fleet ⇒ Google::Apis::ContainerV1beta1::Fleet
Fleet is the fleet configuration for the cluster.
Corresponds to the JSON property fleet
1471 1472 1473 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1471 def fleet @fleet end |
#gke_auto_upgrade_config ⇒ Google::Apis::ContainerV1beta1::GkeAutoUpgradeConfig
GkeAutoUpgradeConfig is the configuration for GKE auto upgrades.
Corresponds to the JSON property gkeAutoUpgradeConfig
1476 1477 1478 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1476 def gke_auto_upgrade_config @gke_auto_upgrade_config end |
#id ⇒ String
Output only. Unique id for the cluster.
Corresponds to the JSON property id
1481 1482 1483 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1481 def id @id end |
#identity_service_config ⇒ Google::Apis::ContainerV1beta1::IdentityServiceConfig
IdentityServiceConfig is configuration for Identity Service which allows
customers to use external identity providers with the K8S API
Corresponds to the JSON property identityServiceConfig
1487 1488 1489 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1487 def identity_service_config @identity_service_config end |
#initial_cluster_version ⇒ String
The initial Kubernetes version for this cluster. Valid versions are those
found in validMasterVersions returned by getServerConfig. The version can be
upgraded over time; such upgrades are reflected in currentMasterVersion and
currentNodeVersion. Users may specify either explicit versions offered by
Kubernetes Engine or version aliases, which have the following behavior: - "
latest": picks the highest valid Kubernetes version - "1.X": picks the highest
valid patch+gke.N patch in the 1.X version - "1.X.Y": picks the highest valid
gke.N patch in the 1.X.Y version - "1.X.Y-gke.N": picks an explicit Kubernetes
version - "","-": picks the default Kubernetes version
Corresponds to the JSON property initialClusterVersion
1500 1501 1502 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1500 def initial_cluster_version @initial_cluster_version end |
#initial_node_count ⇒ Fixnum
The number of nodes to create in this cluster. You must ensure that your
Compute Engine resource quota is
sufficient for this number of instances. You must also have available firewall
and routes quota. For requests, this field should only be used in lieu of a "
node_pool" object, since this configuration (along with the "node_config")
will be used to create a "NodePool" object with an auto-generated name. Do not
use this and a node_pool at the same time. This field is deprecated, use
node_pool.initial_node_count instead.
Corresponds to the JSON property initialNodeCount
1512 1513 1514 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1512 def initial_node_count @initial_node_count end |
#instance_group_urls ⇒ Array<String>
Output only. Deprecated. Use node_pools.instance_group_urls.
Corresponds to the JSON property instanceGroupUrls
1517 1518 1519 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1517 def instance_group_urls @instance_group_urls end |
#ip_allocation_policy ⇒ Google::Apis::ContainerV1beta1::IpAllocationPolicy
Configuration for controlling how IPs are allocated in the cluster.
Corresponds to the JSON property ipAllocationPolicy
1522 1523 1524 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1522 def ip_allocation_policy @ip_allocation_policy end |
#label_fingerprint ⇒ String
The fingerprint of the set of labels for this cluster.
Corresponds to the JSON property labelFingerprint
1527 1528 1529 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1527 def label_fingerprint @label_fingerprint end |
#legacy_abac ⇒ Google::Apis::ContainerV1beta1::LegacyAbac
Configuration for the legacy Attribute Based Access Control authorization mode.
Corresponds to the JSON property legacyAbac
1532 1533 1534 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1532 def legacy_abac @legacy_abac end |
#location ⇒ String
1540 1541 1542 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1540 def location @location end |
#locations ⇒ Array<String>
The list of Google Compute Engine zones in which the cluster's nodes should be located. This
field provides a default value if NodePool.Locations are not specified during node pool
creation. Warning: changing cluster locations will update the NodePool.
Locations of all node
pools and will result in nodes being added and/or removed.
Corresponds to the JSON property locations
1553 1554 1555 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1553 def locations @locations end |
#logging_config ⇒ Google::Apis::ContainerV1beta1::LoggingConfig
LoggingConfig is cluster logging configuration.
Corresponds to the JSON property loggingConfig
1558 1559 1560 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1558 def logging_config @logging_config end |
#logging_service ⇒ String
The logging service the cluster should use to write logs. Currently available
options: * logging.googleapis.com/kubernetes - The Cloud Logging service
with a Kubernetes-native resource model * logging.googleapis.com - The
legacy Cloud Logging service (no longer available as of GKE 1.15). * none -
no logs will be exported from the cluster. If left as an empty string,logging.
googleapis.com/kubernetes will be used for GKE 1.14+ or logging.googleapis.
com for earlier versions.
Corresponds to the JSON property loggingService
1569 1570 1571 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1569 def logging_service @logging_service end |
#maintenance_policy ⇒ Google::Apis::ContainerV1beta1::MaintenancePolicy
MaintenancePolicy defines the maintenance policy to be used for the cluster.
Corresponds to the JSON property maintenancePolicy
1574 1575 1576 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1574 def maintenance_policy @maintenance_policy end |
#managed_opentelemetry_config ⇒ Google::Apis::ContainerV1beta1::ManagedOpenTelemetryConfig
ManagedOpenTelemetryConfig is the configuration for the GKE Managed
OpenTelemetry pipeline.
Corresponds to the JSON property managedOpentelemetryConfig
1580 1581 1582 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1580 def managed_opentelemetry_config @managed_opentelemetry_config end |
#master ⇒ Google::Apis::ContainerV1beta1::Master
Master is the configuration for components on master.
Corresponds to the JSON property master
1585 1586 1587 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1585 def master @master end |
#master_auth ⇒ Google::Apis::ContainerV1beta1::MasterAuth
The authentication information for accessing the master endpoint.
Authentication can be done using HTTP basic auth or using client certificates.
Corresponds to the JSON property masterAuth
1591 1592 1593 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1591 def master_auth @master_auth end |
#master_authorized_networks_config ⇒ Google::Apis::ContainerV1beta1::MasterAuthorizedNetworksConfig
Configuration options for the master authorized networks feature. Enabled
master authorized networks will disallow all external traffic to access
Kubernetes master through HTTPS except traffic from the given CIDR blocks,
Google Compute Engine Public IPs and Google Prod IPs.
Corresponds to the JSON property masterAuthorizedNetworksConfig
1599 1600 1601 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1599 def @master_authorized_networks_config end |
#master_ipv4_cidr_block ⇒ String
The IP prefix in CIDR notation to use for the hosted master network. This
prefix will be used for assigning private IP addresses to the master or set of
masters, as well as the ILB VIP. This field is deprecated, use
private_cluster_config.master_ipv4_cidr_block instead.
Corresponds to the JSON property masterIpv4CidrBlock
1607 1608 1609 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1607 def master_ipv4_cidr_block @master_ipv4_cidr_block end |
#mesh_certificates ⇒ Google::Apis::ContainerV1beta1::MeshCertificates
Configuration for issuance of mTLS keys and certificates to Kubernetes pods.
Corresponds to the JSON property meshCertificates
1612 1613 1614 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1612 def mesh_certificates @mesh_certificates end |
#monitoring_config ⇒ Google::Apis::ContainerV1beta1::MonitoringConfig
MonitoringConfig is cluster monitoring configuration.
Corresponds to the JSON property monitoringConfig
1617 1618 1619 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1617 def monitoring_config @monitoring_config end |
#monitoring_service ⇒ String
The monitoring service the cluster should use to write metrics. Currently
available options: * monitoring.googleapis.com/kubernetes - The Cloud
Monitoring service with a Kubernetes-native resource model * monitoring.
googleapis.com - The legacy Cloud Monitoring service (no longer available as
of GKE 1.15). * none - No metrics will be exported from the cluster. If left
as an empty string,monitoring.googleapis.com/kubernetes will be used for GKE
1.14+ or monitoring.googleapis.com for earlier versions.
Corresponds to the JSON property monitoringService
1628 1629 1630 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1628 def monitoring_service @monitoring_service end |
#name ⇒ String
The name of this cluster. The name must be unique within this project and
location (e.g. zone or region), and can be up to 40 characters with the
following restrictions: * Lowercase letters, numbers, and hyphens only. * Must
start with a letter. * Must end with a number or a letter.
Corresponds to the JSON property name
1636 1637 1638 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1636 def name @name end |
#network ⇒ String
The name of the Google Compute Engine network to which the cluster is
connected. If left unspecified, the default network will be used. On output
this shows the network ID instead of the name.
Corresponds to the JSON property network
1644 1645 1646 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1644 def network @network end |
#network_config ⇒ Google::Apis::ContainerV1beta1::NetworkConfig
NetworkConfig reports the relative names of network & subnetwork.
Corresponds to the JSON property networkConfig
1649 1650 1651 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1649 def network_config @network_config end |
#network_policy ⇒ Google::Apis::ContainerV1beta1::NetworkPolicy
Configuration options for the NetworkPolicy feature. https://kubernetes.io/
docs/concepts/services-networking/networkpolicies/
Corresponds to the JSON property networkPolicy
1655 1656 1657 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1655 def network_policy @network_policy end |
#node_config ⇒ Google::Apis::ContainerV1beta1::NodeConfig
Parameters that describe the nodes in a cluster. GKE Autopilot clusters do not
recognize parameters in NodeConfig. Use AutoprovisioningNodePoolDefaults
instead.
Corresponds to the JSON property nodeConfig
1662 1663 1664 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1662 def node_config @node_config end |
#node_ipv4_cidr_size ⇒ Fixnum
Output only. The size of the address space on each node for hosting containers.
This is provisioned from within the container_ipv4_cidr range. This field
will only be set when cluster is in route-based network mode.
Corresponds to the JSON property nodeIpv4CidrSize
1669 1670 1671 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1669 def node_ipv4_cidr_size @node_ipv4_cidr_size end |
#node_pool_auto_config ⇒ Google::Apis::ContainerV1beta1::NodePoolAutoConfig
node pool configs that apply to all auto-provisioned node pools in autopilot
clusters and node auto-provisioning enabled clusters
Corresponds to the JSON property nodePoolAutoConfig
1675 1676 1677 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1675 def node_pool_auto_config @node_pool_auto_config end |
#node_pool_defaults ⇒ Google::Apis::ContainerV1beta1::NodePoolDefaults
Subset of Nodepool message that has defaults.
Corresponds to the JSON property nodePoolDefaults
1680 1681 1682 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1680 def node_pool_defaults @node_pool_defaults end |
#node_pools ⇒ Array<Google::Apis::ContainerV1beta1::NodePool>
The node pools associated with this cluster. This field should not be set if "
node_config" or "initial_node_count" are specified.
Corresponds to the JSON property nodePools
1686 1687 1688 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1686 def node_pools @node_pools end |
#notification_config ⇒ Google::Apis::ContainerV1beta1::NotificationConfig
NotificationConfig is the configuration of notifications.
Corresponds to the JSON property notificationConfig
1691 1692 1693 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1691 def notification_config @notification_config end |
#parent_product_config ⇒ Google::Apis::ContainerV1beta1::ParentProductConfig
ParentProductConfig is the configuration of the parent product of the cluster.
This field is used by Google internal products that are built on top of a GKE
cluster and take the ownership of the cluster.
Corresponds to the JSON property parentProductConfig
1698 1699 1700 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1698 def parent_product_config @parent_product_config end |
#pod_autoscaling ⇒ Google::Apis::ContainerV1beta1::PodAutoscaling
PodAutoscaling is used for configuration of parameters for workload
autoscaling.
Corresponds to the JSON property podAutoscaling
1704 1705 1706 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1704 def pod_autoscaling @pod_autoscaling end |
#pod_security_policy_config ⇒ Google::Apis::ContainerV1beta1::PodSecurityPolicyConfig
Configuration for the PodSecurityPolicy feature.
Corresponds to the JSON property podSecurityPolicyConfig
1709 1710 1711 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1709 def pod_security_policy_config @pod_security_policy_config end |
#private_cluster ⇒ Boolean Also known as: private_cluster?
If this is a private cluster setup. Private clusters are clusters that, by
default have no external IP addresses on the nodes and where nodes and the
master communicate over private IP addresses. This field is deprecated, use
private_cluster_config.enable_private_nodes instead.
Corresponds to the JSON property privateCluster
1717 1718 1719 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1717 def private_cluster @private_cluster end |
#private_cluster_config ⇒ Google::Apis::ContainerV1beta1::PrivateClusterConfig
Configuration options for private clusters.
Corresponds to the JSON property privateClusterConfig
1723 1724 1725 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1723 def private_cluster_config @private_cluster_config end |
#protect_config ⇒ Google::Apis::ContainerV1beta1::ProtectConfig
ProtectConfig defines the flags needed to enable/disable features for the
Protect API.
Corresponds to the JSON property protectConfig
1729 1730 1731 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1729 def protect_config @protect_config end |
#rbac_binding_config ⇒ Google::Apis::ContainerV1beta1::RbacBindingConfig
RBACBindingConfig allows user to restrict ClusterRoleBindings an RoleBindings
that can be created.
Corresponds to the JSON property rbacBindingConfig
1735 1736 1737 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1735 def rbac_binding_config @rbac_binding_config end |
#release_channel ⇒ Google::Apis::ContainerV1beta1::ReleaseChannel
ReleaseChannel indicates which release channel a cluster is subscribed to.
Release channels are arranged in order of risk. When a cluster is subscribed
to a release channel, Google maintains both the master version and the node
version. Node auto-upgrade defaults to true and cannot be disabled.
Corresponds to the JSON property releaseChannel
1743 1744 1745 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1743 def release_channel @release_channel end |
#resource_labels ⇒ Hash<String,String>
The resource labels for the cluster to use to annotate any related Google
Compute Engine resources.
Corresponds to the JSON property resourceLabels
1749 1750 1751 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1749 def resource_labels @resource_labels end |
#resource_usage_export_config ⇒ Google::Apis::ContainerV1beta1::ResourceUsageExportConfig
Configuration for exporting cluster resource usages.
Corresponds to the JSON property resourceUsageExportConfig
1754 1755 1756 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1754 def resource_usage_export_config @resource_usage_export_config end |
#rollback_safe_upgrade ⇒ Google::Apis::ContainerV1beta1::RollbackSafeUpgrade
RollbackSafeUpgrade is the configuration for the rollback safe upgrade.
Corresponds to the JSON property rollbackSafeUpgrade
1759 1760 1761 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1759 def rollback_safe_upgrade @rollback_safe_upgrade end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
1764 1765 1766 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1764 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
1770 1771 1772 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1770 def satisfies_pzs @satisfies_pzs end |
#secret_manager_config ⇒ Google::Apis::ContainerV1beta1::SecretManagerConfig
SecretManagerConfig is config for secret manager enablement.
Corresponds to the JSON property secretManagerConfig
1776 1777 1778 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1776 def secret_manager_config @secret_manager_config end |
#secret_sync_config ⇒ Google::Apis::ContainerV1beta1::SecretSyncConfig
Configuration for sync Secret Manager secrets as k8s secrets.
Corresponds to the JSON property secretSyncConfig
1781 1782 1783 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1781 def secret_sync_config @secret_sync_config end |
#security_posture_config ⇒ Google::Apis::ContainerV1beta1::SecurityPostureConfig
SecurityPostureConfig defines the flags needed to enable/disable features for
the Security Posture API.
Corresponds to the JSON property securityPostureConfig
1787 1788 1789 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1787 def security_posture_config @security_posture_config end |
#self_link ⇒ String
Output only. Server-defined URL for the resource.
Corresponds to the JSON property selfLink
1792 1793 1794 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1792 def self_link @self_link end |
#services_ipv4_cidr ⇒ String
Output only. The IP address range of the Kubernetes services in this cluster,
in CIDR
notation (e.g. 1.2.3.4/29). Service addresses are typically put in the last
/16 from the container CIDR.
Corresponds to the JSON property servicesIpv4Cidr
1800 1801 1802 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1800 def services_ipv4_cidr @services_ipv4_cidr end |
#shielded_nodes ⇒ Google::Apis::ContainerV1beta1::ShieldedNodes
Configuration of Shielded Nodes feature.
Corresponds to the JSON property shieldedNodes
1805 1806 1807 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1805 def shielded_nodes @shielded_nodes end |
#status ⇒ String
Output only. The current status of this cluster.
Corresponds to the JSON property status
1810 1811 1812 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1810 def status @status end |
#status_message ⇒ String
Output only. Deprecated. Use conditions instead. Additional information about
the current status of this cluster, if available.
Corresponds to the JSON property statusMessage
1816 1817 1818 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1816 def @status_message end |
#subnetwork ⇒ String
The name of the Google Compute Engine subnetwork to which the cluster is connected. On output this
shows the subnetwork ID instead of the name.
Corresponds to the JSON property subnetwork
1823 1824 1825 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1823 def subnetwork @subnetwork end |
#tpu_config ⇒ Google::Apis::ContainerV1beta1::TpuConfig
Configuration for Cloud TPU. This message is deprecated due to the deprecation
of 2VM TPU. The end of life date for 2VM TPU is 2025-04-25.
Corresponds to the JSON property tpuConfig
1829 1830 1831 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1829 def tpu_config @tpu_config end |
#tpu_ipv4_cidr_block ⇒ String
Output only. The IP address range of the Cloud TPUs in this cluster, in CIDR notation (e.g.
1.2.3.4/29). This field is deprecated due to the deprecation of 2VM TPU. The
end of life date for 2VM TPU is 2025-04-25.
Corresponds to the JSON property tpuIpv4CidrBlock
1837 1838 1839 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1837 def tpu_ipv4_cidr_block @tpu_ipv4_cidr_block end |
#user_managed_keys_config ⇒ Google::Apis::ContainerV1beta1::UserManagedKeysConfig
UserManagedKeysConfig holds the resource address to Keys which are used for
signing certs and token that are used for communication within cluster.
Corresponds to the JSON property userManagedKeysConfig
1843 1844 1845 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1843 def user_managed_keys_config @user_managed_keys_config end |
#vertical_pod_autoscaling ⇒ Google::Apis::ContainerV1beta1::VerticalPodAutoscaling
VerticalPodAutoscaling contains global, per-cluster information required by
Vertical Pod Autoscaler to automatically adjust the resources of pods
controlled by it.
Corresponds to the JSON property verticalPodAutoscaling
1850 1851 1852 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1850 def vertical_pod_autoscaling @vertical_pod_autoscaling end |
#workload_alts_config ⇒ Google::Apis::ContainerV1beta1::WorkloadAltsConfig
Configuration for direct-path (via ALTS) with workload identity. This feature
is not officially supported for external customers in Kubernetes Engine when
using Workload Identity.
Corresponds to the JSON property workloadAltsConfig
1857 1858 1859 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1857 def workload_alts_config @workload_alts_config end |
#workload_certificates ⇒ Google::Apis::ContainerV1beta1::WorkloadCertificates
Configuration for issuance of mTLS keys and certificates to Kubernetes pods.
Corresponds to the JSON property workloadCertificates
1862 1863 1864 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1862 def workload_certificates @workload_certificates end |
#workload_identity_config ⇒ Google::Apis::ContainerV1beta1::WorkloadIdentityConfig
Configuration for the use of Kubernetes Service Accounts in IAM policies.
Corresponds to the JSON property workloadIdentityConfig
1867 1868 1869 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1867 def workload_identity_config @workload_identity_config end |
#zone ⇒ String
Output only. The name of the Google Compute Engine zone in which the cluster resides. This field is
deprecated, use location instead.
Corresponds to the JSON property zone
1874 1875 1876 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1874 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 1881 def update!(**args) @addons_config = args[:addons_config] if args.key?(:addons_config) @alpha_cluster_feature_gates = args[:alpha_cluster_feature_gates] if args.key?(:alpha_cluster_feature_gates) @anonymous_authentication_config = args[:anonymous_authentication_config] if args.key?(:anonymous_authentication_config) @authenticator_groups_config = args[:authenticator_groups_config] if args.key?(:authenticator_groups_config) @autopilot = args[:autopilot] if args.key?(:autopilot) @autoscaling = args[:autoscaling] if args.key?(:autoscaling) @binary_authorization = args[:binary_authorization] if args.key?(:binary_authorization) @cluster_ipv4_cidr = args[:cluster_ipv4_cidr] if args.key?(:cluster_ipv4_cidr) @cluster_telemetry = args[:cluster_telemetry] if args.key?(:cluster_telemetry) @compliance_posture_config = args[:compliance_posture_config] if args.key?(:compliance_posture_config) @conditions = args[:conditions] if args.key?(:conditions) @confidential_nodes = args[:confidential_nodes] if args.key?(:confidential_nodes) @control_plane_endpoints_config = args[:control_plane_endpoints_config] if args.key?(:control_plane_endpoints_config) @cost_management_config = args[:cost_management_config] if args.key?(:cost_management_config) @create_time = args[:create_time] if args.key?(:create_time) @current_emulated_version = args[:current_emulated_version] if args.key?(:current_emulated_version) @current_master_version = args[:current_master_version] if args.key?(:current_master_version) @current_node_count = args[:current_node_count] if args.key?(:current_node_count) @current_node_version = args[:current_node_version] if args.key?(:current_node_version) @database_encryption = args[:database_encryption] if args.key?(:database_encryption) @default_max_pods_constraint = args[:default_max_pods_constraint] if args.key?(:default_max_pods_constraint) @description = args[:description] if args.key?(:description) @enable_k8s_beta_apis = args[:enable_k8s_beta_apis] if args.key?(:enable_k8s_beta_apis) @enable_kubernetes_alpha = args[:enable_kubernetes_alpha] if args.key?(:enable_kubernetes_alpha) @enable_tpu = args[:enable_tpu] if args.key?(:enable_tpu) @endpoint = args[:endpoint] if args.key?(:endpoint) @enterprise_config = args[:enterprise_config] if args.key?(:enterprise_config) @etag = args[:etag] if args.key?(:etag) @expire_time = args[:expire_time] if args.key?(:expire_time) @fleet = args[:fleet] if args.key?(:fleet) @gke_auto_upgrade_config = args[:gke_auto_upgrade_config] if args.key?(:gke_auto_upgrade_config) @id = args[:id] if args.key?(:id) @identity_service_config = args[:identity_service_config] if args.key?(:identity_service_config) @initial_cluster_version = args[:initial_cluster_version] if args.key?(:initial_cluster_version) @initial_node_count = args[:initial_node_count] if args.key?(:initial_node_count) @instance_group_urls = args[:instance_group_urls] if args.key?(:instance_group_urls) @ip_allocation_policy = args[:ip_allocation_policy] if args.key?(:ip_allocation_policy) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @legacy_abac = args[:legacy_abac] if args.key?(:legacy_abac) @location = args[:location] if args.key?(:location) @locations = args[:locations] if args.key?(:locations) @logging_config = args[:logging_config] if args.key?(:logging_config) @logging_service = args[:logging_service] if args.key?(:logging_service) @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy) @managed_opentelemetry_config = args[:managed_opentelemetry_config] if args.key?(:managed_opentelemetry_config) @master = args[:master] if args.key?(:master) @master_auth = args[:master_auth] if args.key?(:master_auth) @master_authorized_networks_config = args[:master_authorized_networks_config] if args.key?(:master_authorized_networks_config) @master_ipv4_cidr_block = args[:master_ipv4_cidr_block] if args.key?(:master_ipv4_cidr_block) @mesh_certificates = args[:mesh_certificates] if args.key?(:mesh_certificates) @monitoring_config = args[:monitoring_config] if args.key?(:monitoring_config) @monitoring_service = args[:monitoring_service] if args.key?(:monitoring_service) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @network_config = args[:network_config] if args.key?(:network_config) @network_policy = args[:network_policy] if args.key?(:network_policy) @node_config = args[:node_config] if args.key?(:node_config) @node_ipv4_cidr_size = args[:node_ipv4_cidr_size] if args.key?(:node_ipv4_cidr_size) @node_pool_auto_config = args[:node_pool_auto_config] if args.key?(:node_pool_auto_config) @node_pool_defaults = args[:node_pool_defaults] if args.key?(:node_pool_defaults) @node_pools = args[:node_pools] if args.key?(:node_pools) @notification_config = args[:notification_config] if args.key?(:notification_config) @parent_product_config = args[:parent_product_config] if args.key?(:parent_product_config) @pod_autoscaling = args[:pod_autoscaling] if args.key?(:pod_autoscaling) @pod_security_policy_config = args[:pod_security_policy_config] if args.key?(:pod_security_policy_config) @private_cluster = args[:private_cluster] if args.key?(:private_cluster) @private_cluster_config = args[:private_cluster_config] if args.key?(:private_cluster_config) @protect_config = args[:protect_config] if args.key?(:protect_config) @rbac_binding_config = args[:rbac_binding_config] if args.key?(:rbac_binding_config) @release_channel = args[:release_channel] if args.key?(:release_channel) @resource_labels = args[:resource_labels] if args.key?(:resource_labels) @resource_usage_export_config = args[:resource_usage_export_config] if args.key?(:resource_usage_export_config) @rollback_safe_upgrade = args[:rollback_safe_upgrade] if args.key?(:rollback_safe_upgrade) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @secret_manager_config = args[:secret_manager_config] if args.key?(:secret_manager_config) @secret_sync_config = args[:secret_sync_config] if args.key?(:secret_sync_config) @security_posture_config = args[:security_posture_config] if args.key?(:security_posture_config) @self_link = args[:self_link] if args.key?(:self_link) @services_ipv4_cidr = args[:services_ipv4_cidr] if args.key?(:services_ipv4_cidr) @shielded_nodes = args[:shielded_nodes] if args.key?(:shielded_nodes) @status = args[:status] if args.key?(:status) @status_message = args[:status_message] if args.key?(:status_message) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @tpu_config = args[:tpu_config] if args.key?(:tpu_config) @tpu_ipv4_cidr_block = args[:tpu_ipv4_cidr_block] if args.key?(:tpu_ipv4_cidr_block) @user_managed_keys_config = args[:user_managed_keys_config] if args.key?(:user_managed_keys_config) @vertical_pod_autoscaling = args[:vertical_pod_autoscaling] if args.key?(:vertical_pod_autoscaling) @workload_alts_config = args[:workload_alts_config] if args.key?(:workload_alts_config) @workload_certificates = args[:workload_certificates] if args.key?(:workload_certificates) @workload_identity_config = args[:workload_identity_config] if args.key?(:workload_identity_config) @zone = args[:zone] if args.key?(:zone) end |