Class: Google::Apis::ContainerV1beta1::ClusterUpdate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

ClusterUpdate describes an update to the cluster. Exactly one update can be applied to a cluster with each request, so at most one field can be provided.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterUpdate

Returns a new instance of ClusterUpdate.



2605
2606
2607
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2605

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_pod_ranges_configGoogle::Apis::ContainerV1beta1::AdditionalPodRangesConfig

AdditionalPodRangesConfig is the configuration for additional pod secondary ranges supporting the ClusterUpdate message. Corresponds to the JSON property additionalPodRangesConfig



2086
2087
2088
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2086

def additional_pod_ranges_config
  @additional_pod_ranges_config
end

#desired_additional_ip_ranges_configGoogle::Apis::ContainerV1beta1::DesiredAdditionalIpRangesConfig

DesiredAdditionalIPRangesConfig is a wrapper used for cluster update operation and contains multiple AdditionalIPRangesConfigs. Corresponds to the JSON property desiredAdditionalIpRangesConfig



2092
2093
2094
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2092

def desired_additional_ip_ranges_config
  @desired_additional_ip_ranges_config
end

#desired_addons_configGoogle::Apis::ContainerV1beta1::AddonsConfig

Configuration for the addons that can be automatically spun up in the cluster, enabling additional functionality. Corresponds to the JSON property desiredAddonsConfig



2098
2099
2100
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2098

def desired_addons_config
  @desired_addons_config
end

#desired_anonymous_authentication_configGoogle::Apis::ContainerV1beta1::AnonymousAuthenticationConfig

AnonymousAuthenticationConfig defines the settings needed to limit endpoints that allow anonymous authentication. Corresponds to the JSON property desiredAnonymousAuthenticationConfig



2104
2105
2106
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2104

def desired_anonymous_authentication_config
  @desired_anonymous_authentication_config
end

#desired_authenticator_groups_configGoogle::Apis::ContainerV1beta1::AuthenticatorGroupsConfig

Configuration for returning group information from authenticators. Corresponds to the JSON property desiredAuthenticatorGroupsConfig



2109
2110
2111
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2109

def desired_authenticator_groups_config
  @desired_authenticator_groups_config
end

#desired_auto_ipam_configGoogle::Apis::ContainerV1beta1::AutoIpamConfig

AutoIpamConfig contains all information related to Auto IPAM Corresponds to the JSON property desiredAutoIpamConfig



2114
2115
2116
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2114

def desired_auto_ipam_config
  @desired_auto_ipam_config
end

#desired_autopilot_workload_policy_configGoogle::Apis::ContainerV1beta1::WorkloadPolicyConfig

WorkloadPolicyConfig is the configuration related to GCW workload policy Corresponds to the JSON property desiredAutopilotWorkloadPolicyConfig



2119
2120
2121
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2119

def desired_autopilot_workload_policy_config
  @desired_autopilot_workload_policy_config
end

#desired_binary_authorizationGoogle::Apis::ContainerV1beta1::BinaryAuthorization

Configuration for Binary Authorization. Corresponds to the JSON property desiredBinaryAuthorization



2124
2125
2126
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2124

def desired_binary_authorization
  @desired_binary_authorization
end

#desired_cluster_autoscalingGoogle::Apis::ContainerV1beta1::ClusterAutoscaling

ClusterAutoscaling contains global, per-cluster information required by Cluster Autoscaler to automatically adjust the size of the cluster and create/ delete node pools based on the current needs. Corresponds to the JSON property desiredClusterAutoscaling



2131
2132
2133
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2131

def desired_cluster_autoscaling
  @desired_cluster_autoscaling
end

#desired_cluster_telemetryGoogle::Apis::ContainerV1beta1::ClusterTelemetry

Telemetry integration for the cluster. Corresponds to the JSON property desiredClusterTelemetry



2136
2137
2138
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2136

def desired_cluster_telemetry
  @desired_cluster_telemetry
end

#desired_compliance_posture_configGoogle::Apis::ContainerV1beta1::CompliancePostureConfig

Deprecated: Compliance Posture is no longer supported. For more details, see https://cloud.google.com/kubernetes-engine/docs/deprecations/posture- management-deprecation. CompliancePostureConfig defines the settings needed to enable/disable features for the Compliance Posture. Corresponds to the JSON property desiredCompliancePostureConfig



2144
2145
2146
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2144

def desired_compliance_posture_config
  @desired_compliance_posture_config
end

#desired_containerd_configGoogle::Apis::ContainerV1beta1::ContainerdConfig

ContainerdConfig contains configuration to customize containerd. Corresponds to the JSON property desiredContainerdConfig



2149
2150
2151
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2149

def desired_containerd_config
  @desired_containerd_config
end

#desired_control_plane_endpoints_configGoogle::Apis::ContainerV1beta1::ControlPlaneEndpointsConfig

Configuration for all of the cluster's control plane endpoints. Corresponds to the JSON property desiredControlPlaneEndpointsConfig



2154
2155
2156
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2154

def desired_control_plane_endpoints_config
  @desired_control_plane_endpoints_config
end

#desired_cost_management_configGoogle::Apis::ContainerV1beta1::CostManagementConfig

Configuration for fine-grained cost management feature. Corresponds to the JSON property desiredCostManagementConfig



2159
2160
2161
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2159

def desired_cost_management_config
  @desired_cost_management_config
end

#desired_database_encryptionGoogle::Apis::ContainerV1beta1::DatabaseEncryption

Configuration of etcd encryption. Corresponds to the JSON property desiredDatabaseEncryption



2164
2165
2166
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2164

def desired_database_encryption
  @desired_database_encryption
end

#desired_datapath_providerString

The desired datapath provider for the cluster. Corresponds to the JSON property desiredDatapathProvider

Returns:

  • (String)


2169
2170
2171
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2169

def desired_datapath_provider
  @desired_datapath_provider
end

#desired_default_enable_private_nodesBoolean Also known as: desired_default_enable_private_nodes?

Override the default setting of whether future created nodes have private IP addresses only, namely NetworkConfig.default_enable_private_nodes Corresponds to the JSON property desiredDefaultEnablePrivateNodes

Returns:

  • (Boolean)


2175
2176
2177
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2175

def desired_default_enable_private_nodes
  @desired_default_enable_private_nodes
end

#desired_default_snat_statusGoogle::Apis::ContainerV1beta1::DefaultSnatStatus

DefaultSnatStatus contains the desired state of whether default sNAT should be disabled on the cluster. Corresponds to the JSON property desiredDefaultSnatStatus



2182
2183
2184
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2182

def desired_default_snat_status
  @desired_default_snat_status
end

#desired_disable_l4_lb_firewall_reconciliationBoolean Also known as: desired_disable_l4_lb_firewall_reconciliation?

Enable/Disable L4 LB VPC firewall reconciliation for the cluster. Corresponds to the JSON property desiredDisableL4LbFirewallReconciliation

Returns:

  • (Boolean)


2187
2188
2189
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2187

def desired_disable_l4_lb_firewall_reconciliation
  @desired_disable_l4_lb_firewall_reconciliation
end

#desired_dns_configGoogle::Apis::ContainerV1beta1::DnsConfig

DNSConfig contains the desired set of options for configuring clusterDNS. Corresponds to the JSON property desiredDnsConfig



2193
2194
2195
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2193

def desired_dns_config
  @desired_dns_config
end

#desired_enable_cilium_clusterwide_network_policyBoolean Also known as: desired_enable_cilium_clusterwide_network_policy?

Enable/Disable Cilium Clusterwide Network Policy for the cluster. Corresponds to the JSON property desiredEnableCiliumClusterwideNetworkPolicy

Returns:

  • (Boolean)


2198
2199
2200
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2198

def desired_enable_cilium_clusterwide_network_policy
  @desired_enable_cilium_clusterwide_network_policy
end

#desired_enable_fqdn_network_policyBoolean Also known as: desired_enable_fqdn_network_policy?

Enable/Disable FQDN Network Policy for the cluster. Corresponds to the JSON property desiredEnableFqdnNetworkPolicy

Returns:

  • (Boolean)


2204
2205
2206
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2204

def desired_enable_fqdn_network_policy
  @desired_enable_fqdn_network_policy
end

#desired_enable_multi_networkingBoolean Also known as: desired_enable_multi_networking?

Enable/Disable Multi-Networking for the cluster Corresponds to the JSON property desiredEnableMultiNetworking

Returns:

  • (Boolean)


2210
2211
2212
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2210

def desired_enable_multi_networking
  @desired_enable_multi_networking
end

#desired_enable_private_endpointBoolean Also known as: desired_enable_private_endpoint?

Enable/Disable private endpoint for the cluster's master. Deprecated: Use desired_control_plane_endpoints_config.ip_endpoints_config. enable_public_endpoint instead. Note that the value of enable_public_endpoint is reversed: if enable_private_endpoint is false, then enable_public_endpoint will be true. Corresponds to the JSON property desiredEnablePrivateEndpoint

Returns:

  • (Boolean)


2220
2221
2222
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2220

def desired_enable_private_endpoint
  @desired_enable_private_endpoint
end

#desired_enterprise_configGoogle::Apis::ContainerV1beta1::DesiredEnterpriseConfig

DesiredEnterpriseConfig is a wrapper used for updating enterprise_config. Deprecated: GKE Enterprise features are now available without an Enterprise tier. Corresponds to the JSON property desiredEnterpriseConfig



2228
2229
2230
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2228

def desired_enterprise_config
  @desired_enterprise_config
end

#desired_fleetGoogle::Apis::ContainerV1beta1::Fleet

Fleet is the fleet configuration for the cluster. Corresponds to the JSON property desiredFleet



2233
2234
2235
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2233

def desired_fleet
  @desired_fleet
end

#desired_gateway_api_configGoogle::Apis::ContainerV1beta1::GatewayApiConfig

GatewayAPIConfig contains the desired config of Gateway API on this cluster. Corresponds to the JSON property desiredGatewayApiConfig



2238
2239
2240
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2238

def desired_gateway_api_config
  @desired_gateway_api_config
end

#desired_gcfs_configGoogle::Apis::ContainerV1beta1::GcfsConfig

GcfsConfig contains configurations of Google Container File System. Corresponds to the JSON property desiredGcfsConfig



2243
2244
2245
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2243

def desired_gcfs_config
  @desired_gcfs_config
end

#desired_host_maintenance_policyGoogle::Apis::ContainerV1beta1::HostMaintenancePolicy

HostMaintenancePolicy contains the maintenance policy for the hosts on which the GKE VMs run on. Corresponds to the JSON property desiredHostMaintenancePolicy



2249
2250
2251
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2249

def desired_host_maintenance_policy
  @desired_host_maintenance_policy
end

#desired_identity_service_configGoogle::Apis::ContainerV1beta1::IdentityServiceConfig

IdentityServiceConfig is configuration for Identity Service which allows customers to use external identity providers with the K8S API Corresponds to the JSON property desiredIdentityServiceConfig



2255
2256
2257
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2255

def desired_identity_service_config
  @desired_identity_service_config
end

#desired_image_typeString

The desired image type for the node pool. NOTE: Set the "desired_node_pool" field as well. Corresponds to the JSON property desiredImageType

Returns:

  • (String)


2261
2262
2263
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2261

def desired_image_type
  @desired_image_type
end

#desired_in_transit_encryption_configString

Specify the details of in-transit encryption. Now named inter-node transparent encryption. Corresponds to the JSON property desiredInTransitEncryptionConfig

Returns:

  • (String)


2267
2268
2269
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2267

def desired_in_transit_encryption_config
  @desired_in_transit_encryption_config
end

#desired_intra_node_visibility_configGoogle::Apis::ContainerV1beta1::IntraNodeVisibilityConfig

IntraNodeVisibilityConfig contains the desired config of the intra-node visibility on this cluster. Corresponds to the JSON property desiredIntraNodeVisibilityConfig



2273
2274
2275
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2273

def desired_intra_node_visibility_config
  @desired_intra_node_visibility_config
end

#desired_k8s_beta_apisGoogle::Apis::ContainerV1beta1::K8sBetaApiConfig

Kubernetes open source beta apis enabled on the cluster. Corresponds to the JSON property desiredK8sBetaApis



2278
2279
2280
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2278

def desired_k8s_beta_apis
  @desired_k8s_beta_apis
end

#desired_l4ilb_subsetting_configGoogle::Apis::ContainerV1beta1::IlbSubsettingConfig

ILBSubsettingConfig contains the desired config of L4 Internal LoadBalancer subsetting on this cluster. Corresponds to the JSON property desiredL4ilbSubsettingConfig



2284
2285
2286
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2284

def desired_l4ilb_subsetting_config
  @desired_l4ilb_subsetting_config
end

#desired_locationsArray<String>

The desired list of Google Compute Engine zones in which the cluster's nodes should be located. This list must always include the cluster's primary zone. Warning: changing cluster locations will update the locations of all node pools and will result in nodes being added and/or removed. Corresponds to the JSON property desiredLocations

Returns:

  • (Array<String>)


2293
2294
2295
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2293

def desired_locations
  @desired_locations
end

#desired_logging_configGoogle::Apis::ContainerV1beta1::LoggingConfig

LoggingConfig is cluster logging configuration. Corresponds to the JSON property desiredLoggingConfig



2298
2299
2300
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2298

def desired_logging_config
  @desired_logging_config
end

#desired_logging_serviceString

The logging service the cluster should use to write logs. Currently available options: * logging.googleapis.com/kubernetes - The Cloud Logging service with a Kubernetes-native resource model * logging.googleapis.com - The legacy Cloud Logging service (no longer available as of GKE 1.15). * none - no logs will be exported from the cluster. If left as an empty string,logging. googleapis.com/kubernetes will be used for GKE 1.14+ or logging.googleapis. com for earlier versions. Corresponds to the JSON property desiredLoggingService

Returns:

  • (String)


2309
2310
2311
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2309

def desired_logging_service
  @desired_logging_service
end

#desired_managed_opentelemetry_configGoogle::Apis::ContainerV1beta1::ManagedOpenTelemetryConfig

ManagedOpenTelemetryConfig is the configuration for the GKE Managed OpenTelemetry pipeline. Corresponds to the JSON property desiredManagedOpentelemetryConfig



2315
2316
2317
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2315

def desired_managed_opentelemetry_config
  @desired_managed_opentelemetry_config
end

#desired_masterGoogle::Apis::ContainerV1beta1::Master

Master is the configuration for components on master. Corresponds to the JSON property desiredMaster



2320
2321
2322
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2320

def desired_master
  @desired_master
end

#desired_master_authorized_networks_configGoogle::Apis::ContainerV1beta1::MasterAuthorizedNetworksConfig

Configuration options for the master authorized networks feature. Enabled master authorized networks will disallow all external traffic to access Kubernetes master through HTTPS except traffic from the given CIDR blocks, Google Compute Engine Public IPs and Google Prod IPs. Corresponds to the JSON property desiredMasterAuthorizedNetworksConfig



2328
2329
2330
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2328

def desired_master_authorized_networks_config
  @desired_master_authorized_networks_config
end

#desired_master_versionString

The Kubernetes version to change the master to. The only valid value is the latest supported version. Users may specify either explicit versions offered by Kubernetes Engine or version aliases, which have the following behavior: - " latest": picks the highest valid Kubernetes version - "1.X": picks the highest valid patch+gke.N patch in the 1.X version - "1.X.Y": picks the highest valid gke.N patch in the 1.X.Y version - "1.X.Y-gke.N": picks an explicit Kubernetes version - "-": picks the default Kubernetes version Corresponds to the JSON property desiredMasterVersion

Returns:

  • (String)


2339
2340
2341
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2339

def desired_master_version
  @desired_master_version
end

#desired_mesh_certificatesGoogle::Apis::ContainerV1beta1::MeshCertificates

Configuration for issuance of mTLS keys and certificates to Kubernetes pods. Corresponds to the JSON property desiredMeshCertificates



2344
2345
2346
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2344

def desired_mesh_certificates
  @desired_mesh_certificates
end

#desired_monitoring_configGoogle::Apis::ContainerV1beta1::MonitoringConfig

MonitoringConfig is cluster monitoring configuration. Corresponds to the JSON property desiredMonitoringConfig



2349
2350
2351
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2349

def desired_monitoring_config
  @desired_monitoring_config
end

#desired_monitoring_serviceString

The monitoring service the cluster should use to write metrics. Currently available options: * monitoring.googleapis.com/kubernetes - The Cloud Monitoring service with a Kubernetes-native resource model * monitoring. googleapis.com - The legacy Cloud Monitoring service (no longer available as of GKE 1.15). * none - No metrics will be exported from the cluster. If left as an empty string,monitoring.googleapis.com/kubernetes will be used for GKE 1.14+ or monitoring.googleapis.com for earlier versions. Corresponds to the JSON property desiredMonitoringService

Returns:

  • (String)


2360
2361
2362
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2360

def desired_monitoring_service
  @desired_monitoring_service
end

#desired_network_performance_configGoogle::Apis::ContainerV1beta1::ClusterNetworkPerformanceConfig

Configuration of all network bandwidth tiers Corresponds to the JSON property desiredNetworkPerformanceConfig



2365
2366
2367
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2365

def desired_network_performance_config
  @desired_network_performance_config
end

#desired_network_tier_configGoogle::Apis::ContainerV1beta1::NetworkTierConfig

NetworkTierConfig contains network tier information. Corresponds to the JSON property desiredNetworkTierConfig



2370
2371
2372
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2370

def desired_network_tier_config
  @desired_network_tier_config
end

#desired_node_kubelet_configGoogle::Apis::ContainerV1beta1::NodeKubeletConfig

Node kubelet configs. Corresponds to the JSON property desiredNodeKubeletConfig



2375
2376
2377
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2375

def desired_node_kubelet_config
  @desired_node_kubelet_config
end

#desired_node_pool_auto_config_kubelet_configGoogle::Apis::ContainerV1beta1::NodeKubeletConfig

Node kubelet configs. Corresponds to the JSON property desiredNodePoolAutoConfigKubeletConfig



2380
2381
2382
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2380

def desired_node_pool_auto_config_kubelet_config
  @desired_node_pool_auto_config_kubelet_config
end

#desired_node_pool_auto_config_linux_node_configGoogle::Apis::ContainerV1beta1::LinuxNodeConfig

Parameters that can be configured on Linux nodes. Corresponds to the JSON property desiredNodePoolAutoConfigLinuxNodeConfig



2385
2386
2387
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2385

def desired_node_pool_auto_config_linux_node_config
  @desired_node_pool_auto_config_linux_node_config
end

#desired_node_pool_auto_config_network_tagsGoogle::Apis::ContainerV1beta1::NetworkTags

Collection of Compute Engine network tags that can be applied to a node's underlying VM instance. (See tags field in NodeConfig). Corresponds to the JSON property desiredNodePoolAutoConfigNetworkTags



2392
2393
2394
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2392

def desired_node_pool_auto_config_network_tags
  @desired_node_pool_auto_config_network_tags
end

#desired_node_pool_auto_config_resource_manager_tagsGoogle::Apis::ContainerV1beta1::ResourceManagerTags

A map of resource manager tag keys and values to be attached to the nodes for managing Compute Engine firewalls using Network Firewall Policies. Tags must be according to specifications in https://cloud.google.com/vpc/docs/tags- firewalls-overview#specifications. A maximum of 5 tag key-value pairs can be specified. Existing tags will be replaced with new values. Corresponds to the JSON property desiredNodePoolAutoConfigResourceManagerTags



2401
2402
2403
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2401

def desired_node_pool_auto_config_resource_manager_tags
  @desired_node_pool_auto_config_resource_manager_tags
end

#desired_node_pool_autoscalingGoogle::Apis::ContainerV1beta1::NodePoolAutoscaling

NodePoolAutoscaling contains information required by cluster autoscaler to adjust the size of the node pool to the current cluster usage. Corresponds to the JSON property desiredNodePoolAutoscaling



2407
2408
2409
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2407

def desired_node_pool_autoscaling
  @desired_node_pool_autoscaling
end

#desired_node_pool_idString

The node pool to be upgraded. This field is mandatory if "desired_node_version" , "desired_image_family", "desired_node_pool_autoscaling", or " desired_workload_metadata_config" is specified and there is more than one node pool on the cluster. Corresponds to the JSON property desiredNodePoolId

Returns:

  • (String)


2415
2416
2417
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2415

def desired_node_pool_id
  @desired_node_pool_id
end

#desired_node_pool_logging_configGoogle::Apis::ContainerV1beta1::NodePoolLoggingConfig

NodePoolLoggingConfig specifies logging configuration for nodepools. Corresponds to the JSON property desiredNodePoolLoggingConfig



2420
2421
2422
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2420

def desired_node_pool_logging_config
  @desired_node_pool_logging_config
end

#desired_node_versionString

The Kubernetes version to change the nodes to (typically an upgrade). Users may specify either explicit versions offered by Kubernetes Engine or version aliases, which have the following behavior: - "latest": picks the highest valid Kubernetes version - "1.X": picks the highest valid patch+gke.N patch in the 1.X version - "1.X.Y": picks the highest valid gke.N patch in the 1.X.Y version - "1.X.Y-gke.N": picks an explicit Kubernetes version - "-": picks the Kubernetes master version Corresponds to the JSON property desiredNodeVersion

Returns:

  • (String)


2431
2432
2433
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2431

def desired_node_version
  @desired_node_version
end

#desired_notification_configGoogle::Apis::ContainerV1beta1::NotificationConfig

NotificationConfig is the configuration of notifications. Corresponds to the JSON property desiredNotificationConfig



2436
2437
2438
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2436

def desired_notification_config
  @desired_notification_config
end

#desired_parent_product_configGoogle::Apis::ContainerV1beta1::ParentProductConfig

ParentProductConfig is the configuration of the parent product of the cluster. This field is used by Google internal products that are built on top of a GKE cluster and take the ownership of the cluster. Corresponds to the JSON property desiredParentProductConfig



2443
2444
2445
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2443

def desired_parent_product_config
  @desired_parent_product_config
end

#desired_pod_autoscalingGoogle::Apis::ContainerV1beta1::PodAutoscaling

PodAutoscaling is used for configuration of parameters for workload autoscaling. Corresponds to the JSON property desiredPodAutoscaling



2449
2450
2451
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2449

def desired_pod_autoscaling
  @desired_pod_autoscaling
end

#desired_pod_security_policy_configGoogle::Apis::ContainerV1beta1::PodSecurityPolicyConfig

Configuration for the PodSecurityPolicy feature. Corresponds to the JSON property desiredPodSecurityPolicyConfig



2454
2455
2456
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2454

def desired_pod_security_policy_config
  @desired_pod_security_policy_config
end

#desired_private_cluster_configGoogle::Apis::ContainerV1beta1::PrivateClusterConfig

Configuration options for private clusters. Corresponds to the JSON property desiredPrivateClusterConfig



2459
2460
2461
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2459

def desired_private_cluster_config
  @desired_private_cluster_config
end

#desired_private_ipv6_google_accessString

The desired state of IPv6 connectivity to Google Services. Corresponds to the JSON property desiredPrivateIpv6GoogleAccess

Returns:

  • (String)


2464
2465
2466
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2464

def desired_private_ipv6_google_access
  @desired_private_ipv6_google_access
end

#desired_privileged_admission_configGoogle::Apis::ContainerV1beta1::PrivilegedAdmissionConfig

PrivilegedAdmissionConfig stores the list of authorized allowlist paths for the cluster. Corresponds to the JSON property desiredPrivilegedAdmissionConfig



2470
2471
2472
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2470

def desired_privileged_admission_config
  @desired_privileged_admission_config
end

#desired_protect_configGoogle::Apis::ContainerV1beta1::ProtectConfig

ProtectConfig defines the flags needed to enable/disable features for the Protect API. Corresponds to the JSON property desiredProtectConfig



2476
2477
2478
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2476

def desired_protect_config
  @desired_protect_config
end

#desired_rbac_binding_configGoogle::Apis::ContainerV1beta1::RbacBindingConfig

RBACBindingConfig allows user to restrict ClusterRoleBindings an RoleBindings that can be created. Corresponds to the JSON property desiredRbacBindingConfig



2482
2483
2484
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2482

def desired_rbac_binding_config
  @desired_rbac_binding_config
end

#desired_release_channelGoogle::Apis::ContainerV1beta1::ReleaseChannel

ReleaseChannel indicates which release channel a cluster is subscribed to. Release channels are arranged in order of risk. When a cluster is subscribed to a release channel, Google maintains both the master version and the node version. Node auto-upgrade defaults to true and cannot be disabled. Corresponds to the JSON property desiredReleaseChannel



2490
2491
2492
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2490

def desired_release_channel
  @desired_release_channel
end

#desired_resource_usage_export_configGoogle::Apis::ContainerV1beta1::ResourceUsageExportConfig

Configuration for exporting cluster resource usages. Corresponds to the JSON property desiredResourceUsageExportConfig



2495
2496
2497
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2495

def desired_resource_usage_export_config
  @desired_resource_usage_export_config
end

#desired_rollback_safe_upgradeGoogle::Apis::ContainerV1beta1::RollbackSafeUpgrade

RollbackSafeUpgrade is the configuration for the rollback safe upgrade. Corresponds to the JSON property desiredRollbackSafeUpgrade



2500
2501
2502
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2500

def desired_rollback_safe_upgrade
  @desired_rollback_safe_upgrade
end

#desired_secret_manager_configGoogle::Apis::ContainerV1beta1::SecretManagerConfig

SecretManagerConfig is config for secret manager enablement. Corresponds to the JSON property desiredSecretManagerConfig



2505
2506
2507
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2505

def desired_secret_manager_config
  @desired_secret_manager_config
end

#desired_secret_sync_configGoogle::Apis::ContainerV1beta1::SecretSyncConfig

Configuration for sync Secret Manager secrets as k8s secrets. Corresponds to the JSON property desiredSecretSyncConfig



2510
2511
2512
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2510

def desired_secret_sync_config
  @desired_secret_sync_config
end

#desired_security_posture_configGoogle::Apis::ContainerV1beta1::SecurityPostureConfig

SecurityPostureConfig defines the flags needed to enable/disable features for the Security Posture API. Corresponds to the JSON property desiredSecurityPostureConfig



2516
2517
2518
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2516

def desired_security_posture_config
  @desired_security_posture_config
end

#desired_service_external_ips_configGoogle::Apis::ContainerV1beta1::ServiceExternalIPsConfig

Config to block services with externalIPs field. Corresponds to the JSON property desiredServiceExternalIpsConfig



2521
2522
2523
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2521

def desired_service_external_ips_config
  @desired_service_external_ips_config
end

#desired_shielded_nodesGoogle::Apis::ContainerV1beta1::ShieldedNodes

Configuration of Shielded Nodes feature. Corresponds to the JSON property desiredShieldedNodes



2526
2527
2528
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2526

def desired_shielded_nodes
  @desired_shielded_nodes
end

#desired_stack_typeString

The desired stack type of the cluster. If a stack type is provided and does not match the current stack type of the cluster, update will attempt to change the stack type to the new type. Corresponds to the JSON property desiredStackType

Returns:

  • (String)


2533
2534
2535
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2533

def desired_stack_type
  @desired_stack_type
end

#desired_tpu_configGoogle::Apis::ContainerV1beta1::TpuConfig

Configuration for Cloud TPU. This message is deprecated due to the deprecation of 2VM TPU. The end of life date for 2VM TPU is 2025-04-25. Corresponds to the JSON property desiredTpuConfig



2539
2540
2541
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2539

def desired_tpu_config
  @desired_tpu_config
end

#desired_user_managed_keys_configGoogle::Apis::ContainerV1beta1::UserManagedKeysConfig

UserManagedKeysConfig holds the resource address to Keys which are used for signing certs and token that are used for communication within cluster. Corresponds to the JSON property desiredUserManagedKeysConfig



2545
2546
2547
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2545

def desired_user_managed_keys_config
  @desired_user_managed_keys_config
end

#desired_vertical_pod_autoscalingGoogle::Apis::ContainerV1beta1::VerticalPodAutoscaling

VerticalPodAutoscaling contains global, per-cluster information required by Vertical Pod Autoscaler to automatically adjust the resources of pods controlled by it. Corresponds to the JSON property desiredVerticalPodAutoscaling



2552
2553
2554
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2552

def desired_vertical_pod_autoscaling
  @desired_vertical_pod_autoscaling
end

#desired_workload_alts_configGoogle::Apis::ContainerV1beta1::WorkloadAltsConfig

Configuration for direct-path (via ALTS) with workload identity. This feature is not officially supported for external customers in Kubernetes Engine when using Workload Identity. Corresponds to the JSON property desiredWorkloadAltsConfig



2559
2560
2561
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2559

def desired_workload_alts_config
  @desired_workload_alts_config
end

#desired_workload_certificatesGoogle::Apis::ContainerV1beta1::WorkloadCertificates

Configuration for issuance of mTLS keys and certificates to Kubernetes pods. Corresponds to the JSON property desiredWorkloadCertificates



2564
2565
2566
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2564

def desired_workload_certificates
  @desired_workload_certificates
end

#desired_workload_identity_configGoogle::Apis::ContainerV1beta1::WorkloadIdentityConfig

Configuration for the use of Kubernetes Service Accounts in IAM policies. Corresponds to the JSON property desiredWorkloadIdentityConfig



2569
2570
2571
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2569

def desired_workload_identity_config
  @desired_workload_identity_config
end

#enable_k8s_beta_apisGoogle::Apis::ContainerV1beta1::K8sBetaApiConfig

Kubernetes open source beta apis enabled on the cluster. Corresponds to the JSON property enableK8sBetaApis



2574
2575
2576
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2574

def enable_k8s_beta_apis
  @enable_k8s_beta_apis
end

#etagString

The current etag of the cluster. If an etag is provided and does not match the current etag of the cluster, update will be blocked and an ABORTED error will be returned. Corresponds to the JSON property etag

Returns:

  • (String)


2581
2582
2583
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2581

def etag
  @etag
end

#gke_auto_upgrade_configGoogle::Apis::ContainerV1beta1::GkeAutoUpgradeConfig

GkeAutoUpgradeConfig is the configuration for GKE auto upgrades. Corresponds to the JSON property gkeAutoUpgradeConfig



2586
2587
2588
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2586

def gke_auto_upgrade_config
  @gke_auto_upgrade_config
end

#private_cluster_configGoogle::Apis::ContainerV1beta1::PrivateClusterConfig

Configuration options for private clusters. Corresponds to the JSON property privateClusterConfig



2591
2592
2593
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2591

def private_cluster_config
  @private_cluster_config
end

#removed_additional_pod_ranges_configGoogle::Apis::ContainerV1beta1::AdditionalPodRangesConfig

AdditionalPodRangesConfig is the configuration for additional pod secondary ranges supporting the ClusterUpdate message. Corresponds to the JSON property removedAdditionalPodRangesConfig



2597
2598
2599
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2597

def removed_additional_pod_ranges_config
  @removed_additional_pod_ranges_config
end

#user_managed_keys_configGoogle::Apis::ContainerV1beta1::UserManagedKeysConfig

UserManagedKeysConfig holds the resource address to Keys which are used for signing certs and token that are used for communication within cluster. Corresponds to the JSON property userManagedKeysConfig



2603
2604
2605
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2603

def user_managed_keys_config
  @user_managed_keys_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
2652
2653
2654
2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
2679
2680
2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2610

def update!(**args)
  @additional_pod_ranges_config = args[:additional_pod_ranges_config] if args.key?(:additional_pod_ranges_config)
  @desired_additional_ip_ranges_config = args[:desired_additional_ip_ranges_config] if args.key?(:desired_additional_ip_ranges_config)
  @desired_addons_config = args[:desired_addons_config] if args.key?(:desired_addons_config)
  @desired_anonymous_authentication_config = args[:desired_anonymous_authentication_config] if args.key?(:desired_anonymous_authentication_config)
  @desired_authenticator_groups_config = args[:desired_authenticator_groups_config] if args.key?(:desired_authenticator_groups_config)
  @desired_auto_ipam_config = args[:desired_auto_ipam_config] if args.key?(:desired_auto_ipam_config)
  @desired_autopilot_workload_policy_config = args[:desired_autopilot_workload_policy_config] if args.key?(:desired_autopilot_workload_policy_config)
  @desired_binary_authorization = args[:desired_binary_authorization] if args.key?(:desired_binary_authorization)
  @desired_cluster_autoscaling = args[:desired_cluster_autoscaling] if args.key?(:desired_cluster_autoscaling)
  @desired_cluster_telemetry = args[:desired_cluster_telemetry] if args.key?(:desired_cluster_telemetry)
  @desired_compliance_posture_config = args[:desired_compliance_posture_config] if args.key?(:desired_compliance_posture_config)
  @desired_containerd_config = args[:desired_containerd_config] if args.key?(:desired_containerd_config)
  @desired_control_plane_endpoints_config = args[:desired_control_plane_endpoints_config] if args.key?(:desired_control_plane_endpoints_config)
  @desired_cost_management_config = args[:desired_cost_management_config] if args.key?(:desired_cost_management_config)
  @desired_database_encryption = args[:desired_database_encryption] if args.key?(:desired_database_encryption)
  @desired_datapath_provider = args[:desired_datapath_provider] if args.key?(:desired_datapath_provider)
  @desired_default_enable_private_nodes = args[:desired_default_enable_private_nodes] if args.key?(:desired_default_enable_private_nodes)
  @desired_default_snat_status = args[:desired_default_snat_status] if args.key?(:desired_default_snat_status)
  @desired_disable_l4_lb_firewall_reconciliation = args[:desired_disable_l4_lb_firewall_reconciliation] if args.key?(:desired_disable_l4_lb_firewall_reconciliation)
  @desired_dns_config = args[:desired_dns_config] if args.key?(:desired_dns_config)
  @desired_enable_cilium_clusterwide_network_policy = args[:desired_enable_cilium_clusterwide_network_policy] if args.key?(:desired_enable_cilium_clusterwide_network_policy)
  @desired_enable_fqdn_network_policy = args[:desired_enable_fqdn_network_policy] if args.key?(:desired_enable_fqdn_network_policy)
  @desired_enable_multi_networking = args[:desired_enable_multi_networking] if args.key?(:desired_enable_multi_networking)
  @desired_enable_private_endpoint = args[:desired_enable_private_endpoint] if args.key?(:desired_enable_private_endpoint)
  @desired_enterprise_config = args[:desired_enterprise_config] if args.key?(:desired_enterprise_config)
  @desired_fleet = args[:desired_fleet] if args.key?(:desired_fleet)
  @desired_gateway_api_config = args[:desired_gateway_api_config] if args.key?(:desired_gateway_api_config)
  @desired_gcfs_config = args[:desired_gcfs_config] if args.key?(:desired_gcfs_config)
  @desired_host_maintenance_policy = args[:desired_host_maintenance_policy] if args.key?(:desired_host_maintenance_policy)
  @desired_identity_service_config = args[:desired_identity_service_config] if args.key?(:desired_identity_service_config)
  @desired_image_type = args[:desired_image_type] if args.key?(:desired_image_type)
  @desired_in_transit_encryption_config = args[:desired_in_transit_encryption_config] if args.key?(:desired_in_transit_encryption_config)
  @desired_intra_node_visibility_config = args[:desired_intra_node_visibility_config] if args.key?(:desired_intra_node_visibility_config)
  @desired_k8s_beta_apis = args[:desired_k8s_beta_apis] if args.key?(:desired_k8s_beta_apis)
  @desired_l4ilb_subsetting_config = args[:desired_l4ilb_subsetting_config] if args.key?(:desired_l4ilb_subsetting_config)
  @desired_locations = args[:desired_locations] if args.key?(:desired_locations)
  @desired_logging_config = args[:desired_logging_config] if args.key?(:desired_logging_config)
  @desired_logging_service = args[:desired_logging_service] if args.key?(:desired_logging_service)
  @desired_managed_opentelemetry_config = args[:desired_managed_opentelemetry_config] if args.key?(:desired_managed_opentelemetry_config)
  @desired_master = args[:desired_master] if args.key?(:desired_master)
  @desired_master_authorized_networks_config = args[:desired_master_authorized_networks_config] if args.key?(:desired_master_authorized_networks_config)
  @desired_master_version = args[:desired_master_version] if args.key?(:desired_master_version)
  @desired_mesh_certificates = args[:desired_mesh_certificates] if args.key?(:desired_mesh_certificates)
  @desired_monitoring_config = args[:desired_monitoring_config] if args.key?(:desired_monitoring_config)
  @desired_monitoring_service = args[:desired_monitoring_service] if args.key?(:desired_monitoring_service)
  @desired_network_performance_config = args[:desired_network_performance_config] if args.key?(:desired_network_performance_config)
  @desired_network_tier_config = args[:desired_network_tier_config] if args.key?(:desired_network_tier_config)
  @desired_node_kubelet_config = args[:desired_node_kubelet_config] if args.key?(:desired_node_kubelet_config)
  @desired_node_pool_auto_config_kubelet_config = args[:desired_node_pool_auto_config_kubelet_config] if args.key?(:desired_node_pool_auto_config_kubelet_config)
  @desired_node_pool_auto_config_linux_node_config = args[:desired_node_pool_auto_config_linux_node_config] if args.key?(:desired_node_pool_auto_config_linux_node_config)
  @desired_node_pool_auto_config_network_tags = args[:desired_node_pool_auto_config_network_tags] if args.key?(:desired_node_pool_auto_config_network_tags)
  @desired_node_pool_auto_config_resource_manager_tags = args[:desired_node_pool_auto_config_resource_manager_tags] if args.key?(:desired_node_pool_auto_config_resource_manager_tags)
  @desired_node_pool_autoscaling = args[:desired_node_pool_autoscaling] if args.key?(:desired_node_pool_autoscaling)
  @desired_node_pool_id = args[:desired_node_pool_id] if args.key?(:desired_node_pool_id)
  @desired_node_pool_logging_config = args[:desired_node_pool_logging_config] if args.key?(:desired_node_pool_logging_config)
  @desired_node_version = args[:desired_node_version] if args.key?(:desired_node_version)
  @desired_notification_config = args[:desired_notification_config] if args.key?(:desired_notification_config)
  @desired_parent_product_config = args[:desired_parent_product_config] if args.key?(:desired_parent_product_config)
  @desired_pod_autoscaling = args[:desired_pod_autoscaling] if args.key?(:desired_pod_autoscaling)
  @desired_pod_security_policy_config = args[:desired_pod_security_policy_config] if args.key?(:desired_pod_security_policy_config)
  @desired_private_cluster_config = args[:desired_private_cluster_config] if args.key?(:desired_private_cluster_config)
  @desired_private_ipv6_google_access = args[:desired_private_ipv6_google_access] if args.key?(:desired_private_ipv6_google_access)
  @desired_privileged_admission_config = args[:desired_privileged_admission_config] if args.key?(:desired_privileged_admission_config)
  @desired_protect_config = args[:desired_protect_config] if args.key?(:desired_protect_config)
  @desired_rbac_binding_config = args[:desired_rbac_binding_config] if args.key?(:desired_rbac_binding_config)
  @desired_release_channel = args[:desired_release_channel] if args.key?(:desired_release_channel)
  @desired_resource_usage_export_config = args[:desired_resource_usage_export_config] if args.key?(:desired_resource_usage_export_config)
  @desired_rollback_safe_upgrade = args[:desired_rollback_safe_upgrade] if args.key?(:desired_rollback_safe_upgrade)
  @desired_secret_manager_config = args[:desired_secret_manager_config] if args.key?(:desired_secret_manager_config)
  @desired_secret_sync_config = args[:desired_secret_sync_config] if args.key?(:desired_secret_sync_config)
  @desired_security_posture_config = args[:desired_security_posture_config] if args.key?(:desired_security_posture_config)
  @desired_service_external_ips_config = args[:desired_service_external_ips_config] if args.key?(:desired_service_external_ips_config)
  @desired_shielded_nodes = args[:desired_shielded_nodes] if args.key?(:desired_shielded_nodes)
  @desired_stack_type = args[:desired_stack_type] if args.key?(:desired_stack_type)
  @desired_tpu_config = args[:desired_tpu_config] if args.key?(:desired_tpu_config)
  @desired_user_managed_keys_config = args[:desired_user_managed_keys_config] if args.key?(:desired_user_managed_keys_config)
  @desired_vertical_pod_autoscaling = args[:desired_vertical_pod_autoscaling] if args.key?(:desired_vertical_pod_autoscaling)
  @desired_workload_alts_config = args[:desired_workload_alts_config] if args.key?(:desired_workload_alts_config)
  @desired_workload_certificates = args[:desired_workload_certificates] if args.key?(:desired_workload_certificates)
  @desired_workload_identity_config = args[:desired_workload_identity_config] if args.key?(:desired_workload_identity_config)
  @enable_k8s_beta_apis = args[:enable_k8s_beta_apis] if args.key?(:enable_k8s_beta_apis)
  @etag = args[:etag] if args.key?(:etag)
  @gke_auto_upgrade_config = args[:gke_auto_upgrade_config] if args.key?(:gke_auto_upgrade_config)
  @private_cluster_config = args[:private_cluster_config] if args.key?(:private_cluster_config)
  @removed_additional_pod_ranges_config = args[:removed_additional_pod_ranges_config] if args.key?(:removed_additional_pod_ranges_config)
  @user_managed_keys_config = args[:user_managed_keys_config] if args.key?(:user_managed_keys_config)
end