Class: Google::Apis::ContainerV1beta1::CompatibilityStatus
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::CompatibilityStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
CompatibilityStatus is the status regarding the control plane's compatibility.
Instance Attribute Summary collapse
-
#downgradable_version ⇒ String
Output only.
-
#emulated_version_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompatibilityStatus
constructor
A new instance of CompatibilityStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompatibilityStatus
Returns a new instance of CompatibilityStatus.
2757 2758 2759 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2757 def initialize(**args) update!(**args) end |
Instance Attribute Details
#downgradable_version ⇒ String
Output only. The GKE version that the cluster can be safely downgraded to if
the cluster is emulating the previous minor version. It is usually the cluster'
s previous version before a minor version upgrade.
Corresponds to the JSON property downgradableVersion
2748 2749 2750 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2748 def downgradable_version @downgradable_version end |
#emulated_version_time ⇒ String
Output only. Last time the control plane became available after a minor
version binary upgrade with emulated version set. It indicates the last time
the cluster entered the rollback safe mode.
Corresponds to the JSON property emulatedVersionTime
2755 2756 2757 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2755 def emulated_version_time @emulated_version_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2762 2763 2764 2765 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2762 def update!(**args) @downgradable_version = args[:downgradable_version] if args.key?(:downgradable_version) @emulated_version_time = args[:emulated_version_time] if args.key?(:emulated_version_time) end |