Class: Google::Apis::ContainerV1beta1::CompleteIpRotationRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

CompleteIPRotationRequest moves the cluster master back into single-IP mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompleteIpRotationRequest

Returns a new instance of CompleteIpRotationRequest.



2841
2842
2843
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2841

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


2819
2820
2821
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2819

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster name) of the cluster to complete IP rotation. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


2825
2826
2827
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2825

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


2832
2833
2834
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2832

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


2839
2840
2841
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2839

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2846
2847
2848
2849
2850
2851
# File 'lib/google/apis/container_v1beta1/classes.rb', line 2846

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end