Class: Google::Apis::ContainerV1beta1::CreateClusterRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::CreateClusterRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
CreateClusterRequest creates a cluster.
Instance Attribute Summary collapse
-
#cluster ⇒ Google::Apis::ContainerV1beta1::Cluster
A Google Kubernetes Engine cluster.
-
#parent ⇒ String
The parent (project and location) where the cluster will be created.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateClusterRequest
constructor
A new instance of CreateClusterRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateClusterRequest
Returns a new instance of CreateClusterRequest.
3330 3331 3332 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3330 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster ⇒ Google::Apis::ContainerV1beta1::Cluster
A Google Kubernetes Engine cluster.
Corresponds to the JSON property cluster
3308 3309 3310 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3308 def cluster @cluster end |
#parent ⇒ String
The parent (project and location) where the cluster will be created. Specified
in the format projects/*/locations/*.
Corresponds to the JSON property parent
3314 3315 3316 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3314 def parent @parent end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the parent field.
Corresponds to the JSON property projectId
3321 3322 3323 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3321 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the parent field.
Corresponds to the JSON property zone
3328 3329 3330 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3328 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3335 3336 3337 3338 3339 3340 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3335 def update!(**args) @cluster = args[:cluster] if args.key?(:cluster) @parent = args[:parent] if args.key?(:parent) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |