Class: Google::Apis::ContainerV1beta1::CreateClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

CreateClusterRequest creates a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateClusterRequest

Returns a new instance of CreateClusterRequest.



3116
3117
3118
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3116

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusterGoogle::Apis::ContainerV1beta1::Cluster

A Google Kubernetes Engine cluster. Corresponds to the JSON property cluster



3094
3095
3096
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3094

def cluster
  @cluster
end

#parentString

The parent (project and location) where the cluster will be created. Specified in the format projects/*/locations/*. Corresponds to the JSON property parent

Returns:

  • (String)


3100
3101
3102
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3100

def parent
  @parent
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property projectId

Returns:

  • (String)


3107
3108
3109
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3107

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property zone

Returns:

  • (String)


3114
3115
3116
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3114

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3121
3122
3123
3124
3125
3126
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3121

def update!(**args)
  @cluster = args[:cluster] if args.key?(:cluster)
  @parent = args[:parent] if args.key?(:parent)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end