Class: Google::Apis::ContainerV1beta1::CreateNodePoolRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::CreateNodePoolRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
CreateNodePoolRequest creates a node pool for a cluster.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#node_pool ⇒ Google::Apis::ContainerV1beta1::NodePool
NodePool contains the name and configuration for a cluster's node pool.
-
#parent ⇒ String
The parent (project, location, cluster name) where the node pool will be created.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateNodePoolRequest
constructor
A new instance of CreateNodePoolRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateNodePoolRequest
Returns a new instance of CreateNodePoolRequest.
3383 3384 3385 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3383 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster. This field has been deprecated and
replaced by the parent field.
Corresponds to the JSON property clusterId
3351 3352 3353 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3351 def cluster_id @cluster_id end |
#node_pool ⇒ Google::Apis::ContainerV1beta1::NodePool
NodePool contains the name and configuration for a cluster's node pool. Node
pools are a set of nodes (i.e. VM's), with a common configuration and
specification, under the control of the cluster master. They may have a set of
Kubernetes labels applied to them, which may be used to reference them during
pod scheduling. They may also be resized up or down, to accommodate the
workload.
Corresponds to the JSON property nodePool
3361 3362 3363 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3361 def node_pool @node_pool end |
#parent ⇒ String
The parent (project, location, cluster name) where the node pool will be
created. Specified in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property parent
3367 3368 3369 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3367 def parent @parent end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the parent field.
Corresponds to the JSON property projectId
3374 3375 3376 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3374 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the parent field.
Corresponds to the JSON property zone
3381 3382 3383 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3381 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3388 3389 3390 3391 3392 3393 3394 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3388 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @node_pool = args[:node_pool] if args.key?(:node_pool) @parent = args[:parent] if args.key?(:parent) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |