Class: Google::Apis::ContainerV1beta1::CreateNodePoolRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

CreateNodePoolRequest creates a node pool for a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateNodePoolRequest

Returns a new instance of CreateNodePoolRequest.



3169
3170
3171
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3169

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property clusterId

Returns:

  • (String)


3137
3138
3139
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3137

def cluster_id
  @cluster_id
end

#node_poolGoogle::Apis::ContainerV1beta1::NodePool

NodePool contains the name and configuration for a cluster's node pool. Node pools are a set of nodes (i.e. VM's), with a common configuration and specification, under the control of the cluster master. They may have a set of Kubernetes labels applied to them, which may be used to reference them during pod scheduling. They may also be resized up or down, to accommodate the workload. Corresponds to the JSON property nodePool



3147
3148
3149
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3147

def node_pool
  @node_pool
end

#parentString

The parent (project, location, cluster name) where the node pool will be created. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property parent

Returns:

  • (String)


3153
3154
3155
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3153

def parent
  @parent
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property projectId

Returns:

  • (String)


3160
3161
3162
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3160

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property zone

Returns:

  • (String)


3167
3168
3169
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3167

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3174
3175
3176
3177
3178
3179
3180
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3174

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @node_pool = args[:node_pool] if args.key?(:node_pool)
  @parent = args[:parent] if args.key?(:parent)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end