Class: Google::Apis::ContainerV1beta1::CreateNodePoolRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

CreateNodePoolRequest creates a node pool for a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateNodePoolRequest

Returns a new instance of CreateNodePoolRequest.



3119
3120
3121
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3119

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property clusterId

Returns:

  • (String)


3087
3088
3089
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3087

def cluster_id
  @cluster_id
end

#node_poolGoogle::Apis::ContainerV1beta1::NodePool

NodePool contains the name and configuration for a cluster's node pool. Node pools are a set of nodes (i.e. VM's), with a common configuration and specification, under the control of the cluster master. They may have a set of Kubernetes labels applied to them, which may be used to reference them during pod scheduling. They may also be resized up or down, to accommodate the workload. Corresponds to the JSON property nodePool



3097
3098
3099
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3097

def node_pool
  @node_pool
end

#parentString

The parent (project, location, cluster name) where the node pool will be created. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property parent

Returns:

  • (String)


3103
3104
3105
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3103

def parent
  @parent
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property projectId

Returns:

  • (String)


3110
3111
3112
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3110

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property zone

Returns:

  • (String)


3117
3118
3119
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3117

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3124
3125
3126
3127
3128
3129
3130
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3124

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @node_pool = args[:node_pool] if args.key?(:node_pool)
  @parent = args[:parent] if args.key?(:parent)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end