Class: Google::Apis::ContainerV1beta1::CustomImageConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

CustomImageConfig contains the information r

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomImageConfig

Returns a new instance of CustomImageConfig.



3411
3412
3413
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3411

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#imageString

The name of the image to use for this node. Corresponds to the JSON property image

Returns:

  • (String)


3404
3405
3406
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3404

def image
  @image
end

#image_projectString

The project containing the image to use for this node. Corresponds to the JSON property imageProject

Returns:

  • (String)


3409
3410
3411
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3409

def image_project
  @image_project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3416
3417
3418
3419
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3416

def update!(**args)
  @image = args[:image] if args.key?(:image)
  @image_project = args[:image_project] if args.key?(:image_project)
end