Class: Google::Apis::ContainerV1beta1::CustomImageConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::CustomImageConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
CustomImageConfig contains the information r
Instance Attribute Summary collapse
-
#image ⇒ String
The name of the image to use for this node.
-
#image_family ⇒ String
The name of the image family to use for this node.
-
#image_project ⇒ String
The project containing the image to use for this node.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomImageConfig
constructor
A new instance of CustomImageConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomImageConfig
Returns a new instance of CustomImageConfig.
3416 3417 3418 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3416 def initialize(**args) update!(**args) end |
Instance Attribute Details
#image ⇒ String
The name of the image to use for this node.
Corresponds to the JSON property image
3404 3405 3406 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3404 def image @image end |
#image_family ⇒ String
The name of the image family to use for this node.
Corresponds to the JSON property imageFamily
3409 3410 3411 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3409 def image_family @image_family end |
#image_project ⇒ String
The project containing the image to use for this node.
Corresponds to the JSON property imageProject
3414 3415 3416 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3414 def image_project @image_project end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3421 3422 3423 3424 3425 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3421 def update!(**args) @image = args[:image] if args.key?(:image) @image_family = args[:image_family] if args.key?(:image_family) @image_project = args[:image_project] if args.key?(:image_project) end |