Class: Google::Apis::ContainerV1beta1::DnsEndpointConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::DnsEndpointConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
Describes the configuration of a DNS endpoint.
Instance Attribute Summary collapse
-
#allow_external_traffic ⇒ Boolean
(also: #allow_external_traffic?)
Controls whether user traffic is allowed over this endpoint.
-
#enable_k8s_certs_via_dns ⇒ Boolean
(also: #enable_k8s_certs_via_dns?)
Controls whether the k8s certs auth is allowed via DNS.
-
#enable_k8s_tokens_via_dns ⇒ Boolean
(also: #enable_k8s_tokens_via_dns?)
Controls whether the k8s token auth is allowed via DNS.
-
#endpoint ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DnsEndpointConfig
constructor
A new instance of DnsEndpointConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DnsEndpointConfig
Returns a new instance of DnsEndpointConfig.
3251 3252 3253 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3251 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_external_traffic ⇒ Boolean Also known as: allow_external_traffic?
Controls whether user traffic is allowed over this endpoint. Note that Google-
managed services may still use the endpoint even if this is false.
Corresponds to the JSON property allowExternalTraffic
3228 3229 3230 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3228 def allow_external_traffic @allow_external_traffic end |
#enable_k8s_certs_via_dns ⇒ Boolean Also known as: enable_k8s_certs_via_dns?
Controls whether the k8s certs auth is allowed via DNS.
Corresponds to the JSON property enableK8sCertsViaDns
3234 3235 3236 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3234 def enable_k8s_certs_via_dns @enable_k8s_certs_via_dns end |
#enable_k8s_tokens_via_dns ⇒ Boolean Also known as: enable_k8s_tokens_via_dns?
Controls whether the k8s token auth is allowed via DNS.
Corresponds to the JSON property enableK8sTokensViaDns
3240 3241 3242 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3240 def enable_k8s_tokens_via_dns @enable_k8s_tokens_via_dns end |
#endpoint ⇒ String
Output only. The cluster's DNS endpoint configuration. A DNS format address.
This is accessible from the public internet. Ex: uid.us-central1.gke.goog.
Always present, but the behavior may change according to the value of
DNSEndpointConfig.allow_external_traffic.
Corresponds to the JSON property endpoint
3249 3250 3251 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3249 def endpoint @endpoint end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3256 3257 3258 3259 3260 3261 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3256 def update!(**args) @allow_external_traffic = args[:allow_external_traffic] if args.key?(:allow_external_traffic) @enable_k8s_certs_via_dns = args[:enable_k8s_certs_via_dns] if args.key?(:enable_k8s_certs_via_dns) @enable_k8s_tokens_via_dns = args[:enable_k8s_tokens_via_dns] if args.key?(:enable_k8s_tokens_via_dns) @endpoint = args[:endpoint] if args.key?(:endpoint) end |