Class: Google::Apis::ContainerV1beta1::EphemeralLocalSsdProfile
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::EphemeralLocalSsdProfile
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
Swap on the local SSD shared with pod ephemeral storage.
Instance Attribute Summary collapse
-
#swap_size_gib ⇒ Fixnum
Specifies the size of the swap space in gibibytes (GiB).
-
#swap_size_percent ⇒ Fixnum
Specifies the size of the swap space as a percentage of the ephemeral local SSD capacity.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EphemeralLocalSsdProfile
constructor
A new instance of EphemeralLocalSsdProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EphemeralLocalSsdProfile
Returns a new instance of EphemeralLocalSsdProfile.
3569 3570 3571 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3569 def initialize(**args) update!(**args) end |
Instance Attribute Details
#swap_size_gib ⇒ Fixnum
Specifies the size of the swap space in gibibytes (GiB).
Corresponds to the JSON property swapSizeGib
3561 3562 3563 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3561 def swap_size_gib @swap_size_gib end |
#swap_size_percent ⇒ Fixnum
Specifies the size of the swap space as a percentage of the ephemeral local
SSD capacity.
Corresponds to the JSON property swapSizePercent
3567 3568 3569 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3567 def swap_size_percent @swap_size_percent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3574 3575 3576 3577 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3574 def update!(**args) @swap_size_gib = args[:swap_size_gib] if args.key?(:swap_size_gib) @swap_size_percent = args[:swap_size_percent] if args.key?(:swap_size_percent) end |