Class: Google::Apis::ContainerV1beta1::EvictionMinimumReclaim

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Eviction minimum reclaims are the resource amounts of minimum reclaims for each eviction signal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EvictionMinimumReclaim

Returns a new instance of EvictionMinimumReclaim.



3853
3854
3855
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3853

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#imagefs_availableString

Optional. Minimum reclaim for eviction due to imagefs available signal. Only take percentage value for now. Sample format: "10%". Must be <=10%. See https:/ /kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/# eviction-signals Corresponds to the JSON property imagefsAvailable

Returns:

  • (String)


3811
3812
3813
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3811

def imagefs_available
  @imagefs_available
end

#imagefs_inodes_freeString

Optional. Minimum reclaim for eviction due to imagefs inodes free signal. Only take percentage value for now. Sample format: "10%". Must be <=10%. See https:/ /kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/# eviction-signals Corresponds to the JSON property imagefsInodesFree

Returns:

  • (String)


3819
3820
3821
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3819

def imagefs_inodes_free
  @imagefs_inodes_free
end

#memory_availableString

Optional. Minimum reclaim for eviction due to memory available signal. Only take percentage value for now. Sample format: "10%". Must be <=10%. See https:/ /kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/# eviction-signals Corresponds to the JSON property memoryAvailable

Returns:

  • (String)


3827
3828
3829
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3827

def memory_available
  @memory_available
end

#nodefs_availableString

Optional. Minimum reclaim for eviction due to nodefs available signal. Only take percentage value for now. Sample format: "10%". Must be <=10%. See https:/ /kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/# eviction-signals Corresponds to the JSON property nodefsAvailable

Returns:

  • (String)


3835
3836
3837
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3835

def nodefs_available
  @nodefs_available
end

#nodefs_inodes_freeString

Optional. Minimum reclaim for eviction due to nodefs inodes free signal. Only take percentage value for now. Sample format: "10%". Must be <=10%. See https:/ /kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/# eviction-signals Corresponds to the JSON property nodefsInodesFree

Returns:

  • (String)


3843
3844
3845
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3843

def nodefs_inodes_free
  @nodefs_inodes_free
end

#pid_availableString

Optional. Minimum reclaim for eviction due to pid available signal. Only take percentage value for now. Sample format: "10%". Must be <=10%. See https:// kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/# eviction-signals Corresponds to the JSON property pidAvailable

Returns:

  • (String)


3851
3852
3853
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3851

def pid_available
  @pid_available
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3858
3859
3860
3861
3862
3863
3864
3865
# File 'lib/google/apis/container_v1beta1/classes.rb', line 3858

def update!(**args)
  @imagefs_available = args[:imagefs_available] if args.key?(:imagefs_available)
  @imagefs_inodes_free = args[:imagefs_inodes_free] if args.key?(:imagefs_inodes_free)
  @memory_available = args[:memory_available] if args.key?(:memory_available)
  @nodefs_available = args[:nodefs_available] if args.key?(:nodefs_available)
  @nodefs_inodes_free = args[:nodefs_inodes_free] if args.key?(:nodefs_inodes_free)
  @pid_available = args[:pid_available] if args.key?(:pid_available)
end