Class: Google::Apis::ContainerV1beta1::EvictionSignals
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::EvictionSignals
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
Eviction signals are the current state of a particular resource at a specific point in time. The kubelet uses eviction signals to make eviction decisions by comparing the signals to eviction thresholds, which are the minimum amount of the resource that should be available on the node.
Instance Attribute Summary collapse
-
#imagefs_available ⇒ String
Optional.
-
#imagefs_inodes_free ⇒ String
Optional.
-
#memory_available ⇒ String
Optional.
-
#nodefs_available ⇒ String
Optional.
-
#nodefs_inodes_free ⇒ String
Optional.
-
#pid_available ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EvictionSignals
constructor
A new instance of EvictionSignals.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EvictionSignals
Returns a new instance of EvictionSignals.
4262 4263 4264 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4262 def initialize(**args) update!(**args) end |
Instance Attribute Details
#imagefs_available ⇒ String
Optional. Amount of storage available on filesystem that container runtime
uses for storing images layers. If the container filesystem and image
filesystem are not separate, then imagefs can store both image layers and
writeable layers. Defines the amount of "imagefs.available" signal in kubelet.
Default is unset, if not specified in the kubelet config. Sample format: "30%".
Must be >= 15%. See https://kubernetes.io/docs/concepts/scheduling-eviction/
node-pressure-eviction/#eviction-signals
Corresponds to the JSON property imagefsAvailable
4214 4215 4216 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4214 def imagefs_available @imagefs_available end |
#imagefs_inodes_free ⇒ String
Optional. Amount of inodes available on filesystem that container runtime uses
for storing images layers. Defines the amount of "imagefs.inodesFree" signal
in kubelet. Default is unset, if not specified in the kubelet config. Linux
only. Sample format: "30%". Must be >= 5%. See https://kubernetes.io/docs/
concepts/scheduling-eviction/node-pressure-eviction/#eviction-signals
Corresponds to the JSON property imagefsInodesFree
4223 4224 4225 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4223 def imagefs_inodes_free @imagefs_inodes_free end |
#memory_available ⇒ String
Optional. Memory available (i.e. capacity - workingSet), in bytes. Defines the
amount of "memory.available" signal in kubelet. Default is unset, if not
specified in the kubelet config. Format: positive number + unit, e.g. 100Ki,
10Mi, 5Gi. Valid units are Ki, Mi, Gi. Must be >= 100Mi and <= 50% of the node'
s memory. See https://kubernetes.io/docs/concepts/scheduling-eviction/node-
pressure-eviction/#eviction-signals
Corresponds to the JSON property memoryAvailable
4233 4234 4235 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4233 def memory_available @memory_available end |
#nodefs_available ⇒ String
Optional. Amount of storage available on filesystem that kubelet uses for
volumes, daemon logs, etc. Defines the amount of "nodefs.available" signal in
kubelet. Default is unset, if not specified in the kubelet config. Sample
format: "30%". Must be >= 10%. See https://kubernetes.io/docs/concepts/
scheduling-eviction/node-pressure-eviction/#eviction-signals
Corresponds to the JSON property nodefsAvailable
4242 4243 4244 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4242 def nodefs_available @nodefs_available end |
#nodefs_inodes_free ⇒ String
Optional. Amount of inodes available on filesystem that kubelet uses for
volumes, daemon logs, etc. Defines the amount of "nodefs.inodesFree" signal in
kubelet. Default is unset, if not specified in the kubelet config. Linux only.
It takses percentage value for now. Sample format: "30%". Must be >= 5% and <=
50%. See https://kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-
eviction/#eviction-signals
Corresponds to the JSON property nodefsInodesFree
4252 4253 4254 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4252 def nodefs_inodes_free @nodefs_inodes_free end |
#pid_available ⇒ String
Optional. Amount of PID available for pod allocation. Defines the amount of "
pid.available" signal in kubelet. Default is unset, if not specified in the
kubelet config. Sample format: "30%". Must be >= 10%. See https://kubernetes.
io/docs/concepts/scheduling-eviction/node-pressure-eviction/#eviction-signals
Corresponds to the JSON property pidAvailable
4260 4261 4262 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4260 def pid_available @pid_available end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4267 4268 4269 4270 4271 4272 4273 4274 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4267 def update!(**args) @imagefs_available = args[:imagefs_available] if args.key?(:imagefs_available) @imagefs_inodes_free = args[:imagefs_inodes_free] if args.key?(:imagefs_inodes_free) @memory_available = args[:memory_available] if args.key?(:memory_available) @nodefs_available = args[:nodefs_available] if args.key?(:nodefs_available) @nodefs_inodes_free = args[:nodefs_inodes_free] if args.key?(:nodefs_inodes_free) @pid_available = args[:pid_available] if args.key?(:pid_available) end |