Class: Google::Apis::ContainerV1beta1::ExclusionUntilEndOfSupport
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::ExclusionUntilEndOfSupport
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
Defines the maintenance exclusion for the node pool.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
-
#end_time ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExclusionUntilEndOfSupport
constructor
A new instance of ExclusionUntilEndOfSupport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExclusionUntilEndOfSupport
Returns a new instance of ExclusionUntilEndOfSupport.
4300 4301 4302 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4300 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Optional. Indicates whether the exclusion is enabled.
Corresponds to the JSON property enabled
4284 4285 4286 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4284 def enabled @enabled end |
#end_time ⇒ String
Output only. The end time of the maintenance exclusion. It is output only. It
is the cluster control plane version's end of support time, or end of extended
support time when the cluster is on extended support channel.
Corresponds to the JSON property endTime
4292 4293 4294 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4292 def end_time @end_time end |
#start_time ⇒ String
Output only. The start time of the maintenance exclusion. It is output only.
It is the exclusion creation time.
Corresponds to the JSON property startTime
4298 4299 4300 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4298 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4305 4306 4307 4308 4309 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4305 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |