Class: Google::Apis::ContainerV1beta1::ExclusionUntilEndOfSupport
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::ExclusionUntilEndOfSupport
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
Defines the maintenance exclusion for the node pool.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
-
#end_time ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExclusionUntilEndOfSupport
constructor
A new instance of ExclusionUntilEndOfSupport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExclusionUntilEndOfSupport
Returns a new instance of ExclusionUntilEndOfSupport.
4266 4267 4268 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4266 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Optional. Indicates whether the exclusion is enabled.
Corresponds to the JSON property enabled
4250 4251 4252 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4250 def enabled @enabled end |
#end_time ⇒ String
Output only. The end time of the maintenance exclusion. It is output only. It
is the cluster control plane version's end of support time, or end of extended
support time when the cluster is on extended support channel.
Corresponds to the JSON property endTime
4258 4259 4260 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4258 def end_time @end_time end |
#start_time ⇒ String
Output only. The start time of the maintenance exclusion. It is output only.
It is the exclusion creation time.
Corresponds to the JSON property startTime
4264 4265 4266 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4264 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4271 4272 4273 4274 4275 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4271 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |