Class: Google::Apis::ContainerV1beta1::HostConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

HostConfig configures the registry host under a given Server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostConfig

Returns a new instance of HostConfig.



4768
4769
4770
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4768

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#caArray<Google::Apis::ContainerV1beta1::CertificateConfig>

CA configures the registry host certificate. Corresponds to the JSON property ca



4723
4724
4725
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4723

def ca
  @ca
end

#capabilitiesArray<String>

Capabilities represent the capabilities of the registry host, specifying what operations a host is capable of performing. If not set, containerd enables all capabilities by default. Corresponds to the JSON property capabilities

Returns:

  • (Array<String>)


4730
4731
4732
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4730

def capabilities
  @capabilities
end

#clientArray<Google::Apis::ContainerV1beta1::CertificateConfigPair>

Client configures the registry host client certificate and key. Corresponds to the JSON property client



4735
4736
4737
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4735

def client
  @client
end

#dial_timeoutString

Specifies the maximum duration allowed for a connection attempt to complete. A shorter timeout helps reduce delays when falling back to the original registry if the mirror is unreachable. Maximum allowed value is 180s. If not set, containerd sets default 30s. The value should be a decimal number of seconds with an s suffix. Corresponds to the JSON property dialTimeout

Returns:

  • (String)


4744
4745
4746
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4744

def dial_timeout
  @dial_timeout
end

#headerArray<Google::Apis::ContainerV1beta1::RegistryHeader>

Header configures the registry host headers. Corresponds to the JSON property header



4749
4750
4751
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4749

def header
  @header
end

#hostString

Host configures the registry host/mirror. It supports fully qualified domain names (FQDNs) and IP addresses. Specifying scheme, port or path is supported. Scheme can only be http or https. Wildcards are NOT supported. Examples: - my. customdomain.com - https://my.customdomain.com/path - 10.0.1.2:5000 Corresponds to the JSON property host

Returns:

  • (String)


4757
4758
4759
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4757

def host
  @host
end

#override_pathBoolean Also known as: override_path?

OverridePath is used to indicate the host's API root endpoint is defined in the URL path rather than by the API specification. This may be used with non- compliant OCI registries which are missing the /v2 prefix. If not set, containerd sets default false. Corresponds to the JSON property overridePath

Returns:

  • (Boolean)


4765
4766
4767
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4765

def override_path
  @override_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4773
4774
4775
4776
4777
4778
4779
4780
4781
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4773

def update!(**args)
  @ca = args[:ca] if args.key?(:ca)
  @capabilities = args[:capabilities] if args.key?(:capabilities)
  @client = args[:client] if args.key?(:client)
  @dial_timeout = args[:dial_timeout] if args.key?(:dial_timeout)
  @header = args[:header] if args.key?(:header)
  @host = args[:host] if args.key?(:host)
  @override_path = args[:override_path] if args.key?(:override_path)
end