Class: Google::Apis::ContainerV1beta1::HostConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

HostConfig configures the registry host under a given Server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostConfig

Returns a new instance of HostConfig.



4436
4437
4438
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4436

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#caArray<Google::Apis::ContainerV1beta1::CertificateConfig>

CA configures the registry host certificate. Corresponds to the JSON property ca



4392
4393
4394
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4392

def ca
  @ca
end

#capabilitiesArray<String>

Capabilities represent the capabilities of the registry host, specifying what operations a host is capable of performing. If not set, containerd enables all capabilities by default. Corresponds to the JSON property capabilities

Returns:

  • (Array<String>)


4399
4400
4401
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4399

def capabilities
  @capabilities
end

#clientArray<Google::Apis::ContainerV1beta1::CertificateConfigPair>

Client configures the registry host client certificate and key. Corresponds to the JSON property client



4404
4405
4406
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4404

def client
  @client
end

#dial_timeoutString

Specifies the maximum duration allowed for a connection attempt to complete. A shorter timeout helps reduce delays when falling back to the original registry if the mirror is unreachable. Maximum allowed value is 180s. If not set, containerd sets default 30s. The value should be a decimal number of seconds with an s suffix. Corresponds to the JSON property dialTimeout

Returns:

  • (String)


4413
4414
4415
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4413

def dial_timeout
  @dial_timeout
end

#headerArray<Google::Apis::ContainerV1beta1::RegistryHeader>

Header configures the registry host headers. Corresponds to the JSON property header



4418
4419
4420
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4418

def header
  @header
end

#hostString

Host configures the registry host/mirror. It supports fully qualified domain names (FQDN) and IP addresses: Specifying port is supported. Wildcards are NOT supported. Examples: - my.customdomain.com - 10.0.1.2:5000 Corresponds to the JSON property host

Returns:

  • (String)


4425
4426
4427
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4425

def host
  @host
end

#override_pathBoolean Also known as: override_path?

OverridePath is used to indicate the host's API root endpoint is defined in the URL path rather than by the API specification. This may be used with non- compliant OCI registries which are missing the /v2 prefix. If not set, containerd sets default false. Corresponds to the JSON property overridePath

Returns:

  • (Boolean)


4433
4434
4435
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4433

def override_path
  @override_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4441
4442
4443
4444
4445
4446
4447
4448
4449
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4441

def update!(**args)
  @ca = args[:ca] if args.key?(:ca)
  @capabilities = args[:capabilities] if args.key?(:capabilities)
  @client = args[:client] if args.key?(:client)
  @dial_timeout = args[:dial_timeout] if args.key?(:dial_timeout)
  @header = args[:header] if args.key?(:header)
  @host = args[:host] if args.key?(:host)
  @override_path = args[:override_path] if args.key?(:override_path)
end