Class: Google::Apis::ContainerV1beta1::HostConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

HostConfig configures the registry host under a given Server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostConfig

Returns a new instance of HostConfig.



4326
4327
4328
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4326

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#caArray<Google::Apis::ContainerV1beta1::CertificateConfig>

CA configures the registry host certificate. Corresponds to the JSON property ca



4282
4283
4284
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4282

def ca
  @ca
end

#capabilitiesArray<String>

Capabilities represent the capabilities of the registry host, specifying what operations a host is capable of performing. If not set, containerd enables all capabilities by default. Corresponds to the JSON property capabilities

Returns:

  • (Array<String>)


4289
4290
4291
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4289

def capabilities
  @capabilities
end

#clientArray<Google::Apis::ContainerV1beta1::CertificateConfigPair>

Client configures the registry host client certificate and key. Corresponds to the JSON property client



4294
4295
4296
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4294

def client
  @client
end

#dial_timeoutString

Specifies the maximum duration allowed for a connection attempt to complete. A shorter timeout helps reduce delays when falling back to the original registry if the mirror is unreachable. Maximum allowed value is 180s. If not set, containerd sets default 30s. The value should be a decimal number of seconds with an s suffix. Corresponds to the JSON property dialTimeout

Returns:

  • (String)


4303
4304
4305
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4303

def dial_timeout
  @dial_timeout
end

#headerArray<Google::Apis::ContainerV1beta1::RegistryHeader>

Header configures the registry host headers. Corresponds to the JSON property header



4308
4309
4310
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4308

def header
  @header
end

#hostString

Host configures the registry host/mirror. It supports fully qualified domain names (FQDN) and IP addresses: Specifying port is supported. Wildcards are NOT supported. Examples: - my.customdomain.com - 10.0.1.2:5000 Corresponds to the JSON property host

Returns:

  • (String)


4315
4316
4317
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4315

def host
  @host
end

#override_pathBoolean Also known as: override_path?

OverridePath is used to indicate the host's API root endpoint is defined in the URL path rather than by the API specification. This may be used with non- compliant OCI registries which are missing the /v2 prefix. If not set, containerd sets default false. Corresponds to the JSON property overridePath

Returns:

  • (Boolean)


4323
4324
4325
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4323

def override_path
  @override_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4331
4332
4333
4334
4335
4336
4337
4338
4339
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4331

def update!(**args)
  @ca = args[:ca] if args.key?(:ca)
  @capabilities = args[:capabilities] if args.key?(:capabilities)
  @client = args[:client] if args.key?(:client)
  @dial_timeout = args[:dial_timeout] if args.key?(:dial_timeout)
  @header = args[:header] if args.key?(:header)
  @host = args[:host] if args.key?(:host)
  @override_path = args[:override_path] if args.key?(:override_path)
end