Class: Google::Apis::ContainerV1beta1::IpEndpointsConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::IpEndpointsConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
IP endpoints configuration.
Instance Attribute Summary collapse
-
#authorized_networks_config ⇒ Google::Apis::ContainerV1beta1::MasterAuthorizedNetworksConfig
Configuration options for the master authorized networks feature.
-
#enable_public_endpoint ⇒ Boolean
(also: #enable_public_endpoint?)
Controls whether the control plane allows access through a public IP.
-
#enabled ⇒ Boolean
(also: #enabled?)
Controls whether to allow direct IP access.
-
#global_access ⇒ Boolean
(also: #global_access?)
Controls whether the control plane's private endpoint is accessible from sources in other regions.
-
#private_endpoint ⇒ String
Output only.
-
#private_endpoint_subnetwork ⇒ String
Subnet to provision the master's private endpoint during cluster creation.
-
#public_endpoint ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IpEndpointsConfig
constructor
A new instance of IpEndpointsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IpEndpointsConfig
Returns a new instance of IpEndpointsConfig.
5167 5168 5169 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5167 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authorized_networks_config ⇒ Google::Apis::ContainerV1beta1::MasterAuthorizedNetworksConfig
Configuration options for the master authorized networks feature. Enabled
master authorized networks will disallow all external traffic to access
Kubernetes master through HTTPS except traffic from the given CIDR blocks,
Google Compute Engine Public IPs and Google Prod IPs.
Corresponds to the JSON property authorizedNetworksConfig
5123 5124 5125 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5123 def @authorized_networks_config end |
#enable_public_endpoint ⇒ Boolean Also known as: enable_public_endpoint?
Controls whether the control plane allows access through a public IP. It is
invalid to specify both PrivateClusterConfig.enablePrivateEndpoint and this
field at the same time.
Corresponds to the JSON property enablePublicEndpoint
5130 5131 5132 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5130 def enable_public_endpoint @enable_public_endpoint end |
#enabled ⇒ Boolean Also known as: enabled?
Controls whether to allow direct IP access.
Corresponds to the JSON property enabled
5136 5137 5138 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5136 def enabled @enabled end |
#global_access ⇒ Boolean Also known as: global_access?
Controls whether the control plane's private endpoint is accessible from
sources in other regions. It is invalid to specify both
PrivateClusterMasterGlobalAccessConfig.enabled and this field at the same time.
Corresponds to the JSON property globalAccess
5144 5145 5146 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5144 def global_access @global_access end |
#private_endpoint ⇒ String
Output only. The internal IP address of this cluster's control plane. Only
populated if enabled.
Corresponds to the JSON property privateEndpoint
5151 5152 5153 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5151 def private_endpoint @private_endpoint end |
#private_endpoint_subnetwork ⇒ String
Subnet to provision the master's private endpoint during cluster creation.
Specified in projects//regions//subnetworks/* format. It is invalid to
specify both PrivateClusterConfig.privateEndpointSubnetwork and this field at
the same time.
Corresponds to the JSON property privateEndpointSubnetwork
5159 5160 5161 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5159 def private_endpoint_subnetwork @private_endpoint_subnetwork end |
#public_endpoint ⇒ String
Output only. The external IP address of this cluster's control plane. Only
populated if enabled.
Corresponds to the JSON property publicEndpoint
5165 5166 5167 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5165 def public_endpoint @public_endpoint end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5172 5173 5174 5175 5176 5177 5178 5179 5180 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5172 def update!(**args) @authorized_networks_config = args[:authorized_networks_config] if args.key?(:authorized_networks_config) @enable_public_endpoint = args[:enable_public_endpoint] if args.key?(:enable_public_endpoint) @enabled = args[:enabled] if args.key?(:enabled) @global_access = args[:global_access] if args.key?(:global_access) @private_endpoint = args[:private_endpoint] if args.key?(:private_endpoint) @private_endpoint_subnetwork = args[:private_endpoint_subnetwork] if args.key?(:private_endpoint_subnetwork) @public_endpoint = args[:public_endpoint] if args.key?(:public_endpoint) end |