Class: Google::Apis::ContainerV1beta1::LegacyAbac
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::LegacyAbac
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
Configuration for the legacy Attribute Based Access Control authorization mode.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Whether the ABAC authorizer is enabled for this cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LegacyAbac
constructor
A new instance of LegacyAbac.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LegacyAbac
Returns a new instance of LegacyAbac.
4961 4962 4963 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4961 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Whether the ABAC authorizer is enabled for this cluster. When enabled,
identities in the system, including service accounts, nodes, and controllers,
will have statically granted permissions beyond those provided by the RBAC
configuration or IAM.
Corresponds to the JSON property enabled
4958 4959 4960 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4958 def enabled @enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4966 4967 4968 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 4966 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) end |