Class: Google::Apis::ContainerV1beta1::MaintenancePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

MaintenancePolicy defines the maintenance policy to be used for the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MaintenancePolicy

Returns a new instance of MaintenancePolicy.



5887
5888
5889
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disruption_budgetGoogle::Apis::ContainerV1beta1::DisruptionBudget

DisruptionBudget defines the upgrade disruption budget for the cluster control plane. Corresponds to the JSON property disruptionBudget



5871
5872
5873
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5871

def disruption_budget
  @disruption_budget
end

#resource_versionString

A hash identifying the version of this policy, so that updates to fields of the policy won't accidentally undo intermediate changes (and so that users of the API unaware of some fields won't accidentally remove other fields). Make a get() request to the cluster to get the current resource version and include it with requests to set the policy. Corresponds to the JSON property resourceVersion

Returns:

  • (String)


5880
5881
5882
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5880

def resource_version
  @resource_version
end

#windowGoogle::Apis::ContainerV1beta1::MaintenanceWindow

MaintenanceWindow defines the maintenance window to be used for the cluster. Corresponds to the JSON property window



5885
5886
5887
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5885

def window
  @window
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5892
5893
5894
5895
5896
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5892

def update!(**args)
  @disruption_budget = args[:disruption_budget] if args.key?(:disruption_budget)
  @resource_version = args[:resource_version] if args.key?(:resource_version)
  @window = args[:window] if args.key?(:window)
end