Class: Google::Apis::ContainerV1beta1::MaintenancePolicy
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::MaintenancePolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
MaintenancePolicy defines the maintenance policy to be used for the cluster.
Instance Attribute Summary collapse
-
#disruption_budget ⇒ Google::Apis::ContainerV1beta1::DisruptionBudget
DisruptionBudget defines the upgrade disruption budget for the cluster control plane.
-
#resource_version ⇒ String
A hash identifying the version of this policy, so that updates to fields of the policy won't accidentally undo intermediate changes (and so that users of the API unaware of some fields won't accidentally remove other fields).
-
#window ⇒ Google::Apis::ContainerV1beta1::MaintenanceWindow
MaintenanceWindow defines the maintenance window to be used for the cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MaintenancePolicy
constructor
A new instance of MaintenancePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MaintenancePolicy
Returns a new instance of MaintenancePolicy.
5494 5495 5496 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5494 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disruption_budget ⇒ Google::Apis::ContainerV1beta1::DisruptionBudget
DisruptionBudget defines the upgrade disruption budget for the cluster control
plane.
Corresponds to the JSON property disruptionBudget
5478 5479 5480 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5478 def disruption_budget @disruption_budget end |
#resource_version ⇒ String
A hash identifying the version of this policy, so that updates to fields of
the policy won't accidentally undo intermediate changes (and so that users of
the API unaware of some fields won't accidentally remove other fields). Make a
get() request to the cluster to get the current resource version and include
it with requests to set the policy.
Corresponds to the JSON property resourceVersion
5487 5488 5489 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5487 def resource_version @resource_version end |
#window ⇒ Google::Apis::ContainerV1beta1::MaintenanceWindow
MaintenanceWindow defines the maintenance window to be used for the cluster.
Corresponds to the JSON property window
5492 5493 5494 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5492 def window @window end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5499 5500 5501 5502 5503 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5499 def update!(**args) @disruption_budget = args[:disruption_budget] if args.key?(:disruption_budget) @resource_version = args[:resource_version] if args.key?(:resource_version) @window = args[:window] if args.key?(:window) end |