Class: Google::Apis::ContainerV1beta1::MaintenancePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

MaintenancePolicy defines the maintenance policy to be used for the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MaintenancePolicy

Returns a new instance of MaintenancePolicy.



5378
5379
5380
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_versionString

A hash identifying the version of this policy, so that updates to fields of the policy won't accidentally undo intermediate changes (and so that users of the API unaware of some fields won't accidentally remove other fields). Make a get() request to the cluster to get the current resource version and include it with requests to set the policy. Corresponds to the JSON property resourceVersion

Returns:

  • (String)


5371
5372
5373
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5371

def resource_version
  @resource_version
end

#windowGoogle::Apis::ContainerV1beta1::MaintenanceWindow

MaintenanceWindow defines the maintenance window to be used for the cluster. Corresponds to the JSON property window



5376
5377
5378
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5376

def window
  @window
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5383
5384
5385
5386
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5383

def update!(**args)
  @resource_version = args[:resource_version] if args.key?(:resource_version)
  @window = args[:window] if args.key?(:window)
end