Class: Google::Apis::ContainerV1beta1::MasterAuth
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::MasterAuth
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
The authentication information for accessing the master endpoint. Authentication can be done using HTTP basic auth or using client certificates.
Instance Attribute Summary collapse
-
#client_certificate ⇒ String
Output only.
-
#client_certificate_config ⇒ Google::Apis::ContainerV1beta1::ClientCertificateConfig
Configuration for client certificates on the cluster.
-
#client_key ⇒ String
Output only.
-
#cluster_ca_certificate ⇒ String
Output only.
-
#password ⇒ String
The password to use for HTTP basic authentication to the master endpoint.
-
#username ⇒ String
The username to use for HTTP basic authentication to the master endpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MasterAuth
constructor
A new instance of MasterAuth.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MasterAuth
Returns a new instance of MasterAuth.
5655 5656 5657 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5655 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_certificate ⇒ String
Output only. Base64-encoded public certificate used by clients to authenticate
to the cluster endpoint. Issued only if client_certificate_config is set.
Corresponds to the JSON property clientCertificate
5614 5615 5616 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5614 def client_certificate @client_certificate end |
#client_certificate_config ⇒ Google::Apis::ContainerV1beta1::ClientCertificateConfig
Configuration for client certificates on the cluster.
Corresponds to the JSON property clientCertificateConfig
5619 5620 5621 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5619 def client_certificate_config @client_certificate_config end |
#client_key ⇒ String
Output only. Base64-encoded private key used by clients to authenticate to the
cluster endpoint.
Corresponds to the JSON property clientKey
5625 5626 5627 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5625 def client_key @client_key end |
#cluster_ca_certificate ⇒ String
Output only. Base64-encoded public certificate that is the root of trust for
the cluster.
Corresponds to the JSON property clusterCaCertificate
5631 5632 5633 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5631 def cluster_ca_certificate @cluster_ca_certificate end |
#password ⇒ String
The password to use for HTTP basic authentication to the master endpoint.
Because the master endpoint is open to the Internet, you should create a
strong password. If a password is provided for cluster creation, username must
be non-empty. Warning: basic authentication is deprecated, and will be removed
in GKE control plane versions 1.19 and newer. For a list of recommended
authentication methods, see: https://cloud.google.com/kubernetes-engine/docs/
how-to/api-server-authentication
Corresponds to the JSON property password
5642 5643 5644 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5642 def password @password end |
#username ⇒ String
The username to use for HTTP basic authentication to the master endpoint. For
clusters v1.6.0 and later, basic authentication can be disabled by leaving
username unspecified (or setting it to the empty string). Warning: basic
authentication is deprecated, and will be removed in GKE control plane
versions 1.19 and newer. For a list of recommended authentication methods, see:
https://cloud.google.com/kubernetes-engine/docs/how-to/api-server-
authentication
Corresponds to the JSON property username
5653 5654 5655 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5653 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5660 5661 5662 5663 5664 5665 5666 5667 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5660 def update!(**args) @client_certificate = args[:client_certificate] if args.key?(:client_certificate) @client_certificate_config = args[:client_certificate_config] if args.key?(:client_certificate_config) @client_key = args[:client_key] if args.key?(:client_key) @cluster_ca_certificate = args[:cluster_ca_certificate] if args.key?(:cluster_ca_certificate) @password = args[:password] if args.key?(:password) @username = args[:username] if args.key?(:username) end |