Class: Google::Apis::ContainerV1beta1::MasterAuthorizedNetworksConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Configuration options for the master authorized networks feature. Enabled master authorized networks will disallow all external traffic to access Kubernetes master through HTTPS except traffic from the given CIDR blocks, Google Compute Engine Public IPs and Google Prod IPs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MasterAuthorizedNetworksConfig

Returns a new instance of MasterAuthorizedNetworksConfig.



5584
5585
5586
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5584

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cidr_blocksArray<Google::Apis::ContainerV1beta1::CidrBlock>

cidr_blocks define up to 10 external networks that could access Kubernetes master through HTTPS. Corresponds to the JSON property cidrBlocks



5564
5565
5566
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5564

def cidr_blocks
  @cidr_blocks
end

#enabledBoolean Also known as: enabled?

Whether or not master authorized networks is enabled. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


5569
5570
5571
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5569

def enabled
  @enabled
end

#gcp_public_cidrs_access_enabledBoolean Also known as: gcp_public_cidrs_access_enabled?

Whether master is accessible via Google Compute Engine Public IP addresses. Corresponds to the JSON property gcpPublicCidrsAccessEnabled

Returns:

  • (Boolean)


5575
5576
5577
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5575

def gcp_public_cidrs_access_enabled
  @gcp_public_cidrs_access_enabled
end

#private_endpoint_enforcement_enabledBoolean Also known as: private_endpoint_enforcement_enabled?

Whether master authorized networks is enforced on private endpoint or not. Corresponds to the JSON property privateEndpointEnforcementEnabled

Returns:

  • (Boolean)


5581
5582
5583
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5581

def private_endpoint_enforcement_enabled
  @private_endpoint_enforcement_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5589
5590
5591
5592
5593
5594
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5589

def update!(**args)
  @cidr_blocks = args[:cidr_blocks] if args.key?(:cidr_blocks)
  @enabled = args[:enabled] if args.key?(:enabled)
  @gcp_public_cidrs_access_enabled = args[:gcp_public_cidrs_access_enabled] if args.key?(:gcp_public_cidrs_access_enabled)
  @private_endpoint_enforcement_enabled = args[:private_endpoint_enforcement_enabled] if args.key?(:private_endpoint_enforcement_enabled)
end