Class: Google::Apis::ContainerV1beta1::MeshCertificates
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::MeshCertificates
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
Configuration for issuance of mTLS keys and certificates to Kubernetes pods.
Instance Attribute Summary collapse
-
#enable_certificates ⇒ Boolean
(also: #enable_certificates?)
enable_certificates controls issuance of workload mTLS certificates.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MeshCertificates
constructor
A new instance of MeshCertificates.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MeshCertificates
Returns a new instance of MeshCertificates.
5770 5771 5772 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5770 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_certificates ⇒ Boolean Also known as: enable_certificates?
enable_certificates controls issuance of workload mTLS certificates. If set,
the GKE Workload Identity Certificates controller and node agent will be
deployed in the cluster, which can then be configured by creating a
WorkloadCertificateConfig Custom Resource. Requires Workload Identity (
workload_pool must be non-empty).
Corresponds to the JSON property enableCertificates
5767 5768 5769 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5767 def enable_certificates @enable_certificates end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5775 5776 5777 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5775 def update!(**args) @enable_certificates = args[:enable_certificates] if args.key?(:enable_certificates) end |