Class: Google::Apis::ContainerV1beta1::NetworkConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::NetworkConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
NetworkConfig reports the relative names of network & subnetwork.
Instance Attribute Summary collapse
-
#datapath_provider ⇒ String
The desired datapath provider for this cluster.
-
#default_enable_private_nodes ⇒ Boolean
(also: #default_enable_private_nodes?)
Controls whether by default nodes have private IP addresses only.
-
#default_snat_status ⇒ Google::Apis::ContainerV1beta1::DefaultSnatStatus
DefaultSnatStatus contains the desired state of whether default sNAT should be disabled on the cluster.
-
#disable_l4_lb_firewall_reconciliation ⇒ Boolean
(also: #disable_l4_lb_firewall_reconciliation?)
Disable L4 load balancer VPC firewalls to enable firewall policies.
-
#dns_config ⇒ Google::Apis::ContainerV1beta1::DnsConfig
DNSConfig contains the desired set of options for configuring clusterDNS.
-
#enable_cilium_clusterwide_network_policy ⇒ Boolean
(also: #enable_cilium_clusterwide_network_policy?)
Whether CiliumClusterWideNetworkPolicy is enabled on this cluster.
-
#enable_fqdn_network_policy ⇒ Boolean
(also: #enable_fqdn_network_policy?)
Whether FQDN Network Policy is enabled on this cluster.
-
#enable_intra_node_visibility ⇒ Boolean
(also: #enable_intra_node_visibility?)
Whether Intra-node visibility is enabled for this cluster.
-
#enable_l4ilb_subsetting ⇒ Boolean
(also: #enable_l4ilb_subsetting?)
Whether L4ILB Subsetting is enabled for this cluster.
-
#enable_multi_networking ⇒ Boolean
(also: #enable_multi_networking?)
Whether multi-networking is enabled for this cluster.
-
#gateway_api_config ⇒ Google::Apis::ContainerV1beta1::GatewayApiConfig
GatewayAPIConfig contains the desired config of Gateway API on this cluster.
-
#in_transit_encryption_config ⇒ String
Specify the details of in-transit encryption.
-
#network ⇒ String
Output only.
-
#network_performance_config ⇒ Google::Apis::ContainerV1beta1::ClusterNetworkPerformanceConfig
Configuration of all network bandwidth tiers Corresponds to the JSON property
networkPerformanceConfig. -
#private_ipv6_google_access ⇒ String
The desired state of IPv6 connectivity to Google Services.
-
#service_external_ips_config ⇒ Google::Apis::ContainerV1beta1::ServiceExternalIPsConfig
Config to block services with externalIPs field.
-
#subnetwork ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkConfig
constructor
A new instance of NetworkConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkConfig
Returns a new instance of NetworkConfig.
5860 5861 5862 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5860 def initialize(**args) update!(**args) end |
Instance Attribute Details
#datapath_provider ⇒ String
The desired datapath provider for this cluster. By default, uses the IPTables-
based kube-proxy implementation.
Corresponds to the JSON property datapathProvider
5761 5762 5763 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5761 def datapath_provider @datapath_provider end |
#default_enable_private_nodes ⇒ Boolean Also known as: default_enable_private_nodes?
Controls whether by default nodes have private IP addresses only. It is
invalid to specify both PrivateClusterConfig.enablePrivateNodes and this field
at the same time. To update the default setting, use ClusterUpdate.
desired_default_enable_private_nodes
Corresponds to the JSON property defaultEnablePrivateNodes
5769 5770 5771 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5769 def default_enable_private_nodes @default_enable_private_nodes end |
#default_snat_status ⇒ Google::Apis::ContainerV1beta1::DefaultSnatStatus
DefaultSnatStatus contains the desired state of whether default sNAT should be
disabled on the cluster.
Corresponds to the JSON property defaultSnatStatus
5776 5777 5778 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5776 def default_snat_status @default_snat_status end |
#disable_l4_lb_firewall_reconciliation ⇒ Boolean Also known as: disable_l4_lb_firewall_reconciliation?
Disable L4 load balancer VPC firewalls to enable firewall policies.
Corresponds to the JSON property disableL4LbFirewallReconciliation
5781 5782 5783 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5781 def disable_l4_lb_firewall_reconciliation @disable_l4_lb_firewall_reconciliation end |
#dns_config ⇒ Google::Apis::ContainerV1beta1::DnsConfig
DNSConfig contains the desired set of options for configuring clusterDNS.
Corresponds to the JSON property dnsConfig
5787 5788 5789 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5787 def dns_config @dns_config end |
#enable_cilium_clusterwide_network_policy ⇒ Boolean Also known as: enable_cilium_clusterwide_network_policy?
Whether CiliumClusterWideNetworkPolicy is enabled on this cluster.
Corresponds to the JSON property enableCiliumClusterwideNetworkPolicy
5792 5793 5794 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5792 def enable_cilium_clusterwide_network_policy @enable_cilium_clusterwide_network_policy end |
#enable_fqdn_network_policy ⇒ Boolean Also known as: enable_fqdn_network_policy?
Whether FQDN Network Policy is enabled on this cluster.
Corresponds to the JSON property enableFqdnNetworkPolicy
5798 5799 5800 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5798 def enable_fqdn_network_policy @enable_fqdn_network_policy end |
#enable_intra_node_visibility ⇒ Boolean Also known as: enable_intra_node_visibility?
Whether Intra-node visibility is enabled for this cluster. This makes same
node pod to pod traffic visible for VPC network.
Corresponds to the JSON property enableIntraNodeVisibility
5805 5806 5807 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5805 def enable_intra_node_visibility @enable_intra_node_visibility end |
#enable_l4ilb_subsetting ⇒ Boolean Also known as: enable_l4ilb_subsetting?
Whether L4ILB Subsetting is enabled for this cluster.
Corresponds to the JSON property enableL4ilbSubsetting
5811 5812 5813 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5811 def enable_l4ilb_subsetting @enable_l4ilb_subsetting end |
#enable_multi_networking ⇒ Boolean Also known as: enable_multi_networking?
Whether multi-networking is enabled for this cluster.
Corresponds to the JSON property enableMultiNetworking
5817 5818 5819 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5817 def enable_multi_networking @enable_multi_networking end |
#gateway_api_config ⇒ Google::Apis::ContainerV1beta1::GatewayApiConfig
GatewayAPIConfig contains the desired config of Gateway API on this cluster.
Corresponds to the JSON property gatewayApiConfig
5823 5824 5825 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5823 def gateway_api_config @gateway_api_config end |
#in_transit_encryption_config ⇒ String
Specify the details of in-transit encryption.
Corresponds to the JSON property inTransitEncryptionConfig
5828 5829 5830 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5828 def in_transit_encryption_config @in_transit_encryption_config end |
#network ⇒ String
Output only. The relative name of the Google Compute Engine network to which the
cluster is connected. Example: projects/my-project/global/networks/my-network
Corresponds to the JSON property network
5835 5836 5837 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5835 def network @network end |
#network_performance_config ⇒ Google::Apis::ContainerV1beta1::ClusterNetworkPerformanceConfig
Configuration of all network bandwidth tiers
Corresponds to the JSON property networkPerformanceConfig
5840 5841 5842 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5840 def network_performance_config @network_performance_config end |
#private_ipv6_google_access ⇒ String
The desired state of IPv6 connectivity to Google Services. By default, no
private IPv6 access to or from Google Services (all access will be via IPv4)
Corresponds to the JSON property privateIpv6GoogleAccess
5846 5847 5848 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5846 def private_ipv6_google_access @private_ipv6_google_access end |
#service_external_ips_config ⇒ Google::Apis::ContainerV1beta1::ServiceExternalIPsConfig
Config to block services with externalIPs field.
Corresponds to the JSON property serviceExternalIpsConfig
5851 5852 5853 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5851 def service_external_ips_config @service_external_ips_config end |
#subnetwork ⇒ String
Output only. The relative name of the Google Compute Engine subnetwork to which the cluster is connected.
Example: projects/my-project/regions/us-central1/subnetworks/my-subnet
Corresponds to the JSON property subnetwork
5858 5859 5860 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5858 def subnetwork @subnetwork end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5865 5866 5867 5868 5869 5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 5881 5882 5883 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 5865 def update!(**args) @datapath_provider = args[:datapath_provider] if args.key?(:datapath_provider) @default_enable_private_nodes = args[:default_enable_private_nodes] if args.key?(:default_enable_private_nodes) @default_snat_status = args[:default_snat_status] if args.key?(:default_snat_status) @disable_l4_lb_firewall_reconciliation = args[:disable_l4_lb_firewall_reconciliation] if args.key?(:disable_l4_lb_firewall_reconciliation) @dns_config = args[:dns_config] if args.key?(:dns_config) @enable_cilium_clusterwide_network_policy = args[:enable_cilium_clusterwide_network_policy] if args.key?(:enable_cilium_clusterwide_network_policy) @enable_fqdn_network_policy = args[:enable_fqdn_network_policy] if args.key?(:enable_fqdn_network_policy) @enable_intra_node_visibility = args[:enable_intra_node_visibility] if args.key?(:enable_intra_node_visibility) @enable_l4ilb_subsetting = args[:enable_l4ilb_subsetting] if args.key?(:enable_l4ilb_subsetting) @enable_multi_networking = args[:enable_multi_networking] if args.key?(:enable_multi_networking) @gateway_api_config = args[:gateway_api_config] if args.key?(:gateway_api_config) @in_transit_encryption_config = args[:in_transit_encryption_config] if args.key?(:in_transit_encryption_config) @network = args[:network] if args.key?(:network) @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config) @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access) @service_external_ips_config = args[:service_external_ips_config] if args.key?(:service_external_ips_config) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) end |