Class: Google::Apis::ContainerV1beta1::NodeConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Parameters that describe the nodes in a cluster. GKE Autopilot clusters do not recognize parameters in NodeConfig. Use AutoprovisioningNodePoolDefaults instead.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeConfig

Returns a new instance of NodeConfig.



6942
6943
6944
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6942

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acceleratorsArray<Google::Apis::ContainerV1beta1::AcceleratorConfig>

A list of hardware accelerators to be attached to each node. See https://cloud. google.com/compute/docs/gpus for more information about support for GPUs. Corresponds to the JSON property accelerators



6601
6602
6603
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6601

def accelerators
  @accelerators
end

#advanced_machine_featuresGoogle::Apis::ContainerV1beta1::AdvancedMachineFeatures

Specifies options for controlling advanced machine features. Corresponds to the JSON property advancedMachineFeatures



6606
6607
6608
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6606

def advanced_machine_features
  @advanced_machine_features
end

#boot_diskGoogle::Apis::ContainerV1beta1::BootDisk

BootDisk specifies the boot disk configuration for node pools. Corresponds to the JSON property bootDisk



6611
6612
6613
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6611

def boot_disk
  @boot_disk
end

#boot_disk_kms_keyString

The Customer Managed Encryption Key used to encrypt the boot disk attached to each node in the node pool. This should be of the form projects/[ KEY_PROJECT_ID]/locations/[LOCATION]/keyRings/[RING_NAME]/cryptoKeys/[KEY_NAME] . For more information about protecting resources with Cloud KMS Keys please see: https://cloud.google.com/compute/docs/disks/customer-managed-encryption Corresponds to the JSON property bootDiskKmsKey

Returns:

  • (String)


6620
6621
6622
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6620

def boot_disk_kms_key
  @boot_disk_kms_key
end

#confidential_nodesGoogle::Apis::ContainerV1beta1::ConfidentialNodes

ConfidentialNodes is configuration for the confidential nodes feature, which makes nodes run on confidential VMs. Corresponds to the JSON property confidentialNodes



6626
6627
6628
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6626

def confidential_nodes
  @confidential_nodes
end

#consolidation_delayString

Consolidation delay defines duration after which the Cluster Autoscaler can scale down underutilized nodes. If not set, nodes are scaled down by default behavior, i.e. according to the chosen autoscaling profile. Corresponds to the JSON property consolidationDelay

Returns:

  • (String)


6633
6634
6635
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6633

def consolidation_delay
  @consolidation_delay
end

#containerd_configGoogle::Apis::ContainerV1beta1::ContainerdConfig

ContainerdConfig contains configuration to customize containerd. Corresponds to the JSON property containerdConfig



6638
6639
6640
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6638

def containerd_config
  @containerd_config
end

#disk_size_gbFixnum

Size of the disk attached to each node, specified in GB. The smallest allowed disk size is 10GB. If unspecified, the default disk size is 100GB. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


6644
6645
6646
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6644

def disk_size_gb
  @disk_size_gb
end

#disk_typeString

Type of the disk attached to each node (e.g. 'pd-standard', 'pd-ssd' or 'pd- balanced') If unspecified, the default disk type is 'pd-standard' Corresponds to the JSON property diskType

Returns:

  • (String)


6650
6651
6652
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6650

def disk_type
  @disk_type
end

#effective_cgroup_modeString

Output only. effective_cgroup_mode is the cgroup mode actually used by the node pool. It is determined by the cgroup mode specified in the LinuxNodeConfig or the default cgroup mode based on the cluster creation version. Corresponds to the JSON property effectiveCgroupMode

Returns:

  • (String)


6658
6659
6660
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6658

def effective_cgroup_mode
  @effective_cgroup_mode
end

#enable_confidential_storageBoolean Also known as: enable_confidential_storage?

Optional. Reserved for future use. Corresponds to the JSON property enableConfidentialStorage

Returns:

  • (Boolean)


6663
6664
6665
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6663

def enable_confidential_storage
  @enable_confidential_storage
end

#ephemeral_storage_configGoogle::Apis::ContainerV1beta1::EphemeralStorageConfig

EphemeralStorageConfig contains configuration for the ephemeral storage filesystem. Corresponds to the JSON property ephemeralStorageConfig



6670
6671
6672
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6670

def ephemeral_storage_config
  @ephemeral_storage_config
end

#ephemeral_storage_local_ssd_configGoogle::Apis::ContainerV1beta1::EphemeralStorageLocalSsdConfig

EphemeralStorageLocalSsdConfig contains configuration for the node ephemeral storage using Local SSDs. Corresponds to the JSON property ephemeralStorageLocalSsdConfig



6676
6677
6678
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6676

def ephemeral_storage_local_ssd_config
  @ephemeral_storage_local_ssd_config
end

#fast_socketGoogle::Apis::ContainerV1beta1::FastSocket

Configuration of Fast Socket feature. Corresponds to the JSON property fastSocket



6681
6682
6683
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6681

def fast_socket
  @fast_socket
end

#flex_startBoolean Also known as: flex_start?

Flex Start flag for enabling Flex Start VM. Corresponds to the JSON property flexStart

Returns:

  • (Boolean)


6686
6687
6688
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6686

def flex_start
  @flex_start
end

#gcfs_configGoogle::Apis::ContainerV1beta1::GcfsConfig

GcfsConfig contains configurations of Google Container File System. Corresponds to the JSON property gcfsConfig



6692
6693
6694
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6692

def gcfs_config
  @gcfs_config
end

#gpu_direct_configGoogle::Apis::ContainerV1beta1::GpuDirectConfig

GPUDirectConfig specifies the GPU direct strategy on the node pool. Corresponds to the JSON property gpuDirectConfig



6697
6698
6699
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6697

def gpu_direct_config
  @gpu_direct_config
end

#gvnicGoogle::Apis::ContainerV1beta1::VirtualNic

Configuration of gVNIC feature. Corresponds to the JSON property gvnic



6702
6703
6704
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6702

def gvnic
  @gvnic
end

#host_maintenance_policyGoogle::Apis::ContainerV1beta1::HostMaintenancePolicy

HostMaintenancePolicy contains the maintenance policy for the hosts on which the GKE VMs run on. Corresponds to the JSON property hostMaintenancePolicy



6708
6709
6710
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6708

def host_maintenance_policy
  @host_maintenance_policy
end

#image_typeString

The image type to use for this node. Note that for a given image type, the latest version of it will be used. Please see https://cloud.google.com/ kubernetes-engine/docs/concepts/node-images for available image types. Corresponds to the JSON property imageType

Returns:

  • (String)


6715
6716
6717
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6715

def image_type
  @image_type
end

#kubelet_configGoogle::Apis::ContainerV1beta1::NodeKubeletConfig

Node kubelet configs. Corresponds to the JSON property kubeletConfig



6720
6721
6722
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6720

def kubelet_config
  @kubelet_config
end

#labelsHash<String,String>

The Kubernetes labels (key/value pairs) to apply to each node. The values in this field are added to the set of default labels Kubernetes applies to nodes. This field has the following restrictions: * Labels must use a valid Kubernetes syntax and character set, as defined in https://kubernetes.io/docs/ concepts/overview/working-with-objects/labels/#syntax-and-character-set. * This field supports up to 1,024 total characters in a single request. Depending on the Kubernetes version, keys in this field might conflict with the keys of the default labels, which might change which of your labels are applied to the nodes. Assume that the behavior is unpredictable and avoid label key conflicts. For more information about the default labels, see: https: //kubernetes.io/docs/reference/labels-annotations-taints/ Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6735
6736
6737
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6735

def labels
  @labels
end

#linux_node_configGoogle::Apis::ContainerV1beta1::LinuxNodeConfig

Parameters that can be configured on Linux nodes. Corresponds to the JSON property linuxNodeConfig



6740
6741
6742
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6740

def linux_node_config
  @linux_node_config
end

#local_nvme_ssd_block_configGoogle::Apis::ContainerV1beta1::LocalNvmeSsdBlockConfig

LocalNvmeSsdBlockConfig contains configuration for using raw-block local NVMe SSDs Corresponds to the JSON property localNvmeSsdBlockConfig



6746
6747
6748
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6746

def local_nvme_ssd_block_config
  @local_nvme_ssd_block_config
end

#local_ssd_countFixnum

The number of local SSD disks to be attached to the node. The limit for this value is dependent upon the maximum number of disks available on a machine per zone. See: https://cloud.google.com/compute/docs/disks/local-ssd for more information. Corresponds to the JSON property localSsdCount

Returns:

  • (Fixnum)


6754
6755
6756
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6754

def local_ssd_count
  @local_ssd_count
end

#local_ssd_encryption_modeString

Specifies which method should be used for encrypting the Local SSDs attached to the node. Corresponds to the JSON property localSsdEncryptionMode

Returns:

  • (String)


6760
6761
6762
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6760

def local_ssd_encryption_mode
  @local_ssd_encryption_mode
end

#logging_configGoogle::Apis::ContainerV1beta1::NodePoolLoggingConfig

NodePoolLoggingConfig specifies logging configuration for node pools. Corresponds to the JSON property loggingConfig



6765
6766
6767
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6765

def logging_config
  @logging_config
end

#machine_typeString

The name of a Google Compute Engine machine type. If unspecified, the default machine type is e2- medium. Corresponds to the JSON property machineType

Returns:

  • (String)


6772
6773
6774
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6772

def machine_type
  @machine_type
end

#max_run_durationString

The maximum duration for the nodes to exist. If unspecified, the nodes can exist indefinitely. Corresponds to the JSON property maxRunDuration

Returns:

  • (String)


6778
6779
6780
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6778

def max_run_duration
  @max_run_duration
end

#metadataHash<String,String>

The metadata key/value pairs assigned to instances in the cluster. Keys must conform to the regexp [a-zA-Z0-9-_]+ and be less than 128 bytes in length. These are reflected as part of a URL in the metadata server. Additionally, to avoid ambiguity, keys must not conflict with any other metadata keys for the project or be one of the reserved keys: - "cluster-location" - "cluster-name" - "cluster-uid" - "configure-sh" - "containerd-configure-sh" - "enable-oslogin"

  • "gci-ensure-gke-docker" - "gci-metrics-enabled" - "gci-update-strategy" - " instance-template" - "kube-env" - "startup-script" - "user-data" - "disable- address-manager" - "windows-startup-script-ps1" - "common-psm1" - "k8s-node- setup-psm1" - "install-ssh-psm1" - "user-profile-psm1" Values are free-form strings, and only have meaning as interpreted by the image running in the instance. The only restriction placed on them is that each value's size must be less than or equal to 32 KB. The total size of all keys and values must be less than 512 KB. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


6796
6797
6798
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6796

def 
  @metadata
end

#min_cpu_platformString

Minimum CPU platform to be used by this instance. The instance may be scheduled on the specified or newer CPU platform. Applicable values are the friendly names of CPU platforms, such as minCpuPlatform: "Intel Haswell" or minCpuPlatform: "Intel Sandy Bridge". For more information, read how to specify min CPU platform. Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


6806
6807
6808
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6806

def min_cpu_platform
  @min_cpu_platform
end

#node_groupString

Setting this field will assign instances of this pool to run on the specified node group. This is useful for running workloads on sole tenant nodes. Corresponds to the JSON property nodeGroup

Returns:

  • (String)


6813
6814
6815
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6813

def node_group
  @node_group
end

#node_image_configGoogle::Apis::ContainerV1beta1::CustomImageConfig

CustomImageConfig contains the information r Corresponds to the JSON property nodeImageConfig



6818
6819
6820
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6818

def node_image_config
  @node_image_config
end

#oauth_scopesArray<String>

The set of Google API scopes to be made available on all of the node VMs under the "default" service account. The following scopes are recommended, but not required, and by default are not included: * https://www.googleapis.com/auth/ compute is required for mounting persistent storage on your nodes. * https:// www.googleapis.com/auth/devstorage.read_only is required for communicating with gcr.io (the Artifact Registry). If unspecified, no scopes are added, unless Cloud Logging or Cloud Monitoring are enabled, in which case their required scopes will be added. Corresponds to the JSON property oauthScopes

Returns:

  • (Array<String>)


6831
6832
6833
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6831

def oauth_scopes
  @oauth_scopes
end

#preemptibleBoolean Also known as: preemptible?

Whether the nodes are created as preemptible VM instances. See: https://cloud. google.com/compute/docs/instances/preemptible for more information about preemptible VM instances. Corresponds to the JSON property preemptible

Returns:

  • (Boolean)


6838
6839
6840
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6838

def preemptible
  @preemptible
end

#reservation_affinityGoogle::Apis::ContainerV1beta1::ReservationAffinity

ReservationAffinity is the configuration of desired reservation which instances could take capacity from. Corresponds to the JSON property reservationAffinity



6846
6847
6848
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6846

def reservation_affinity
  @reservation_affinity
end

#resource_labelsHash<String,String>

The resource labels for the node pool to use to annotate any related Google Compute Engine resources. Corresponds to the JSON property resourceLabels

Returns:

  • (Hash<String,String>)


6852
6853
6854
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6852

def resource_labels
  @resource_labels
end

#resource_manager_tagsGoogle::Apis::ContainerV1beta1::ResourceManagerTags

A map of resource manager tag keys and values to be attached to the nodes for managing Compute Engine firewalls using Network Firewall Policies. Tags must be according to specifications in https://cloud.google.com/vpc/docs/tags- firewalls-overview#specifications. A maximum of 5 tag key-value pairs can be specified. Existing tags will be replaced with new values. Corresponds to the JSON property resourceManagerTags



6861
6862
6863
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6861

def resource_manager_tags
  @resource_manager_tags
end

#sandbox_configGoogle::Apis::ContainerV1beta1::SandboxConfig

SandboxConfig contains configurations of the sandbox to use for the node. Corresponds to the JSON property sandboxConfig



6866
6867
6868
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6866

def sandbox_config
  @sandbox_config
end

#secondary_boot_disk_update_strategyGoogle::Apis::ContainerV1beta1::SecondaryBootDiskUpdateStrategy

SecondaryBootDiskUpdateStrategy is a placeholder which will be extended in the future to define different options for updating secondary boot disks. Corresponds to the JSON property secondaryBootDiskUpdateStrategy



6872
6873
6874
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6872

def secondary_boot_disk_update_strategy
  @secondary_boot_disk_update_strategy
end

#secondary_boot_disksArray<Google::Apis::ContainerV1beta1::SecondaryBootDisk>

List of secondary boot disks attached to the nodes. Corresponds to the JSON property secondaryBootDisks



6877
6878
6879
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6877

def secondary_boot_disks
  @secondary_boot_disks
end

#service_accountString

The Google Cloud Platform Service Account to be used by the node VMs. Specify the email address of the Service Account; otherwise, if no Service Account is specified, the "default" service account is used. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


6884
6885
6886
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6884

def 
  @service_account
end

#shielded_instance_configGoogle::Apis::ContainerV1beta1::ShieldedInstanceConfig

A set of Shielded Instance options. Corresponds to the JSON property shieldedInstanceConfig



6889
6890
6891
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6889

def shielded_instance_config
  @shielded_instance_config
end

#sole_tenant_configGoogle::Apis::ContainerV1beta1::SoleTenantConfig

SoleTenantConfig contains the NodeAffinities to specify what shared sole tenant node groups should back the node pool. Corresponds to the JSON property soleTenantConfig



6895
6896
6897
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6895

def sole_tenant_config
  @sole_tenant_config
end

#spotBoolean Also known as: spot?

Spot flag for enabling Spot VM, which is a rebrand of the existing preemptible flag. Corresponds to the JSON property spot

Returns:

  • (Boolean)


6901
6902
6903
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6901

def spot
  @spot
end

#storage_poolsArray<String>

List of Storage Pools where boot disks are provisioned. Corresponds to the JSON property storagePools

Returns:

  • (Array<String>)


6907
6908
6909
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6907

def storage_pools
  @storage_pools
end

#tagsArray<String>

The list of instance tags applied to all nodes. Tags are used to identify valid sources or targets for network firewalls and are specified by the client during cluster or node pool creation. Each tag within the list must comply with RFC1035. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


6915
6916
6917
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6915

def tags
  @tags
end

#taint_configGoogle::Apis::ContainerV1beta1::TaintConfig

TaintConfig contains the configuration for the taints of the node pool. Corresponds to the JSON property taintConfig



6920
6921
6922
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6920

def taint_config
  @taint_config
end

#taintsArray<Google::Apis::ContainerV1beta1::NodeTaint>

List of kubernetes taints to be applied to each node. For more information, including usage and the valid values, see: https://kubernetes.io/docs/concepts/ configuration/taint-and-toleration/ Corresponds to the JSON property taints



6927
6928
6929
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6927

def taints
  @taints
end

#windows_node_configGoogle::Apis::ContainerV1beta1::WindowsNodeConfig

Parameters that can be configured on Windows nodes. Windows Node Config that define the parameters that will be used to configure the Windows node pool settings. Corresponds to the JSON property windowsNodeConfig



6934
6935
6936
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6934

def windows_node_config
  @windows_node_config
end

#workload_metadata_configGoogle::Apis::ContainerV1beta1::WorkloadMetadataConfig

WorkloadMetadataConfig defines the metadata configuration to expose to workloads on the node pool. Corresponds to the JSON property workloadMetadataConfig



6940
6941
6942
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6940

def 
  @workload_metadata_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6947
6948
6949
6950
6951
6952
6953
6954
6955
6956
6957
6958
6959
6960
6961
6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
6988
6989
6990
6991
6992
6993
6994
6995
6996
6997
6998
6999
# File 'lib/google/apis/container_v1beta1/classes.rb', line 6947

def update!(**args)
  @accelerators = args[:accelerators] if args.key?(:accelerators)
  @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features)
  @boot_disk = args[:boot_disk] if args.key?(:boot_disk)
  @boot_disk_kms_key = args[:boot_disk_kms_key] if args.key?(:boot_disk_kms_key)
  @confidential_nodes = args[:confidential_nodes] if args.key?(:confidential_nodes)
  @consolidation_delay = args[:consolidation_delay] if args.key?(:consolidation_delay)
  @containerd_config = args[:containerd_config] if args.key?(:containerd_config)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @disk_type = args[:disk_type] if args.key?(:disk_type)
  @effective_cgroup_mode = args[:effective_cgroup_mode] if args.key?(:effective_cgroup_mode)
  @enable_confidential_storage = args[:enable_confidential_storage] if args.key?(:enable_confidential_storage)
  @ephemeral_storage_config = args[:ephemeral_storage_config] if args.key?(:ephemeral_storage_config)
  @ephemeral_storage_local_ssd_config = args[:ephemeral_storage_local_ssd_config] if args.key?(:ephemeral_storage_local_ssd_config)
  @fast_socket = args[:fast_socket] if args.key?(:fast_socket)
  @flex_start = args[:flex_start] if args.key?(:flex_start)
  @gcfs_config = args[:gcfs_config] if args.key?(:gcfs_config)
  @gpu_direct_config = args[:gpu_direct_config] if args.key?(:gpu_direct_config)
  @gvnic = args[:gvnic] if args.key?(:gvnic)
  @host_maintenance_policy = args[:host_maintenance_policy] if args.key?(:host_maintenance_policy)
  @image_type = args[:image_type] if args.key?(:image_type)
  @kubelet_config = args[:kubelet_config] if args.key?(:kubelet_config)
  @labels = args[:labels] if args.key?(:labels)
  @linux_node_config = args[:linux_node_config] if args.key?(:linux_node_config)
  @local_nvme_ssd_block_config = args[:local_nvme_ssd_block_config] if args.key?(:local_nvme_ssd_block_config)
  @local_ssd_count = args[:local_ssd_count] if args.key?(:local_ssd_count)
  @local_ssd_encryption_mode = args[:local_ssd_encryption_mode] if args.key?(:local_ssd_encryption_mode)
  @logging_config = args[:logging_config] if args.key?(:logging_config)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @max_run_duration = args[:max_run_duration] if args.key?(:max_run_duration)
  @metadata = args[:metadata] if args.key?(:metadata)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @node_group = args[:node_group] if args.key?(:node_group)
  @node_image_config = args[:node_image_config] if args.key?(:node_image_config)
  @oauth_scopes = args[:oauth_scopes] if args.key?(:oauth_scopes)
  @preemptible = args[:preemptible] if args.key?(:preemptible)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @resource_labels = args[:resource_labels] if args.key?(:resource_labels)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
  @sandbox_config = args[:sandbox_config] if args.key?(:sandbox_config)
  @secondary_boot_disk_update_strategy = args[:secondary_boot_disk_update_strategy] if args.key?(:secondary_boot_disk_update_strategy)
  @secondary_boot_disks = args[:secondary_boot_disks] if args.key?(:secondary_boot_disks)
  @service_account = args[:service_account] if args.key?(:service_account)
  @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config)
  @sole_tenant_config = args[:sole_tenant_config] if args.key?(:sole_tenant_config)
  @spot = args[:spot] if args.key?(:spot)
  @storage_pools = args[:storage_pools] if args.key?(:storage_pools)
  @tags = args[:tags] if args.key?(:tags)
  @taint_config = args[:taint_config] if args.key?(:taint_config)
  @taints = args[:taints] if args.key?(:taints)
  @windows_node_config = args[:windows_node_config] if args.key?(:windows_node_config)
  @workload_metadata_config = args[:workload_metadata_config] if args.key?(:workload_metadata_config)
end