Class: Google::Apis::ContainerV1beta1::NodePoolAutoConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::NodePoolAutoConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
node pool configs that apply to all auto-provisioned node pools in autopilot clusters and node auto-provisioning enabled clusters
Instance Attribute Summary collapse
-
#linux_node_config ⇒ Google::Apis::ContainerV1beta1::LinuxNodeConfig
Parameters that can be configured on Linux nodes.
-
#network_tags ⇒ Google::Apis::ContainerV1beta1::NetworkTags
Collection of Compute Engine network tags that can be applied to a node's underlying VM instance.
-
#node_kubelet_config ⇒ Google::Apis::ContainerV1beta1::NodeKubeletConfig
Node kubelet configs.
-
#resource_manager_tags ⇒ Google::Apis::ContainerV1beta1::ResourceManagerTags
A map of resource manager tag keys and values to be attached to the nodes for managing Compute Engine firewalls using Network Firewall Policies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodePoolAutoConfig
constructor
A new instance of NodePoolAutoConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodePoolAutoConfig
Returns a new instance of NodePoolAutoConfig.
7856 7857 7858 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7856 def initialize(**args) update!(**args) end |
Instance Attribute Details
#linux_node_config ⇒ Google::Apis::ContainerV1beta1::LinuxNodeConfig
Parameters that can be configured on Linux nodes.
Corresponds to the JSON property linuxNodeConfig
7833 7834 7835 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7833 def linux_node_config @linux_node_config end |
#network_tags ⇒ Google::Apis::ContainerV1beta1::NetworkTags
Collection of Compute Engine network tags that can be applied to a node's
underlying VM instance. (See tags field in NodeConfig).
Corresponds to the JSON property networkTags
7840 7841 7842 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7840 def @network_tags end |
#node_kubelet_config ⇒ Google::Apis::ContainerV1beta1::NodeKubeletConfig
Node kubelet configs.
Corresponds to the JSON property nodeKubeletConfig
7845 7846 7847 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7845 def node_kubelet_config @node_kubelet_config end |
#resource_manager_tags ⇒ Google::Apis::ContainerV1beta1::ResourceManagerTags
A map of resource manager tag keys and values to be attached to the nodes for
managing Compute Engine firewalls using Network Firewall Policies. Tags must
be according to specifications in https://cloud.google.com/vpc/docs/tags-
firewalls-overview#specifications. A maximum of 5 tag key-value pairs can be
specified. Existing tags will be replaced with new values.
Corresponds to the JSON property resourceManagerTags
7854 7855 7856 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7854 def @resource_manager_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7861 7862 7863 7864 7865 7866 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7861 def update!(**args) @linux_node_config = args[:linux_node_config] if args.key?(:linux_node_config) @network_tags = args[:network_tags] if args.key?(:network_tags) @node_kubelet_config = args[:node_kubelet_config] if args.key?(:node_kubelet_config) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) end |