Class: Google::Apis::ContainerV1beta1::NodePoolAutoConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

node pool configs that apply to all auto-provisioned node pools in autopilot clusters and node auto-provisioning enabled clusters

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodePoolAutoConfig

Returns a new instance of NodePoolAutoConfig.



7275
7276
7277
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7275

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#linux_node_configGoogle::Apis::ContainerV1beta1::LinuxNodeConfig

Parameters that can be configured on Linux nodes. Corresponds to the JSON property linuxNodeConfig



7252
7253
7254
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7252

def linux_node_config
  @linux_node_config
end

#network_tagsGoogle::Apis::ContainerV1beta1::NetworkTags

Collection of Compute Engine network tags that can be applied to a node's underlying VM instance. (See tags field in NodeConfig). Corresponds to the JSON property networkTags



7259
7260
7261
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7259

def network_tags
  @network_tags
end

#node_kubelet_configGoogle::Apis::ContainerV1beta1::NodeKubeletConfig

Node kubelet configs. Corresponds to the JSON property nodeKubeletConfig



7264
7265
7266
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7264

def node_kubelet_config
  @node_kubelet_config
end

#resource_manager_tagsGoogle::Apis::ContainerV1beta1::ResourceManagerTags

A map of resource manager tag keys and values to be attached to the nodes for managing Compute Engine firewalls using Network Firewall Policies. Tags must be according to specifications in https://cloud.google.com/vpc/docs/tags- firewalls-overview#specifications. A maximum of 5 tag key-value pairs can be specified. Existing tags will be replaced with new values. Corresponds to the JSON property resourceManagerTags



7273
7274
7275
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7273

def resource_manager_tags
  @resource_manager_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7280
7281
7282
7283
7284
7285
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7280

def update!(**args)
  @linux_node_config = args[:linux_node_config] if args.key?(:linux_node_config)
  @network_tags = args[:network_tags] if args.key?(:network_tags)
  @node_kubelet_config = args[:node_kubelet_config] if args.key?(:node_kubelet_config)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
end