Class: Google::Apis::ContainerV1beta1::NodePoolAutoscaling

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

NodePoolAutoscaling contains information required by cluster autoscaler to adjust the size of the node pool to the current cluster usage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodePoolAutoscaling

Returns a new instance of NodePoolAutoscaling.



7836
7837
7838
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7836

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoprovisionedBoolean Also known as: autoprovisioned?

Can this node pool be deleted automatically. Corresponds to the JSON property autoprovisioned

Returns:

  • (Boolean)


7795
7796
7797
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7795

def autoprovisioned
  @autoprovisioned
end

#enabledBoolean Also known as: enabled?

Is autoscaling enabled for this node pool. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


7801
7802
7803
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7801

def enabled
  @enabled
end

#location_policyString

Location policy used when scaling up a node pool. Corresponds to the JSON property locationPolicy

Returns:

  • (String)


7807
7808
7809
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7807

def location_policy
  @location_policy
end

#max_node_countFixnum

Maximum number of nodes for one location in the node pool. Must be >= min_node_count. There has to be enough quota to scale up the cluster. Corresponds to the JSON property maxNodeCount

Returns:

  • (Fixnum)


7813
7814
7815
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7813

def max_node_count
  @max_node_count
end

#min_node_countFixnum

Minimum number of nodes for one location in the node pool. Must be greater than or equal to 0 and less than or equal to max_node_count. Corresponds to the JSON property minNodeCount

Returns:

  • (Fixnum)


7819
7820
7821
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7819

def min_node_count
  @min_node_count
end

#total_max_node_countFixnum

Maximum number of nodes in the node pool. Must be greater than or equal to total_min_node_count. There has to be enough quota to scale up the cluster. The total_*_node_count fields are mutually exclusive with the *_node_count fields. Corresponds to the JSON property totalMaxNodeCount

Returns:

  • (Fixnum)


7827
7828
7829
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7827

def total_max_node_count
  @total_max_node_count
end

#total_min_node_countFixnum

Minimum number of nodes in the node pool. Must be greater than or equal to 0 and less than or equal to total_max_node_count. The total_*_node_count fields are mutually exclusive with the *_node_count fields. Corresponds to the JSON property totalMinNodeCount

Returns:

  • (Fixnum)


7834
7835
7836
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7834

def total_min_node_count
  @total_min_node_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7841
7842
7843
7844
7845
7846
7847
7848
7849
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7841

def update!(**args)
  @autoprovisioned = args[:autoprovisioned] if args.key?(:autoprovisioned)
  @enabled = args[:enabled] if args.key?(:enabled)
  @location_policy = args[:location_policy] if args.key?(:location_policy)
  @max_node_count = args[:max_node_count] if args.key?(:max_node_count)
  @min_node_count = args[:min_node_count] if args.key?(:min_node_count)
  @total_max_node_count = args[:total_max_node_count] if args.key?(:total_max_node_count)
  @total_min_node_count = args[:total_min_node_count] if args.key?(:total_min_node_count)
end