Class: Google::Apis::ContainerV1beta1::NodePoolAutoscaling

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

NodePoolAutoscaling contains information required by cluster autoscaler to adjust the size of the node pool to the current cluster usage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodePoolAutoscaling

Returns a new instance of NodePoolAutoscaling.



7823
7824
7825
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7823

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoprovisionedBoolean Also known as: autoprovisioned?

Can this node pool be deleted automatically. Corresponds to the JSON property autoprovisioned

Returns:

  • (Boolean)


7782
7783
7784
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7782

def autoprovisioned
  @autoprovisioned
end

#enabledBoolean Also known as: enabled?

Is autoscaling enabled for this node pool. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


7788
7789
7790
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7788

def enabled
  @enabled
end

#location_policyString

Location policy used when scaling up a node pool. Corresponds to the JSON property locationPolicy

Returns:

  • (String)


7794
7795
7796
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7794

def location_policy
  @location_policy
end

#max_node_countFixnum

Maximum number of nodes for one location in the node pool. Must be >= min_node_count. There has to be enough quota to scale up the cluster. Corresponds to the JSON property maxNodeCount

Returns:

  • (Fixnum)


7800
7801
7802
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7800

def max_node_count
  @max_node_count
end

#min_node_countFixnum

Minimum number of nodes for one location in the node pool. Must be greater than or equal to 0 and less than or equal to max_node_count. Corresponds to the JSON property minNodeCount

Returns:

  • (Fixnum)


7806
7807
7808
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7806

def min_node_count
  @min_node_count
end

#total_max_node_countFixnum

Maximum number of nodes in the node pool. Must be greater than or equal to total_min_node_count. There has to be enough quota to scale up the cluster. The total_*_node_count fields are mutually exclusive with the *_node_count fields. Corresponds to the JSON property totalMaxNodeCount

Returns:

  • (Fixnum)


7814
7815
7816
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7814

def total_max_node_count
  @total_max_node_count
end

#total_min_node_countFixnum

Minimum number of nodes in the node pool. Must be greater than or equal to 0 and less than or equal to total_max_node_count. The total_*_node_count fields are mutually exclusive with the *_node_count fields. Corresponds to the JSON property totalMinNodeCount

Returns:

  • (Fixnum)


7821
7822
7823
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7821

def total_min_node_count
  @total_min_node_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7828
7829
7830
7831
7832
7833
7834
7835
7836
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7828

def update!(**args)
  @autoprovisioned = args[:autoprovisioned] if args.key?(:autoprovisioned)
  @enabled = args[:enabled] if args.key?(:enabled)
  @location_policy = args[:location_policy] if args.key?(:location_policy)
  @max_node_count = args[:max_node_count] if args.key?(:max_node_count)
  @min_node_count = args[:min_node_count] if args.key?(:min_node_count)
  @total_max_node_count = args[:total_max_node_count] if args.key?(:total_max_node_count)
  @total_min_node_count = args[:total_min_node_count] if args.key?(:total_min_node_count)
end