Class: Google::Apis::ContainerV1beta1::NodePoolAutoscaling
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::NodePoolAutoscaling
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
NodePoolAutoscaling contains information required by cluster autoscaler to adjust the size of the node pool to the current cluster usage.
Instance Attribute Summary collapse
-
#autoprovisioned ⇒ Boolean
(also: #autoprovisioned?)
Can this node pool be deleted automatically.
-
#enabled ⇒ Boolean
(also: #enabled?)
Is autoscaling enabled for this node pool.
-
#location_policy ⇒ String
Location policy used when scaling up a nodepool.
-
#max_node_count ⇒ Fixnum
Maximum number of nodes for one location in the node pool.
-
#min_node_count ⇒ Fixnum
Minimum number of nodes for one location in the node pool.
-
#total_max_node_count ⇒ Fixnum
Maximum number of nodes in the node pool.
-
#total_min_node_count ⇒ Fixnum
Minimum number of nodes in the node pool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodePoolAutoscaling
constructor
A new instance of NodePoolAutoscaling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodePoolAutoscaling
Returns a new instance of NodePoolAutoscaling.
7173 7174 7175 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7173 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoprovisioned ⇒ Boolean Also known as: autoprovisioned?
Can this node pool be deleted automatically.
Corresponds to the JSON property autoprovisioned
7132 7133 7134 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7132 def autoprovisioned @autoprovisioned end |
#enabled ⇒ Boolean Also known as: enabled?
Is autoscaling enabled for this node pool.
Corresponds to the JSON property enabled
7138 7139 7140 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7138 def enabled @enabled end |
#location_policy ⇒ String
Location policy used when scaling up a nodepool.
Corresponds to the JSON property locationPolicy
7144 7145 7146 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7144 def location_policy @location_policy end |
#max_node_count ⇒ Fixnum
Maximum number of nodes for one location in the node pool. Must be >=
min_node_count. There has to be enough quota to scale up the cluster.
Corresponds to the JSON property maxNodeCount
7150 7151 7152 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7150 def max_node_count @max_node_count end |
#min_node_count ⇒ Fixnum
Minimum number of nodes for one location in the node pool. Must be greater
than or equal to 0 and less than or equal to max_node_count.
Corresponds to the JSON property minNodeCount
7156 7157 7158 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7156 def min_node_count @min_node_count end |
#total_max_node_count ⇒ Fixnum
Maximum number of nodes in the node pool. Must be greater than or equal to
total_min_node_count. There has to be enough quota to scale up the cluster.
The total_*_node_count fields are mutually exclusive with the *_node_count
fields.
Corresponds to the JSON property totalMaxNodeCount
7164 7165 7166 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7164 def total_max_node_count @total_max_node_count end |
#total_min_node_count ⇒ Fixnum
Minimum number of nodes in the node pool. Must be greater than or equal to 0
and less than or equal to total_max_node_count. The total_*_node_count fields
are mutually exclusive with the *_node_count fields.
Corresponds to the JSON property totalMinNodeCount
7171 7172 7173 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7171 def total_min_node_count @total_min_node_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7178 7179 7180 7181 7182 7183 7184 7185 7186 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7178 def update!(**args) @autoprovisioned = args[:autoprovisioned] if args.key?(:autoprovisioned) @enabled = args[:enabled] if args.key?(:enabled) @location_policy = args[:location_policy] if args.key?(:location_policy) @max_node_count = args[:max_node_count] if args.key?(:max_node_count) @min_node_count = args[:min_node_count] if args.key?(:min_node_count) @total_max_node_count = args[:total_max_node_count] if args.key?(:total_max_node_count) @total_min_node_count = args[:total_min_node_count] if args.key?(:total_min_node_count) end |