Class: Google::Apis::ContainerV1beta1::NodePoolUpgradeInfo
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::NodePoolUpgradeInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
NodePoolUpgradeInfo contains the upgrade information of a node pool.
Instance Attribute Summary collapse
-
#auto_upgrade_status ⇒ Array<String>
The auto upgrade status.
-
#custom_image_info ⇒ Google::Apis::ContainerV1beta1::CustomImageInfo
Contains the custom image info for a node pool.
-
#end_of_extended_support_timestamp ⇒ String
The node pool's current minor version's end of extended support timestamp.
-
#end_of_standard_support_timestamp ⇒ String
The node pool's current minor version's end of standard support timestamp.
-
#minor_target_version ⇒ String
minor_target_version indicates the target version for minor upgrade.
-
#patch_target_version ⇒ String
patch_target_version indicates the target version for patch upgrade.
-
#paused_reason ⇒ Array<String>
The auto upgrade paused reason.
-
#upgrade_details ⇒ Array<Google::Apis::ContainerV1beta1::UpgradeDetails>
The list of past auto upgrades.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodePoolUpgradeInfo
constructor
A new instance of NodePoolUpgradeInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodePoolUpgradeInfo
Returns a new instance of NodePoolUpgradeInfo.
8055 8056 8057 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8055 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_upgrade_status ⇒ Array<String>
The auto upgrade status.
Corresponds to the JSON property autoUpgradeStatus
8018 8019 8020 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8018 def auto_upgrade_status @auto_upgrade_status end |
#custom_image_info ⇒ Google::Apis::ContainerV1beta1::CustomImageInfo
Contains the custom image info for a node pool.
Corresponds to the JSON property customImageInfo
8023 8024 8025 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8023 def custom_image_info @custom_image_info end |
#end_of_extended_support_timestamp ⇒ String
The node pool's current minor version's end of extended support timestamp.
Corresponds to the JSON property endOfExtendedSupportTimestamp
8028 8029 8030 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8028 def @end_of_extended_support_timestamp end |
#end_of_standard_support_timestamp ⇒ String
The node pool's current minor version's end of standard support timestamp.
Corresponds to the JSON property endOfStandardSupportTimestamp
8033 8034 8035 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8033 def @end_of_standard_support_timestamp end |
#minor_target_version ⇒ String
minor_target_version indicates the target version for minor upgrade.
Corresponds to the JSON property minorTargetVersion
8038 8039 8040 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8038 def minor_target_version @minor_target_version end |
#patch_target_version ⇒ String
patch_target_version indicates the target version for patch upgrade.
Corresponds to the JSON property patchTargetVersion
8043 8044 8045 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8043 def patch_target_version @patch_target_version end |
#paused_reason ⇒ Array<String>
The auto upgrade paused reason.
Corresponds to the JSON property pausedReason
8048 8049 8050 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8048 def paused_reason @paused_reason end |
#upgrade_details ⇒ Array<Google::Apis::ContainerV1beta1::UpgradeDetails>
The list of past auto upgrades.
Corresponds to the JSON property upgradeDetails
8053 8054 8055 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8053 def upgrade_details @upgrade_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8060 8061 8062 8063 8064 8065 8066 8067 8068 8069 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8060 def update!(**args) @auto_upgrade_status = args[:auto_upgrade_status] if args.key?(:auto_upgrade_status) @custom_image_info = args[:custom_image_info] if args.key?(:custom_image_info) @end_of_extended_support_timestamp = args[:end_of_extended_support_timestamp] if args.key?(:end_of_extended_support_timestamp) @end_of_standard_support_timestamp = args[:end_of_standard_support_timestamp] if args.key?(:end_of_standard_support_timestamp) @minor_target_version = args[:minor_target_version] if args.key?(:minor_target_version) @patch_target_version = args[:patch_target_version] if args.key?(:patch_target_version) @paused_reason = args[:paused_reason] if args.key?(:paused_reason) @upgrade_details = args[:upgrade_details] if args.key?(:upgrade_details) end |