Class: Google::Apis::ContainerV1beta1::NodeVfioConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::NodeVfioConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
Configuration settings for VFIO (Virtual Function I/O) on a node. VFIO allows safe, unprivileged, userspace drivers to access I/O devices.
Instance Attribute Summary collapse
-
#dma_entry_limit ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeVfioConfig
constructor
A new instance of NodeVfioConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeVfioConfig
Returns a new instance of NodeVfioConfig.
8164 8165 8166 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8164 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dma_entry_limit ⇒ Fixnum
Optional. Specifies the maximum number of DMA entries (pages) that can be
mapped by the VFIO IOMMU type 1 driver for a container. This limit affects the
total amount of host memory that can be pinned for direct device access, which
is often critical for high-performance devices like TPUs and GPUs. This
setting corresponds to the kernel parameter at: /sys/module/vfio_iommu_type1/
parameters/dma_entry_limit. The default value in the kernel is 65535.
Higher values may be needed for workloads mapping large memory regions.
Supported values are integers between 65535 and 4194304.
Corresponds to the JSON property dmaEntryLimit
8162 8163 8164 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8162 def dma_entry_limit @dma_entry_limit end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8169 8170 8171 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8169 def update!(**args) @dma_entry_limit = args[:dma_entry_limit] if args.key?(:dma_entry_limit) end |