Class: Google::Apis::ContainerV1beta1::Operation
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::Operation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
This operation resource represents operations that may have happened or are happening on the cluster. All fields are output only.
Instance Attribute Summary collapse
-
#cluster_conditions ⇒ Array<Google::Apis::ContainerV1beta1::StatusCondition>
Which conditions caused the current cluster state.
-
#detail ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::ContainerV1beta1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#location ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#nodepool_conditions ⇒ Array<Google::Apis::ContainerV1beta1::StatusCondition>
Which conditions caused the current node pool state.
-
#operation_type ⇒ String
Output only.
-
#progress ⇒ Google::Apis::ContainerV1beta1::OperationProgress
Information about operation (or operation stage) progress.
-
#self_link ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#status_message ⇒ String
Output only.
-
#target_link ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Operation
constructor
A new instance of Operation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Operation
Returns a new instance of Operation.
8169 8170 8171 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8169 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_conditions ⇒ Array<Google::Apis::ContainerV1beta1::StatusCondition>
Which conditions caused the current cluster state. Deprecated. Use field error
instead.
Corresponds to the JSON property clusterConditions
8074 8075 8076 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8074 def cluster_conditions @cluster_conditions end |
#detail ⇒ String
Output only. Detailed operation progress, if available.
Corresponds to the JSON property detail
8079 8080 8081 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8079 def detail @detail end |
#end_time ⇒ String
Output only. The time the operation completed, in RFC3339 text format.
Corresponds to the JSON property endTime
8085 8086 8087 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8085 def end_time @end_time end |
#error ⇒ Google::Apis::ContainerV1beta1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
8095 8096 8097 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8095 def error @error end |
#location ⇒ String
8103 8104 8105 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8103 def location @location end |
#name ⇒ String
Output only. The server-assigned ID for the operation.
Corresponds to the JSON property name
8108 8109 8110 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8108 def name @name end |
#nodepool_conditions ⇒ Array<Google::Apis::ContainerV1beta1::StatusCondition>
Which conditions caused the current node pool state. Deprecated. Use field
error instead.
Corresponds to the JSON property nodepoolConditions
8114 8115 8116 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8114 def nodepool_conditions @nodepool_conditions end |
#operation_type ⇒ String
Output only. The operation type.
Corresponds to the JSON property operationType
8119 8120 8121 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8119 def operation_type @operation_type end |
#progress ⇒ Google::Apis::ContainerV1beta1::OperationProgress
Information about operation (or operation stage) progress.
Corresponds to the JSON property progress
8124 8125 8126 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8124 def progress @progress end |
#self_link ⇒ String
Output only. Server-defined URI for the operation. Example: https://container.
googleapis.com/v1alpha1/projects/123/locations/us-central1/operations/
operation-123.
Corresponds to the JSON property selfLink
8131 8132 8133 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8131 def self_link @self_link end |
#start_time ⇒ String
Output only. The time the operation started, in RFC3339 text format.
Corresponds to the JSON property startTime
8137 8138 8139 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8137 def start_time @start_time end |
#status ⇒ String
Output only. The current status of the operation.
Corresponds to the JSON property status
8142 8143 8144 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8142 def status @status end |
#status_message ⇒ String
Output only. If an error has occurred, a textual description of the error.
Deprecated. Use field error instead.
Corresponds to the JSON property statusMessage
8148 8149 8150 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8148 def @status_message end |
#target_link ⇒ String
Output only. Server-defined URI for the target of the operation. The format of
this is a URI to the resource being modified (such as a cluster, node pool, or
node). For node pool repairs, there may be multiple nodes being repaired, but
only one will be the target. Examples: - ## https://container.googleapis.com/
v1/projects/123/locations/us-central1/clusters/my-cluster ## https://
container.googleapis.com/v1/projects/123/zones/us-central1-c/clusters/my-
cluster/nodePools/my-np https://container.googleapis.com/v1/projects/123/
zones/us-central1-c/clusters/my-cluster/nodePools/my-np/node/my-node
Corresponds to the JSON property targetLink
8160 8161 8162 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8160 def target_link @target_link end |
#zone ⇒ String
Output only. The name of the Google Compute Engine zone in which the operation is taking place. This
field is deprecated, use location instead.
Corresponds to the JSON property zone
8167 8168 8169 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8167 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 8185 8186 8187 8188 8189 8190 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8174 def update!(**args) @cluster_conditions = args[:cluster_conditions] if args.key?(:cluster_conditions) @detail = args[:detail] if args.key?(:detail) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @nodepool_conditions = args[:nodepool_conditions] if args.key?(:nodepool_conditions) @operation_type = args[:operation_type] if args.key?(:operation_type) @progress = args[:progress] if args.key?(:progress) @self_link = args[:self_link] if args.key?(:self_link) @start_time = args[:start_time] if args.key?(:start_time) @status = args[:status] if args.key?(:status) @status_message = args[:status_message] if args.key?(:status_message) @target_link = args[:target_link] if args.key?(:target_link) @zone = args[:zone] if args.key?(:zone) end |