Class: Google::Apis::ContainerV1beta1::Operation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

This operation resource represents operations that may have happened or are happening on the cluster. All fields are output only.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Operation

Returns a new instance of Operation.



7623
7624
7625
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7623

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_conditionsArray<Google::Apis::ContainerV1beta1::StatusCondition>

Which conditions caused the current cluster state. Deprecated. Use field error instead. Corresponds to the JSON property clusterConditions



7528
7529
7530
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7528

def cluster_conditions
  @cluster_conditions
end

#detailString

Output only. Detailed operation progress, if available. Corresponds to the JSON property detail

Returns:

  • (String)


7533
7534
7535
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7533

def detail
  @detail
end

#end_timeString

Output only. The time the operation completed, in RFC3339 text format. Corresponds to the JSON property endTime

Returns:

  • (String)


7539
7540
7541
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7539

def end_time
  @end_time
end

#errorGoogle::Apis::ContainerV1beta1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



7549
7550
7551
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7549

def error
  @error
end

#locationString

Output only. The name of the Google Compute Engine zone or region in which the cluster resides. Corresponds to the JSON property location

Returns:

  • (String)


7557
7558
7559
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7557

def location
  @location
end

#nameString

Output only. The server-assigned ID for the operation. Corresponds to the JSON property name

Returns:

  • (String)


7562
7563
7564
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7562

def name
  @name
end

#nodepool_conditionsArray<Google::Apis::ContainerV1beta1::StatusCondition>

Which conditions caused the current node pool state. Deprecated. Use field error instead. Corresponds to the JSON property nodepoolConditions



7568
7569
7570
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7568

def nodepool_conditions
  @nodepool_conditions
end

#operation_typeString

Output only. The operation type. Corresponds to the JSON property operationType

Returns:

  • (String)


7573
7574
7575
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7573

def operation_type
  @operation_type
end

#progressGoogle::Apis::ContainerV1beta1::OperationProgress

Information about operation (or operation stage) progress. Corresponds to the JSON property progress



7578
7579
7580
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7578

def progress
  @progress
end

Output only. Server-defined URI for the operation. Example: https://container. googleapis.com/v1alpha1/projects/123/locations/us-central1/operations/ operation-123. Corresponds to the JSON property selfLink

Returns:

  • (String)


7585
7586
7587
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7585

def self_link
  @self_link
end

#start_timeString

Output only. The time the operation started, in RFC3339 text format. Corresponds to the JSON property startTime

Returns:

  • (String)


7591
7592
7593
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7591

def start_time
  @start_time
end

#statusString

Output only. The current status of the operation. Corresponds to the JSON property status

Returns:

  • (String)


7596
7597
7598
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7596

def status
  @status
end

#status_messageString

Output only. If an error has occurred, a textual description of the error. Deprecated. Use field error instead. Corresponds to the JSON property statusMessage

Returns:

  • (String)


7602
7603
7604
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7602

def status_message
  @status_message
end

Output only. Server-defined URI for the target of the operation. The format of this is a URI to the resource being modified (such as a cluster, node pool, or node). For node pool repairs, there may be multiple nodes being repaired, but only one will be the target. Examples: - ## https://container.googleapis.com/ v1/projects/123/locations/us-central1/clusters/my-cluster ## https:// container.googleapis.com/v1/projects/123/zones/us-central1-c/clusters/my- cluster/nodePools/my-np https://container.googleapis.com/v1/projects/123/ zones/us-central1-c/clusters/my-cluster/nodePools/my-np/node/my-node Corresponds to the JSON property targetLink

Returns:

  • (String)


7614
7615
7616
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7614

def target_link
  @target_link
end

#zoneString

Output only. The name of the Google Compute Engine zone in which the operation is taking place. This field is deprecated, use location instead. Corresponds to the JSON property zone

Returns:

  • (String)


7621
7622
7623
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7621

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7628
7629
7630
7631
7632
7633
7634
7635
7636
7637
7638
7639
7640
7641
7642
7643
7644
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7628

def update!(**args)
  @cluster_conditions = args[:cluster_conditions] if args.key?(:cluster_conditions)
  @detail = args[:detail] if args.key?(:detail)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @nodepool_conditions = args[:nodepool_conditions] if args.key?(:nodepool_conditions)
  @operation_type = args[:operation_type] if args.key?(:operation_type)
  @progress = args[:progress] if args.key?(:progress)
  @self_link = args[:self_link] if args.key?(:self_link)
  @start_time = args[:start_time] if args.key?(:start_time)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target_link = args[:target_link] if args.key?(:target_link)
  @zone = args[:zone] if args.key?(:zone)
end