Class: Google::Apis::ContainerV1beta1::Operation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

This operation resource represents operations that may have happened or are happening on the cluster. All fields are output only.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Operation

Returns a new instance of Operation.



7459
7460
7461
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7459

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_conditionsArray<Google::Apis::ContainerV1beta1::StatusCondition>

Which conditions caused the current cluster state. Deprecated. Use field error instead. Corresponds to the JSON property clusterConditions



7364
7365
7366
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7364

def cluster_conditions
  @cluster_conditions
end

#detailString

Output only. Detailed operation progress, if available. Corresponds to the JSON property detail

Returns:

  • (String)


7369
7370
7371
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7369

def detail
  @detail
end

#end_timeString

Output only. The time the operation completed, in RFC3339 text format. Corresponds to the JSON property endTime

Returns:

  • (String)


7375
7376
7377
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7375

def end_time
  @end_time
end

#errorGoogle::Apis::ContainerV1beta1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



7385
7386
7387
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7385

def error
  @error
end

#locationString

Output only. The name of the Google Compute Engine zone or region in which the cluster resides. Corresponds to the JSON property location

Returns:

  • (String)


7393
7394
7395
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7393

def location
  @location
end

#nameString

Output only. The server-assigned ID for the operation. Corresponds to the JSON property name

Returns:

  • (String)


7398
7399
7400
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7398

def name
  @name
end

#nodepool_conditionsArray<Google::Apis::ContainerV1beta1::StatusCondition>

Which conditions caused the current node pool state. Deprecated. Use field error instead. Corresponds to the JSON property nodepoolConditions



7404
7405
7406
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7404

def nodepool_conditions
  @nodepool_conditions
end

#operation_typeString

Output only. The operation type. Corresponds to the JSON property operationType

Returns:

  • (String)


7409
7410
7411
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7409

def operation_type
  @operation_type
end

#progressGoogle::Apis::ContainerV1beta1::OperationProgress

Information about operation (or operation stage) progress. Corresponds to the JSON property progress



7414
7415
7416
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7414

def progress
  @progress
end

Output only. Server-defined URI for the operation. Example: https://container. googleapis.com/v1alpha1/projects/123/locations/us-central1/operations/ operation-123. Corresponds to the JSON property selfLink

Returns:

  • (String)


7421
7422
7423
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7421

def self_link
  @self_link
end

#start_timeString

Output only. The time the operation started, in RFC3339 text format. Corresponds to the JSON property startTime

Returns:

  • (String)


7427
7428
7429
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7427

def start_time
  @start_time
end

#statusString

Output only. The current status of the operation. Corresponds to the JSON property status

Returns:

  • (String)


7432
7433
7434
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7432

def status
  @status
end

#status_messageString

Output only. If an error has occurred, a textual description of the error. Deprecated. Use field error instead. Corresponds to the JSON property statusMessage

Returns:

  • (String)


7438
7439
7440
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7438

def status_message
  @status_message
end

Output only. Server-defined URI for the target of the operation. The format of this is a URI to the resource being modified (such as a cluster, node pool, or node). For node pool repairs, there may be multiple nodes being repaired, but only one will be the target. Examples: - ## https://container.googleapis.com/ v1/projects/123/locations/us-central1/clusters/my-cluster ## https:// container.googleapis.com/v1/projects/123/zones/us-central1-c/clusters/my- cluster/nodePools/my-np https://container.googleapis.com/v1/projects/123/ zones/us-central1-c/clusters/my-cluster/nodePools/my-np/node/my-node Corresponds to the JSON property targetLink

Returns:

  • (String)


7450
7451
7452
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7450

def target_link
  @target_link
end

#zoneString

Output only. The name of the Google Compute Engine zone in which the operation is taking place. This field is deprecated, use location instead. Corresponds to the JSON property zone

Returns:

  • (String)


7457
7458
7459
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7457

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7464
7465
7466
7467
7468
7469
7470
7471
7472
7473
7474
7475
7476
7477
7478
7479
7480
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7464

def update!(**args)
  @cluster_conditions = args[:cluster_conditions] if args.key?(:cluster_conditions)
  @detail = args[:detail] if args.key?(:detail)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @nodepool_conditions = args[:nodepool_conditions] if args.key?(:nodepool_conditions)
  @operation_type = args[:operation_type] if args.key?(:operation_type)
  @progress = args[:progress] if args.key?(:progress)
  @self_link = args[:self_link] if args.key?(:self_link)
  @start_time = args[:start_time] if args.key?(:start_time)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target_link = args[:target_link] if args.key?(:target_link)
  @zone = args[:zone] if args.key?(:zone)
end