Class: Google::Apis::ContainerV1beta1::PlacementPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::PlacementPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
PlacementPolicy defines the placement policy used by the node pool.
Instance Attribute Summary collapse
-
#policy_name ⇒ String
If set, refers to the name of a custom resource policy supplied by the user.
-
#tpu_topology ⇒ String
TPU placement topology for pod slice node pool.
-
#type ⇒ String
The type of placement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PlacementPolicy
constructor
A new instance of PlacementPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PlacementPolicy
Returns a new instance of PlacementPolicy.
7850 7851 7852 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7850 def initialize(**args) update!(**args) end |
Instance Attribute Details
#policy_name ⇒ String
If set, refers to the name of a custom resource policy supplied by the user.
The resource policy must be in the same project and region as the node pool.
If not found, InvalidArgument error is returned.
Corresponds to the JSON property policyName
7837 7838 7839 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7837 def policy_name @policy_name end |
#tpu_topology ⇒ String
TPU placement topology for pod slice node pool. https://cloud.google.com/tpu/
docs/types-topologies#tpu_topologies
Corresponds to the JSON property tpuTopology
7843 7844 7845 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7843 def tpu_topology @tpu_topology end |
#type ⇒ String
The type of placement.
Corresponds to the JSON property type
7848 7849 7850 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7848 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7855 7856 7857 7858 7859 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7855 def update!(**args) @policy_name = args[:policy_name] if args.key?(:policy_name) @tpu_topology = args[:tpu_topology] if args.key?(:tpu_topology) @type = args[:type] if args.key?(:type) end |