Class: Google::Apis::ContainerV1beta1::PlacementPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

PlacementPolicy defines the placement policy used by the node pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PlacementPolicy

Returns a new instance of PlacementPolicy.



7686
7687
7688
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7686

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#policy_nameString

If set, refers to the name of a custom resource policy supplied by the user. The resource policy must be in the same project and region as the node pool. If not found, InvalidArgument error is returned. Corresponds to the JSON property policyName

Returns:

  • (String)


7673
7674
7675
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7673

def policy_name
  @policy_name
end

#tpu_topologyString

TPU placement topology for pod slice node pool. https://cloud.google.com/tpu/ docs/types-topologies#tpu_topologies Corresponds to the JSON property tpuTopology

Returns:

  • (String)


7679
7680
7681
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7679

def tpu_topology
  @tpu_topology
end

#typeString

The type of placement. Corresponds to the JSON property type

Returns:

  • (String)


7684
7685
7686
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7684

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7691
7692
7693
7694
7695
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7691

def update!(**args)
  @policy_name = args[:policy_name] if args.key?(:policy_name)
  @tpu_topology = args[:tpu_topology] if args.key?(:tpu_topology)
  @type = args[:type] if args.key?(:type)
end