Class: Google::Apis::ContainerV1beta1::PrivateClusterConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::PrivateClusterConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
Configuration options for private clusters.
Instance Attribute Summary collapse
-
#enable_private_endpoint ⇒ Boolean
(also: #enable_private_endpoint?)
Whether the master's internal IP address is used as the cluster endpoint.
-
#enable_private_nodes ⇒ Boolean
(also: #enable_private_nodes?)
Whether nodes have internal IP addresses only.
-
#master_global_access_config ⇒ Google::Apis::ContainerV1beta1::PrivateClusterMasterGlobalAccessConfig
Configuration for controlling master global access settings.
-
#master_ipv4_cidr_block ⇒ String
The IP range in CIDR notation to use for the hosted master network.
-
#peering_name ⇒ String
Output only.
-
#private_endpoint ⇒ String
Output only.
-
#private_endpoint_subnetwork ⇒ String
Subnet to provision the master's private endpoint during cluster creation.
-
#public_endpoint ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PrivateClusterConfig
constructor
A new instance of PrivateClusterConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PrivateClusterConfig
Returns a new instance of PrivateClusterConfig.
8572 8573 8574 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8572 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_private_endpoint ⇒ Boolean Also known as: enable_private_endpoint?
Whether the master's internal IP address is used as the cluster endpoint. Use
ControlPlaneEndpointsConfig.IPEndpointsConfig.enable_public_endpoint instead.
Note that the value of enable_public_endpoint is reversed: if
enable_private_endpoint is false, then enable_public_endpoint will be true.
Corresponds to the JSON property enablePrivateEndpoint
8521 8522 8523 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8521 def enable_private_endpoint @enable_private_endpoint end |
#enable_private_nodes ⇒ Boolean Also known as: enable_private_nodes?
Whether nodes have internal IP addresses only. If enabled, all nodes are given
only RFC 1918 private addresses and communicate with the master via private
networking. Deprecated: Use NetworkConfig.default_enable_private_nodes instead.
Corresponds to the JSON property enablePrivateNodes
8529 8530 8531 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8529 def enable_private_nodes @enable_private_nodes end |
#master_global_access_config ⇒ Google::Apis::ContainerV1beta1::PrivateClusterMasterGlobalAccessConfig
Configuration for controlling master global access settings.
Corresponds to the JSON property masterGlobalAccessConfig
8535 8536 8537 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8535 def master_global_access_config @master_global_access_config end |
#master_ipv4_cidr_block ⇒ String
The IP range in CIDR notation to use for the hosted master network. This range
will be used for assigning internal IP addresses to the master or set of
masters, as well as the ILB VIP. This range must not overlap with any other
ranges in use within the cluster's network.
Corresponds to the JSON property masterIpv4CidrBlock
8543 8544 8545 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8543 def master_ipv4_cidr_block @master_ipv4_cidr_block end |
#peering_name ⇒ String
Output only. The peering name in the customer VPC used by this cluster.
Corresponds to the JSON property peeringName
8548 8549 8550 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8548 def peering_name @peering_name end |
#private_endpoint ⇒ String
Output only. The internal IP address of this cluster's master endpoint.
Deprecated: Use ControlPlaneEndpointsConfig.IPEndpointsConfig.private_endpoint
instead.
Corresponds to the JSON property privateEndpoint
8555 8556 8557 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8555 def private_endpoint @private_endpoint end |
#private_endpoint_subnetwork ⇒ String
Subnet to provision the master's private endpoint during cluster creation.
Specified in projects//regions//subnetworks/* format. Deprecated: Use
ControlPlaneEndpointsConfig.IPEndpointsConfig.private_endpoint_subnetwork
instead.
Corresponds to the JSON property privateEndpointSubnetwork
8563 8564 8565 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8563 def private_endpoint_subnetwork @private_endpoint_subnetwork end |
#public_endpoint ⇒ String
Output only. The external IP address of this cluster's master endpoint.
Deprecated: Use ControlPlaneEndpointsConfig.IPEndpointsConfig.public_endpoint
instead.
Corresponds to the JSON property publicEndpoint
8570 8571 8572 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8570 def public_endpoint @public_endpoint end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8577 8578 8579 8580 8581 8582 8583 8584 8585 8586 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8577 def update!(**args) @enable_private_endpoint = args[:enable_private_endpoint] if args.key?(:enable_private_endpoint) @enable_private_nodes = args[:enable_private_nodes] if args.key?(:enable_private_nodes) @master_global_access_config = args[:master_global_access_config] if args.key?(:master_global_access_config) @master_ipv4_cidr_block = args[:master_ipv4_cidr_block] if args.key?(:master_ipv4_cidr_block) @peering_name = args[:peering_name] if args.key?(:peering_name) @private_endpoint = args[:private_endpoint] if args.key?(:private_endpoint) @private_endpoint_subnetwork = args[:private_endpoint_subnetwork] if args.key?(:private_endpoint_subnetwork) @public_endpoint = args[:public_endpoint] if args.key?(:public_endpoint) end |