Class: Google::Apis::ContainerV1beta1::PrivateClusterConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Configuration options for private clusters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrivateClusterConfig

Returns a new instance of PrivateClusterConfig.



8026
8027
8028
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8026

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_private_endpointBoolean Also known as: enable_private_endpoint?

Whether the master's internal IP address is used as the cluster endpoint. Use ControlPlaneEndpointsConfig.IPEndpointsConfig.enable_public_endpoint instead. Note that the value of enable_public_endpoint is reversed: if enable_private_endpoint is false, then enable_public_endpoint will be true. Corresponds to the JSON property enablePrivateEndpoint

Returns:

  • (Boolean)


7975
7976
7977
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7975

def enable_private_endpoint
  @enable_private_endpoint
end

#enable_private_nodesBoolean Also known as: enable_private_nodes?

Whether nodes have internal IP addresses only. If enabled, all nodes are given only RFC 1918 private addresses and communicate with the master via private networking. Deprecated: Use NetworkConfig.default_enable_private_nodes instead. Corresponds to the JSON property enablePrivateNodes

Returns:

  • (Boolean)


7983
7984
7985
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7983

def enable_private_nodes
  @enable_private_nodes
end

#master_global_access_configGoogle::Apis::ContainerV1beta1::PrivateClusterMasterGlobalAccessConfig

Configuration for controlling master global access settings. Corresponds to the JSON property masterGlobalAccessConfig



7989
7990
7991
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7989

def master_global_access_config
  @master_global_access_config
end

#master_ipv4_cidr_blockString

The IP range in CIDR notation to use for the hosted master network. This range will be used for assigning internal IP addresses to the master or set of masters, as well as the ILB VIP. This range must not overlap with any other ranges in use within the cluster's network. Corresponds to the JSON property masterIpv4CidrBlock

Returns:

  • (String)


7997
7998
7999
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7997

def master_ipv4_cidr_block
  @master_ipv4_cidr_block
end

#peering_nameString

Output only. The peering name in the customer VPC used by this cluster. Corresponds to the JSON property peeringName

Returns:

  • (String)


8002
8003
8004
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8002

def peering_name
  @peering_name
end

#private_endpointString

Output only. The internal IP address of this cluster's master endpoint. Deprecated: Use ControlPlaneEndpointsConfig.IPEndpointsConfig.private_endpoint instead. Corresponds to the JSON property privateEndpoint

Returns:

  • (String)


8009
8010
8011
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8009

def private_endpoint
  @private_endpoint
end

#private_endpoint_subnetworkString

Subnet to provision the master's private endpoint during cluster creation. Specified in projects//regions//subnetworks/* format. Deprecated: Use ControlPlaneEndpointsConfig.IPEndpointsConfig.private_endpoint_subnetwork instead. Corresponds to the JSON property privateEndpointSubnetwork

Returns:

  • (String)


8017
8018
8019
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8017

def private_endpoint_subnetwork
  @private_endpoint_subnetwork
end

#public_endpointString

Output only. The external IP address of this cluster's master endpoint. Deprecated: Use ControlPlaneEndpointsConfig.IPEndpointsConfig.public_endpoint instead. Corresponds to the JSON property publicEndpoint

Returns:

  • (String)


8024
8025
8026
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8024

def public_endpoint
  @public_endpoint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8031
8032
8033
8034
8035
8036
8037
8038
8039
8040
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8031

def update!(**args)
  @enable_private_endpoint = args[:enable_private_endpoint] if args.key?(:enable_private_endpoint)
  @enable_private_nodes = args[:enable_private_nodes] if args.key?(:enable_private_nodes)
  @master_global_access_config = args[:master_global_access_config] if args.key?(:master_global_access_config)
  @master_ipv4_cidr_block = args[:master_ipv4_cidr_block] if args.key?(:master_ipv4_cidr_block)
  @peering_name = args[:peering_name] if args.key?(:peering_name)
  @private_endpoint = args[:private_endpoint] if args.key?(:private_endpoint)
  @private_endpoint_subnetwork = args[:private_endpoint_subnetwork] if args.key?(:private_endpoint_subnetwork)
  @public_endpoint = args[:public_endpoint] if args.key?(:public_endpoint)
end