Class: Google::Apis::ContainerV1beta1::PubSub

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Pub/Sub specific notification config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PubSub

Returns a new instance of PubSub.



8002
8003
8004
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Enable notifications for Pub/Sub. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


7985
7986
7987
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7985

def enabled
  @enabled
end

#filterGoogle::Apis::ContainerV1beta1::Filter

Allows filtering to one or more specific event types. If event types are present, those and only those event types will be transmitted to the cluster. Other types will be skipped. If no filter is specified, or no event types are present, all event types will be sent Corresponds to the JSON property filter



7994
7995
7996
# File 'lib/google/apis/container_v1beta1/classes.rb', line 7994

def filter
  @filter
end

#topicString

The desired Pub/Sub topic to which notifications will be sent by GKE. Format is projects/project/topics/topic`. Corresponds to the JSON propertytopic`

Returns:

  • (String)


8000
8001
8002
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8000

def topic
  @topic
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8007
8008
8009
8010
8011
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8007

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @filter = args[:filter] if args.key?(:filter)
  @topic = args[:topic] if args.key?(:topic)
end