Class: Google::Apis::ContainerV1beta1::QueuedProvisioning
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::QueuedProvisioning
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
QueuedProvisioning defines the queued provisioning used by the node pool.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Denotes that this node pool is QRM specific, meaning nodes can be only obtained through queuing via the Cluster Autoscaler ProvisioningRequest API.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueuedProvisioning
constructor
A new instance of QueuedProvisioning.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueuedProvisioning
Returns a new instance of QueuedProvisioning.
8735 8736 8737 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8735 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Denotes that this node pool is QRM specific, meaning nodes can be only
obtained through queuing via the Cluster Autoscaler ProvisioningRequest API.
Corresponds to the JSON property enabled
8732 8733 8734 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8732 def enabled @enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8740 8741 8742 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8740 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) end |