Class: Google::Apis::ContainerV1beta1::RecurringMaintenanceWindow

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Represents an arbitrary window of time that recurs. Alternative to RecurringTimeWindow, with renamed fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RecurringMaintenanceWindow

Returns a new instance of RecurringMaintenanceWindow.



8930
8931
8932
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8930

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delay_untilGoogle::Apis::ContainerV1beta1::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property delayUntil



8906
8907
8908
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8906

def delay_until
  @delay_until
end

#recurrenceString

Required. An RRULE (https://tools.ietf.org/html/rfc5545#section-3.8.5.3) for how this window reccurs. For example, to have something repeat every weekday, you'd use: FREQ=WEEKLY;BYDAY=MO,TU,WE,TH,FR To repeat some window daily ( equivalent to the DailyMaintenanceWindow): FREQ=DAILY For the first weekend of every month: FREQ=MONTHLY;BYSETPOS=1;BYDAY=SA,SU The FREQ values of HOURLY, MINUTELY, and SECONDLY are not supported. Corresponds to the JSON property recurrence

Returns:

  • (String)


8916
8917
8918
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8916

def recurrence
  @recurrence
end

#window_durationString

Required. Duration of the window. Corresponds to the JSON property windowDuration

Returns:

  • (String)


8921
8922
8923
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8921

def window_duration
  @window_duration
end

#window_start_timeGoogle::Apis::ContainerV1beta1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property windowStartTime



8928
8929
8930
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8928

def window_start_time
  @window_start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8935
8936
8937
8938
8939
8940
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8935

def update!(**args)
  @delay_until = args[:delay_until] if args.key?(:delay_until)
  @recurrence = args[:recurrence] if args.key?(:recurrence)
  @window_duration = args[:window_duration] if args.key?(:window_duration)
  @window_start_time = args[:window_start_time] if args.key?(:window_start_time)
end