Class: Google::Apis::ContainerV1beta1::RegistryHostConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

RegistryHostConfig configures the top-level structure for a single containerd registry server's configuration, which represents one hosts.toml file on the node. It will override the same fqdns in PrivateRegistryAccessConfig.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegistryHostConfig

Returns a new instance of RegistryHostConfig.



9009
9010
9011
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9009

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostsArray<Google::Apis::ContainerV1beta1::HostConfig>

HostConfig configures a list of host-specific configurations for the server. Each server can have at most 10 host configurations. Corresponds to the JSON property hosts



8998
8999
9000
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8998

def hosts
  @hosts
end

#serverString

Defines the host name of the registry server, which will be used to create configuration file as /etc/containerd/hosts.d//hosts.toml. It supports fully qualified domain names (FQDN) and IP addresses: Specifying port is supported, while scheme and path are NOT supported. Wildcards are NOT supported. Examples:

  • my.customdomain.com - 10.0.1.2:5000 Corresponds to the JSON property server

Returns:

  • (String)


9007
9008
9009
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9007

def server
  @server
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9014
9015
9016
9017
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9014

def update!(**args)
  @hosts = args[:hosts] if args.key?(:hosts)
  @server = args[:server] if args.key?(:server)
end