Class: Google::Apis::ContainerV1beta1::RollbackNodePoolUpgradeRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

RollbackNodePoolUpgradeRequest rollbacks the previously Aborted or Failed NodePool upgrade. This will be an no-op if the last upgrade successfully completed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RollbackNodePoolUpgradeRequest

Returns a new instance of RollbackNodePoolUpgradeRequest.



9295
9296
9297
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9295

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to rollback. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9260
9261
9262
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9260

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster, node pool id) of the node poll to rollback upgrade. Specified in the format projects/*/locations/*/clusters/*/ nodePools/*. Corresponds to the JSON property name

Returns:

  • (String)


9267
9268
9269
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9267

def name
  @name
end

#node_pool_idString

Deprecated. The name of the node pool to rollback. This field has been deprecated and replaced by the name field. Corresponds to the JSON property nodePoolId

Returns:

  • (String)


9273
9274
9275
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9273

def node_pool_id
  @node_pool_id
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9280
9281
9282
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9280

def project_id
  @project_id
end

#respect_pdbBoolean Also known as: respect_pdb?

Option for rollback to ignore the PodDisruptionBudget. Default value is false. Corresponds to the JSON property respectPdb

Returns:

  • (Boolean)


9285
9286
9287
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9285

def respect_pdb
  @respect_pdb
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9293
9294
9295
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9293

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9300
9301
9302
9303
9304
9305
9306
9307
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9300

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @respect_pdb = args[:respect_pdb] if args.key?(:respect_pdb)
  @zone = args[:zone] if args.key?(:zone)
end