Class: Google::Apis::ContainerV1beta1::SetAddonsConfigRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

SetAddonsRequest sets the addons associated with the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetAddonsConfigRequest

Returns a new instance of SetAddonsConfigRequest.



9114
9115
9116
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9114

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addons_configGoogle::Apis::ContainerV1beta1::AddonsConfig

Configuration for the addons that can be automatically spun up in the cluster, enabling additional functionality. Corresponds to the JSON property addonsConfig



9086
9087
9088
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9086

def addons_config
  @addons_config
end

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9092
9093
9094
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9092

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster) of the cluster to set addons. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


9098
9099
9100
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9098

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9105
9106
9107
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9105

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9112
9113
9114
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9112

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9119
9120
9121
9122
9123
9124
9125
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9119

def update!(**args)
  @addons_config = args[:addons_config] if args.key?(:addons_config)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end