Class: Google::Apis::ContainerV1beta1::SetAddonsConfigRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::SetAddonsConfigRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
SetAddonsRequest sets the addons associated with the cluster.
Instance Attribute Summary collapse
-
#addons_config ⇒ Google::Apis::ContainerV1beta1::AddonsConfig
Configuration for the addons that can be automatically spun up in the cluster, enabling additional functionality.
-
#cluster_id ⇒ String
Deprecated.
-
#name ⇒ String
The name (project, location, cluster) of the cluster to set addons.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetAddonsConfigRequest
constructor
A new instance of SetAddonsConfigRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetAddonsConfigRequest
Returns a new instance of SetAddonsConfigRequest.
8950 8951 8952 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8950 def initialize(**args) update!(**args) end |
Instance Attribute Details
#addons_config ⇒ Google::Apis::ContainerV1beta1::AddonsConfig
Configuration for the addons that can be automatically spun up in the cluster,
enabling additional functionality.
Corresponds to the JSON property addonsConfig
8922 8923 8924 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8922 def addons_config @addons_config end |
#cluster_id ⇒ String
Deprecated. The name of the cluster to upgrade. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
8928 8929 8930 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8928 def cluster_id @cluster_id end |
#name ⇒ String
The name (project, location, cluster) of the cluster to set addons. Specified
in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
8934 8935 8936 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8934 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
8941 8942 8943 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8941 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
8948 8949 8950 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8948 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8955 8956 8957 8958 8959 8960 8961 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8955 def update!(**args) @addons_config = args[:addons_config] if args.key?(:addons_config) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |