Class: Google::Apis::ContainerV1beta1::SetLabelsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::SetLabelsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
SetLabelsRequest sets the Google Cloud Platform labels on a Google Container Engine cluster, which will in turn set them for Google Compute Engine resources used by that cluster
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#label_fingerprint ⇒ String
Required.
-
#name ⇒ String
The name (project, location, cluster name) of the cluster to set labels.
-
#project_id ⇒ String
Deprecated.
-
#resource_labels ⇒ Hash<String,String>
Required.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetLabelsRequest
constructor
A new instance of SetLabelsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetLabelsRequest
Returns a new instance of SetLabelsRequest.
9174 9175 9176 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9174 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster. This field has been deprecated and
replaced by the name field.
Corresponds to the JSON property clusterId
9138 9139 9140 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9138 def cluster_id @cluster_id end |
#label_fingerprint ⇒ String
Required. The fingerprint of the previous set of labels for this resource,
used to detect conflicts. The fingerprint is initially generated by Kubernetes
Engine and changes after every request to modify or update labels. You must
always provide an up-to-date fingerprint hash when updating or changing labels.
Make a get() request to the resource to get the latest fingerprint.
Corresponds to the JSON property labelFingerprint
9147 9148 9149 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9147 def label_fingerprint @label_fingerprint end |
#name ⇒ String
The name (project, location, cluster name) of the cluster to set labels.
Specified in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
9153 9154 9155 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9153 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
9160 9161 9162 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9160 def project_id @project_id end |
#resource_labels ⇒ Hash<String,String>
Required. The labels to set for that cluster.
Corresponds to the JSON property resourceLabels
9165 9166 9167 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9165 def resource_labels @resource_labels end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
9172 9173 9174 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9172 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9179 9180 9181 9182 9183 9184 9185 9186 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9179 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @resource_labels = args[:resource_labels] if args.key?(:resource_labels) @zone = args[:zone] if args.key?(:zone) end |