Class: Google::Apis::ContainerV1beta1::SetLabelsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::SetLabelsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
SetLabelsRequest sets the Google Cloud Platform labels on a Google Container Engine cluster, which will in turn set them for Google Compute Engine resources used by that cluster
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#label_fingerprint ⇒ String
Required.
-
#name ⇒ String
The name (project, location, cluster name) of the cluster to set labels.
-
#project_id ⇒ String
Deprecated.
-
#resource_labels ⇒ Hash<String,String>
Required.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetLabelsRequest
constructor
A new instance of SetLabelsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetLabelsRequest
Returns a new instance of SetLabelsRequest.
9010 9011 9012 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9010 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster. This field has been deprecated and
replaced by the name field.
Corresponds to the JSON property clusterId
8974 8975 8976 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8974 def cluster_id @cluster_id end |
#label_fingerprint ⇒ String
Required. The fingerprint of the previous set of labels for this resource,
used to detect conflicts. The fingerprint is initially generated by Kubernetes
Engine and changes after every request to modify or update labels. You must
always provide an up-to-date fingerprint hash when updating or changing labels.
Make a get() request to the resource to get the latest fingerprint.
Corresponds to the JSON property labelFingerprint
8983 8984 8985 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8983 def label_fingerprint @label_fingerprint end |
#name ⇒ String
The name (project, location, cluster name) of the cluster to set labels.
Specified in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
8989 8990 8991 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8989 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
8996 8997 8998 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 8996 def project_id @project_id end |
#resource_labels ⇒ Hash<String,String>
Required. The labels to set for that cluster.
Corresponds to the JSON property resourceLabels
9001 9002 9003 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9001 def resource_labels @resource_labels end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
9008 9009 9010 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9008 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9015 9016 9017 9018 9019 9020 9021 9022 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9015 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @resource_labels = args[:resource_labels] if args.key?(:resource_labels) @zone = args[:zone] if args.key?(:zone) end |