Class: Google::Apis::ContainerV1beta1::SetLegacyAbacRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::SetLegacyAbacRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
SetLegacyAbacRequest enables or disables the ABAC authorization mechanism for a cluster.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#enabled ⇒ Boolean
(also: #enabled?)
Required.
-
#name ⇒ String
The name (project, location, cluster name) of the cluster to set legacy abac.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetLegacyAbacRequest
constructor
A new instance of SetLegacyAbacRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetLegacyAbacRequest
Returns a new instance of SetLegacyAbacRequest.
9973 9974 9975 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9973 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster to update. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
9945 9946 9947 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9945 def cluster_id @cluster_id end |
#enabled ⇒ Boolean Also known as: enabled?
Required. Whether ABAC authorization will be enabled in the cluster.
Corresponds to the JSON property enabled
9950 9951 9952 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9950 def enabled @enabled end |
#name ⇒ String
The name (project, location, cluster name) of the cluster to set legacy abac.
Specified in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
9957 9958 9959 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9957 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
9964 9965 9966 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9964 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
9971 9972 9973 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9971 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9978 9979 9980 9981 9982 9983 9984 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9978 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @enabled = args[:enabled] if args.key?(:enabled) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |