Class: Google::Apis::ContainerV1beta1::SetLegacyAbacRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

SetLegacyAbacRequest enables or disables the ABAC authorization mechanism for a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetLegacyAbacRequest

Returns a new instance of SetLegacyAbacRequest.



9226
9227
9228
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9226

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to update. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9198
9199
9200
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9198

def cluster_id
  @cluster_id
end

#enabledBoolean Also known as: enabled?

Required. Whether ABAC authorization will be enabled in the cluster. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


9203
9204
9205
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9203

def enabled
  @enabled
end

#nameString

The name (project, location, cluster name) of the cluster to set legacy abac. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


9210
9211
9212
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9210

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9217
9218
9219
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9217

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9224
9225
9226
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9224

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9231
9232
9233
9234
9235
9236
9237
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9231

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @enabled = args[:enabled] if args.key?(:enabled)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end