Class: Google::Apis::ContainerV1beta1::SetLegacyAbacRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

SetLegacyAbacRequest enables or disables the ABAC authorization mechanism for a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetLegacyAbacRequest

Returns a new instance of SetLegacyAbacRequest.



9062
9063
9064
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9062

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to update. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9034
9035
9036
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9034

def cluster_id
  @cluster_id
end

#enabledBoolean Also known as: enabled?

Required. Whether ABAC authorization will be enabled in the cluster. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


9039
9040
9041
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9039

def enabled
  @enabled
end

#nameString

The name (project, location, cluster name) of the cluster to set legacy abac. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


9046
9047
9048
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9046

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9053
9054
9055
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9053

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9060
9061
9062
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9060

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9067
9068
9069
9070
9071
9072
9073
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9067

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @enabled = args[:enabled] if args.key?(:enabled)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end