Class: Google::Apis::ContainerV1beta1::SetLocationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

SetLocationsRequest sets the locations of the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetLocationsRequest

Returns a new instance of SetLocationsRequest.



9280
9281
9282
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9280

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9248
9249
9250
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9248

def cluster_id
  @cluster_id
end

#locationsArray<String>

Required. The desired list of Google Compute Engine zones in which the cluster's nodes should be located. Changing the locations a cluster is in will result in nodes being either created or removed from the cluster, depending on whether locations are being added or removed. This list must always include the cluster's primary zone. Corresponds to the JSON property locations

Returns:

  • (Array<String>)


9258
9259
9260
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9258

def locations
  @locations
end

#nameString

The name (project, location, cluster) of the cluster to set locations. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


9264
9265
9266
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9264

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9271
9272
9273
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9271

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9278
9279
9280
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9278

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9285
9286
9287
9288
9289
9290
9291
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9285

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @locations = args[:locations] if args.key?(:locations)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end