Class: Google::Apis::ContainerV1beta1::SetLoggingServiceRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::SetLoggingServiceRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
SetLoggingServiceRequest sets the logging service of a cluster.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#logging_service ⇒ String
Required.
-
#name ⇒ String
The name (project, location, cluster) of the cluster to set logging.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetLoggingServiceRequest
constructor
A new instance of SetLoggingServiceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetLoggingServiceRequest
Returns a new instance of SetLoggingServiceRequest.
10082 10083 10084 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10082 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster to upgrade. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
10049 10050 10051 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10049 def cluster_id @cluster_id end |
#logging_service ⇒ String
Required. The logging service the cluster should use to write logs. Currently
available options: * logging.googleapis.com/kubernetes - The Cloud Logging
service with a Kubernetes-native resource model * logging.googleapis.com -
The legacy Cloud Logging service (no longer available as of GKE 1.15). * none
- no logs will be exported from the cluster. If left as an empty string,
logging.googleapis.com/kuberneteswill be used for GKE 1.14+ orlogging. googleapis.comfor earlier versions. Corresponds to the JSON propertyloggingService
10060 10061 10062 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10060 def logging_service @logging_service end |
#name ⇒ String
The name (project, location, cluster) of the cluster to set logging. Specified
in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
10066 10067 10068 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10066 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
10073 10074 10075 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10073 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
10080 10081 10082 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10080 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10087 10088 10089 10090 10091 10092 10093 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10087 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @logging_service = args[:logging_service] if args.key?(:logging_service) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |