Class: Google::Apis::ContainerV1beta1::SetLoggingServiceRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

SetLoggingServiceRequest sets the logging service of a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetLoggingServiceRequest

Returns a new instance of SetLoggingServiceRequest.



9335
9336
9337
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9335

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9302
9303
9304
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9302

def cluster_id
  @cluster_id
end

#logging_serviceString

Required. The logging service the cluster should use to write logs. Currently available options: * logging.googleapis.com/kubernetes - The Cloud Logging service with a Kubernetes-native resource model * logging.googleapis.com - The legacy Cloud Logging service (no longer available as of GKE 1.15). * none

  • no logs will be exported from the cluster. If left as an empty string, logging.googleapis.com/kubernetes will be used for GKE 1.14+ or logging. googleapis.com for earlier versions. Corresponds to the JSON property loggingService

Returns:

  • (String)


9313
9314
9315
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9313

def logging_service
  @logging_service
end

#nameString

The name (project, location, cluster) of the cluster to set logging. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


9319
9320
9321
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9319

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9326
9327
9328
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9326

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9333
9334
9335
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9333

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9340
9341
9342
9343
9344
9345
9346
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9340

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @logging_service = args[:logging_service] if args.key?(:logging_service)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end