Class: Google::Apis::ContainerV1beta1::SetLoggingServiceRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::SetLoggingServiceRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
SetLoggingServiceRequest sets the logging service of a cluster.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#logging_service ⇒ String
Required.
-
#name ⇒ String
The name (project, location, cluster) of the cluster to set logging.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetLoggingServiceRequest
constructor
A new instance of SetLoggingServiceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetLoggingServiceRequest
Returns a new instance of SetLoggingServiceRequest.
9171 9172 9173 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9171 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster to upgrade. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
9138 9139 9140 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9138 def cluster_id @cluster_id end |
#logging_service ⇒ String
Required. The logging service the cluster should use to write logs. Currently
available options: * logging.googleapis.com/kubernetes - The Cloud Logging
service with a Kubernetes-native resource model * logging.googleapis.com -
The legacy Cloud Logging service (no longer available as of GKE 1.15). * none
- no logs will be exported from the cluster. If left as an empty string,
logging.googleapis.com/kuberneteswill be used for GKE 1.14+ orlogging. googleapis.comfor earlier versions. Corresponds to the JSON propertyloggingService
9149 9150 9151 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9149 def logging_service @logging_service end |
#name ⇒ String
The name (project, location, cluster) of the cluster to set logging. Specified
in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
9155 9156 9157 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9155 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
9162 9163 9164 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9162 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
9169 9170 9171 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9169 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9176 9177 9178 9179 9180 9181 9182 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9176 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @logging_service = args[:logging_service] if args.key?(:logging_service) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |