Class: Google::Apis::ContainerV1beta1::SetMaintenancePolicyRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

SetMaintenancePolicyRequest sets the maintenance policy for a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetMaintenancePolicyRequest

Returns a new instance of SetMaintenancePolicyRequest.



9381
9382
9383
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9381

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Required. The name of the cluster to update. Corresponds to the JSON property clusterId

Returns:

  • (String)


9356
9357
9358
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9356

def cluster_id
  @cluster_id
end

#maintenance_policyGoogle::Apis::ContainerV1beta1::MaintenancePolicy

MaintenancePolicy defines the maintenance policy to be used for the cluster. Corresponds to the JSON property maintenancePolicy



9361
9362
9363
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9361

def maintenance_policy
  @maintenance_policy
end

#nameString

The name (project, location, cluster name) of the cluster to set maintenance policy. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


9367
9368
9369
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9367

def name
  @name
end

#project_idString

Required. The Google Developers Console project ID or project number. Corresponds to the JSON property projectId

Returns:

  • (String)


9373
9374
9375
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9373

def project_id
  @project_id
end

#zoneString

Required. The name of the Google Compute Engine zone in which the cluster resides. Corresponds to the JSON property zone

Returns:

  • (String)


9379
9380
9381
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9379

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9386
9387
9388
9389
9390
9391
9392
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9386

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end