Class: Google::Apis::ContainerV1beta1::SetMaintenancePolicyRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::SetMaintenancePolicyRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
SetMaintenancePolicyRequest sets the maintenance policy for a cluster.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Required.
-
#maintenance_policy ⇒ Google::Apis::ContainerV1beta1::MaintenancePolicy
MaintenancePolicy defines the maintenance policy to be used for the cluster.
-
#name ⇒ String
The name (project, location, cluster name) of the cluster to set maintenance policy.
-
#project_id ⇒ String
Required.
-
#zone ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetMaintenancePolicyRequest
constructor
A new instance of SetMaintenancePolicyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetMaintenancePolicyRequest
Returns a new instance of SetMaintenancePolicyRequest.
9217 9218 9219 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Required. The name of the cluster to update.
Corresponds to the JSON property clusterId
9192 9193 9194 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9192 def cluster_id @cluster_id end |
#maintenance_policy ⇒ Google::Apis::ContainerV1beta1::MaintenancePolicy
MaintenancePolicy defines the maintenance policy to be used for the cluster.
Corresponds to the JSON property maintenancePolicy
9197 9198 9199 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9197 def maintenance_policy @maintenance_policy end |
#name ⇒ String
The name (project, location, cluster name) of the cluster to set maintenance
policy. Specified in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
9203 9204 9205 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9203 def name @name end |
#project_id ⇒ String
Required. The Google Developers Console project ID or project number.
Corresponds to the JSON property projectId
9209 9210 9211 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9209 def project_id @project_id end |
#zone ⇒ String
Required. The name of the Google Compute Engine zone in which the cluster resides.
Corresponds to the JSON property zone
9215 9216 9217 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9215 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9222 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |