Class: Google::Apis::ContainerV1beta1::SetMasterAuthRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::SetMasterAuthRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
SetMasterAuthRequest updates the admin password of a cluster.
Instance Attribute Summary collapse
-
#action ⇒ String
Required.
-
#cluster_id ⇒ String
Deprecated.
-
#name ⇒ String
The name (project, location, cluster) of the cluster to set auth.
-
#project_id ⇒ String
Deprecated.
-
#update ⇒ Google::Apis::ContainerV1beta1::MasterAuth
The authentication information for accessing the master endpoint.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetMasterAuthRequest
constructor
A new instance of SetMasterAuthRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetMasterAuthRequest
Returns a new instance of SetMasterAuthRequest.
10189 10190 10191 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10189 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Required. The exact form of action to be taken on the master auth.
Corresponds to the JSON property action
10155 10156 10157 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10155 def action @action end |
#cluster_id ⇒ String
Deprecated. The name of the cluster to upgrade. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
10161 10162 10163 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10161 def cluster_id @cluster_id end |
#name ⇒ String
The name (project, location, cluster) of the cluster to set auth. Specified in
the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
10167 10168 10169 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10167 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
10174 10175 10176 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10174 def project_id @project_id end |
#update ⇒ Google::Apis::ContainerV1beta1::MasterAuth
The authentication information for accessing the master endpoint.
Authentication can be done using HTTP basic auth or using client certificates.
Corresponds to the JSON property update
10180 10181 10182 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10180 def update @update end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
10187 10188 10189 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10187 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10194 10195 10196 10197 10198 10199 10200 10201 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10194 def update!(**args) @action = args[:action] if args.key?(:action) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @update = args[:update] if args.key?(:update) @zone = args[:zone] if args.key?(:zone) end |