Class: Google::Apis::ContainerV1beta1::SetMasterAuthRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

SetMasterAuthRequest updates the admin password of a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetMasterAuthRequest

Returns a new instance of SetMasterAuthRequest.



10055
10056
10057
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10055

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Required. The exact form of action to be taken on the master auth. Corresponds to the JSON property action

Returns:

  • (String)


10021
10022
10023
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10021

def action
  @action
end

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


10027
10028
10029
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10027

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster) of the cluster to set auth. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


10033
10034
10035
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10033

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


10040
10041
10042
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10040

def project_id
  @project_id
end

#updateGoogle::Apis::ContainerV1beta1::MasterAuth

The authentication information for accessing the master endpoint. Authentication can be done using HTTP basic auth or using client certificates. Corresponds to the JSON property update



10046
10047
10048
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10046

def update
  @update
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


10053
10054
10055
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10053

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10060
10061
10062
10063
10064
10065
10066
10067
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10060

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @update = args[:update] if args.key?(:update)
  @zone = args[:zone] if args.key?(:zone)
end