Class: Google::Apis::ContainerV1beta1::SetMasterAuthRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::SetMasterAuthRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
SetMasterAuthRequest updates the admin password of a cluster.
Instance Attribute Summary collapse
-
#action ⇒ String
Required.
-
#cluster_id ⇒ String
Deprecated.
-
#name ⇒ String
The name (project, location, cluster) of the cluster to set auth.
-
#project_id ⇒ String
Deprecated.
-
#update ⇒ Google::Apis::ContainerV1beta1::MasterAuth
The authentication information for accessing the master endpoint.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetMasterAuthRequest
constructor
A new instance of SetMasterAuthRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetMasterAuthRequest
Returns a new instance of SetMasterAuthRequest.
9272 9273 9274 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9272 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Required. The exact form of action to be taken on the master auth.
Corresponds to the JSON property action
9238 9239 9240 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9238 def action @action end |
#cluster_id ⇒ String
Deprecated. The name of the cluster to upgrade. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
9244 9245 9246 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9244 def cluster_id @cluster_id end |
#name ⇒ String
The name (project, location, cluster) of the cluster to set auth. Specified in
the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
9250 9251 9252 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9250 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
9257 9258 9259 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9257 def project_id @project_id end |
#update ⇒ Google::Apis::ContainerV1beta1::MasterAuth
The authentication information for accessing the master endpoint.
Authentication can be done using HTTP basic auth or using client certificates.
Corresponds to the JSON property update
9263 9264 9265 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9263 def update @update end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
9270 9271 9272 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9270 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9277 9278 9279 9280 9281 9282 9283 9284 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9277 def update!(**args) @action = args[:action] if args.key?(:action) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @update = args[:update] if args.key?(:update) @zone = args[:zone] if args.key?(:zone) end |