Class: Google::Apis::ContainerV1beta1::SetMonitoringServiceRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

SetMonitoringServiceRequest sets the monitoring service of a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetMonitoringServiceRequest

Returns a new instance of SetMonitoringServiceRequest.



10130
10131
10132
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10130

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


10097
10098
10099
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10097

def cluster_id
  @cluster_id
end

#monitoring_serviceString

Required. The monitoring service the cluster should use to write metrics. Currently available options: * monitoring.googleapis.com/kubernetes - The Cloud Monitoring service with a Kubernetes-native resource model * monitoring. googleapis.com - The legacy Cloud Monitoring service (no longer available as of GKE 1.15). * none - No metrics will be exported from the cluster. If left as an empty string,monitoring.googleapis.com/kubernetes will be used for GKE 1.14+ or monitoring.googleapis.com for earlier versions. Corresponds to the JSON property monitoringService

Returns:

  • (String)


10108
10109
10110
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10108

def monitoring_service
  @monitoring_service
end

#nameString

The name (project, location, cluster) of the cluster to set monitoring. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


10114
10115
10116
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10114

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


10121
10122
10123
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10121

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


10128
10129
10130
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10128

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10135
10136
10137
10138
10139
10140
10141
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10135

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @monitoring_service = args[:monitoring_service] if args.key?(:monitoring_service)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end