Class: Google::Apis::ContainerV1beta1::SetMonitoringServiceRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

SetMonitoringServiceRequest sets the monitoring service of a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetMonitoringServiceRequest

Returns a new instance of SetMonitoringServiceRequest.



9328
9329
9330
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9328

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9295
9296
9297
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9295

def cluster_id
  @cluster_id
end

#monitoring_serviceString

Required. The monitoring service the cluster should use to write metrics. Currently available options: * monitoring.googleapis.com/kubernetes - The Cloud Monitoring service with a Kubernetes-native resource model * monitoring. googleapis.com - The legacy Cloud Monitoring service (no longer available as of GKE 1.15). * none - No metrics will be exported from the cluster. If left as an empty string,monitoring.googleapis.com/kubernetes will be used for GKE 1.14+ or monitoring.googleapis.com for earlier versions. Corresponds to the JSON property monitoringService

Returns:

  • (String)


9306
9307
9308
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9306

def monitoring_service
  @monitoring_service
end

#nameString

The name (project, location, cluster) of the cluster to set monitoring. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


9312
9313
9314
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9312

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9319
9320
9321
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9319

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9326
9327
9328
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9326

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9333
9334
9335
9336
9337
9338
9339
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9333

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @monitoring_service = args[:monitoring_service] if args.key?(:monitoring_service)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end