Class: Google::Apis::ContainerV1beta1::SetNetworkPolicyRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::SetNetworkPolicyRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
SetNetworkPolicyRequest enables/disables network policy for a cluster.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#name ⇒ String
The name (project, location, cluster name) of the cluster to set networking policy.
-
#network_policy ⇒ Google::Apis::ContainerV1beta1::NetworkPolicy
Configuration options for the NetworkPolicy feature.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetNetworkPolicyRequest
constructor
A new instance of SetNetworkPolicyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetNetworkPolicyRequest
Returns a new instance of SetNetworkPolicyRequest.
10289 10290 10291 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10289 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster. This field has been deprecated and
replaced by the name field.
Corresponds to the JSON property clusterId
10261 10262 10263 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10261 def cluster_id @cluster_id end |
#name ⇒ String
The name (project, location, cluster name) of the cluster to set networking
policy. Specified in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
10267 10268 10269 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10267 def name @name end |
#network_policy ⇒ Google::Apis::ContainerV1beta1::NetworkPolicy
Configuration options for the NetworkPolicy feature. https://kubernetes.io/
docs/concepts/services-networking/networkpolicies/
Corresponds to the JSON property networkPolicy
10273 10274 10275 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10273 def network_policy @network_policy end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
10280 10281 10282 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10280 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
10287 10288 10289 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10287 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10294 10295 10296 10297 10298 10299 10300 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10294 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @name = args[:name] if args.key?(:name) @network_policy = args[:network_policy] if args.key?(:network_policy) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |