Class: Google::Apis::ContainerV1beta1::SetNetworkPolicyRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

SetNetworkPolicyRequest enables/disables network policy for a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetNetworkPolicyRequest

Returns a new instance of SetNetworkPolicyRequest.



10180
10181
10182
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10180

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


10152
10153
10154
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10152

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster name) of the cluster to set networking policy. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


10158
10159
10160
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10158

def name
  @name
end

#network_policyGoogle::Apis::ContainerV1beta1::NetworkPolicy

Configuration options for the NetworkPolicy feature. https://kubernetes.io/ docs/concepts/services-networking/networkpolicies/ Corresponds to the JSON property networkPolicy



10164
10165
10166
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10164

def network_policy
  @network_policy
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


10171
10172
10173
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10171

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


10178
10179
10180
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10178

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10185
10186
10187
10188
10189
10190
10191
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10185

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @network_policy = args[:network_policy] if args.key?(:network_policy)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end