Class: Google::Apis::ContainerV1beta1::SetNetworkPolicyRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

SetNetworkPolicyRequest enables/disables network policy for a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetNetworkPolicyRequest

Returns a new instance of SetNetworkPolicyRequest.



10161
10162
10163
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10161

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


10133
10134
10135
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10133

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster name) of the cluster to set networking policy. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


10139
10140
10141
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10139

def name
  @name
end

#network_policyGoogle::Apis::ContainerV1beta1::NetworkPolicy

Configuration options for the NetworkPolicy feature. https://kubernetes.io/ docs/concepts/services-networking/networkpolicies/ Corresponds to the JSON property networkPolicy



10145
10146
10147
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10145

def network_policy
  @network_policy
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


10152
10153
10154
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10152

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


10159
10160
10161
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10159

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10166
10167
10168
10169
10170
10171
10172
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10166

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @network_policy = args[:network_policy] if args.key?(:network_policy)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end