Class: Google::Apis::ContainerV1beta1::SetNetworkPolicyRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::SetNetworkPolicyRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
SetNetworkPolicyRequest enables/disables network policy for a cluster.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#name ⇒ String
The name (project, location, cluster name) of the cluster to set networking policy.
-
#network_policy ⇒ Google::Apis::ContainerV1beta1::NetworkPolicy
Configuration options for the NetworkPolicy feature.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetNetworkPolicyRequest
constructor
A new instance of SetNetworkPolicyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetNetworkPolicyRequest
Returns a new instance of SetNetworkPolicyRequest.
9542 9543 9544 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9542 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster. This field has been deprecated and
replaced by the name field.
Corresponds to the JSON property clusterId
9514 9515 9516 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9514 def cluster_id @cluster_id end |
#name ⇒ String
The name (project, location, cluster name) of the cluster to set networking
policy. Specified in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
9520 9521 9522 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9520 def name @name end |
#network_policy ⇒ Google::Apis::ContainerV1beta1::NetworkPolicy
Configuration options for the NetworkPolicy feature. https://kubernetes.io/
docs/concepts/services-networking/networkpolicies/
Corresponds to the JSON property networkPolicy
9526 9527 9528 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9526 def network_policy @network_policy end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
9533 9534 9535 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9533 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
9540 9541 9542 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9540 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9547 9548 9549 9550 9551 9552 9553 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9547 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @name = args[:name] if args.key?(:name) @network_policy = args[:network_policy] if args.key?(:network_policy) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |