Class: Google::Apis::ContainerV1beta1::SetNetworkPolicyRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

SetNetworkPolicyRequest enables/disables network policy for a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetNetworkPolicyRequest

Returns a new instance of SetNetworkPolicyRequest.



9378
9379
9380
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9350
9351
9352
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9350

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster name) of the cluster to set networking policy. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


9356
9357
9358
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9356

def name
  @name
end

#network_policyGoogle::Apis::ContainerV1beta1::NetworkPolicy

Configuration options for the NetworkPolicy feature. https://kubernetes.io/ docs/concepts/services-networking/networkpolicies/ Corresponds to the JSON property networkPolicy



9362
9363
9364
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9362

def network_policy
  @network_policy
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9369
9370
9371
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9369

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9376
9377
9378
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9376

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9383
9384
9385
9386
9387
9388
9389
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9383

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @network_policy = args[:network_policy] if args.key?(:network_policy)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end