Class: Google::Apis::ContainerV1beta1::SetNodePoolAutoscalingRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::SetNodePoolAutoscalingRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
SetNodePoolAutoscalingRequest sets the autoscaler settings of a node pool.
Instance Attribute Summary collapse
-
#autoscaling ⇒ Google::Apis::ContainerV1beta1::NodePoolAutoscaling
NodePoolAutoscaling contains information required by cluster autoscaler to adjust the size of the node pool to the current cluster usage.
-
#cluster_id ⇒ String
Deprecated.
-
#name ⇒ String
The name (project, location, cluster, node pool) of the node pool to set autoscaler settings.
-
#node_pool_id ⇒ String
Deprecated.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetNodePoolAutoscalingRequest
constructor
A new instance of SetNodePoolAutoscalingRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetNodePoolAutoscalingRequest
Returns a new instance of SetNodePoolAutoscalingRequest.
10346 10347 10348 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10346 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoscaling ⇒ Google::Apis::ContainerV1beta1::NodePoolAutoscaling
NodePoolAutoscaling contains information required by cluster autoscaler to
adjust the size of the node pool to the current cluster usage.
Corresponds to the JSON property autoscaling
10311 10312 10313 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10311 def autoscaling @autoscaling end |
#cluster_id ⇒ String
Deprecated. The name of the cluster to upgrade. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
10317 10318 10319 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10317 def cluster_id @cluster_id end |
#name ⇒ String
The name (project, location, cluster, node pool) of the node pool to set
autoscaler settings. Specified in the format projects/*/locations/*/clusters/*
/nodePools/*.
Corresponds to the JSON property name
10324 10325 10326 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10324 def name @name end |
#node_pool_id ⇒ String
Deprecated. The name of the node pool to upgrade. This field has been
deprecated and replaced by the name field.
Corresponds to the JSON property nodePoolId
10330 10331 10332 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10330 def node_pool_id @node_pool_id end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
10337 10338 10339 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10337 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
10344 10345 10346 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10344 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10351 10352 10353 10354 10355 10356 10357 10358 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10351 def update!(**args) @autoscaling = args[:autoscaling] if args.key?(:autoscaling) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @name = args[:name] if args.key?(:name) @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |