Class: Google::Apis::ContainerV1beta1::SetNodePoolAutoscalingRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::SetNodePoolAutoscalingRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
SetNodePoolAutoscalingRequest sets the autoscaler settings of a node pool.
Instance Attribute Summary collapse
-
#autoscaling ⇒ Google::Apis::ContainerV1beta1::NodePoolAutoscaling
NodePoolAutoscaling contains information required by cluster autoscaler to adjust the size of the node pool to the current cluster usage.
-
#cluster_id ⇒ String
Deprecated.
-
#name ⇒ String
The name (project, location, cluster, node pool) of the node pool to set autoscaler settings.
-
#node_pool_id ⇒ String
Deprecated.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetNodePoolAutoscalingRequest
constructor
A new instance of SetNodePoolAutoscalingRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetNodePoolAutoscalingRequest
Returns a new instance of SetNodePoolAutoscalingRequest.
10218 10219 10220 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10218 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoscaling ⇒ Google::Apis::ContainerV1beta1::NodePoolAutoscaling
NodePoolAutoscaling contains information required by cluster autoscaler to
adjust the size of the node pool to the current cluster usage.
Corresponds to the JSON property autoscaling
10183 10184 10185 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10183 def autoscaling @autoscaling end |
#cluster_id ⇒ String
Deprecated. The name of the cluster to upgrade. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
10189 10190 10191 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10189 def cluster_id @cluster_id end |
#name ⇒ String
The name (project, location, cluster, node pool) of the node pool to set
autoscaler settings. Specified in the format projects/*/locations/*/clusters/*
/nodePools/*.
Corresponds to the JSON property name
10196 10197 10198 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10196 def name @name end |
#node_pool_id ⇒ String
Deprecated. The name of the node pool to upgrade. This field has been
deprecated and replaced by the name field.
Corresponds to the JSON property nodePoolId
10202 10203 10204 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10202 def node_pool_id @node_pool_id end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
10209 10210 10211 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10209 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
10216 10217 10218 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10216 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10223 10224 10225 10226 10227 10228 10229 10230 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10223 def update!(**args) @autoscaling = args[:autoscaling] if args.key?(:autoscaling) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @name = args[:name] if args.key?(:name) @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |