Class: Google::Apis::ContainerV1beta1::SetNodePoolAutoscalingRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::SetNodePoolAutoscalingRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
SetNodePoolAutoscalingRequest sets the autoscaler settings of a node pool.
Instance Attribute Summary collapse
-
#autoscaling ⇒ Google::Apis::ContainerV1beta1::NodePoolAutoscaling
NodePoolAutoscaling contains information required by cluster autoscaler to adjust the size of the node pool to the current cluster usage.
-
#cluster_id ⇒ String
Deprecated.
-
#name ⇒ String
The name (project, location, cluster, node pool) of the node pool to set autoscaler settings.
-
#node_pool_id ⇒ String
Deprecated.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetNodePoolAutoscalingRequest
constructor
A new instance of SetNodePoolAutoscalingRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetNodePoolAutoscalingRequest
Returns a new instance of SetNodePoolAutoscalingRequest.
9599 9600 9601 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9599 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoscaling ⇒ Google::Apis::ContainerV1beta1::NodePoolAutoscaling
NodePoolAutoscaling contains information required by cluster autoscaler to
adjust the size of the node pool to the current cluster usage.
Corresponds to the JSON property autoscaling
9564 9565 9566 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9564 def autoscaling @autoscaling end |
#cluster_id ⇒ String
Deprecated. The name of the cluster to upgrade. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
9570 9571 9572 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9570 def cluster_id @cluster_id end |
#name ⇒ String
The name (project, location, cluster, node pool) of the node pool to set
autoscaler settings. Specified in the format projects/*/locations/*/clusters/*
/nodePools/*.
Corresponds to the JSON property name
9577 9578 9579 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9577 def name @name end |
#node_pool_id ⇒ String
Deprecated. The name of the node pool to upgrade. This field has been
deprecated and replaced by the name field.
Corresponds to the JSON property nodePoolId
9583 9584 9585 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9583 def node_pool_id @node_pool_id end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
9590 9591 9592 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9590 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
9597 9598 9599 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9597 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9604 9605 9606 9607 9608 9609 9610 9611 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9604 def update!(**args) @autoscaling = args[:autoscaling] if args.key?(:autoscaling) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @name = args[:name] if args.key?(:name) @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |