Class: Google::Apis::ContainerV1beta1::SetNodePoolManagementRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::SetNodePoolManagementRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
SetNodePoolManagementRequest sets the node management properties of a node pool.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#management ⇒ Google::Apis::ContainerV1beta1::NodeManagement
NodeManagement defines the set of node management services turned on for the node pool.
-
#name ⇒ String
The name (project, location, cluster, node pool id) of the node pool to set management properties.
-
#node_pool_id ⇒ String
Deprecated.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetNodePoolManagementRequest
constructor
A new instance of SetNodePoolManagementRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetNodePoolManagementRequest
Returns a new instance of SetNodePoolManagementRequest.
10277 10278 10279 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10277 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster to update. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
10242 10243 10244 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10242 def cluster_id @cluster_id end |
#management ⇒ Google::Apis::ContainerV1beta1::NodeManagement
NodeManagement defines the set of node management services turned on for the
node pool.
Corresponds to the JSON property management
10248 10249 10250 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10248 def management @management end |
#name ⇒ String
The name (project, location, cluster, node pool id) of the node pool to set
management properties. Specified in the format projects/*/locations/*/
clusters/*/nodePools/*.
Corresponds to the JSON property name
10255 10256 10257 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10255 def name @name end |
#node_pool_id ⇒ String
Deprecated. The name of the node pool to update. This field has been
deprecated and replaced by the name field.
Corresponds to the JSON property nodePoolId
10261 10262 10263 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10261 def node_pool_id @node_pool_id end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
10268 10269 10270 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10268 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
10275 10276 10277 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10275 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10282 10283 10284 10285 10286 10287 10288 10289 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10282 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @management = args[:management] if args.key?(:management) @name = args[:name] if args.key?(:name) @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |