Class: Google::Apis::ContainerV1beta1::SetNodePoolSizeRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::SetNodePoolSizeRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
SetNodePoolSizeRequest sets the size of a node pool.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#name ⇒ String
The name (project, location, cluster, node pool id) of the node pool to set size.
-
#node_count ⇒ Fixnum
Required.
-
#node_pool_id ⇒ String
Deprecated.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetNodePoolSizeRequest
constructor
A new instance of SetNodePoolSizeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetNodePoolSizeRequest
Returns a new instance of SetNodePoolSizeRequest.
10461 10462 10463 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10461 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster to update. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
10428 10429 10430 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10428 def cluster_id @cluster_id end |
#name ⇒ String
The name (project, location, cluster, node pool id) of the node pool to set
size. Specified in the format projects/*/locations/*/clusters/*/nodePools/*.
Corresponds to the JSON property name
10434 10435 10436 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10434 def name @name end |
#node_count ⇒ Fixnum
Required. The desired node count for the pool.
Corresponds to the JSON property nodeCount
10439 10440 10441 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10439 def node_count @node_count end |
#node_pool_id ⇒ String
Deprecated. The name of the node pool to update. This field has been
deprecated and replaced by the name field.
Corresponds to the JSON property nodePoolId
10445 10446 10447 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10445 def node_pool_id @node_pool_id end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
10452 10453 10454 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10452 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
10459 10460 10461 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10459 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10466 10467 10468 10469 10470 10471 10472 10473 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10466 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @name = args[:name] if args.key?(:name) @node_count = args[:node_count] if args.key?(:node_count) @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |