Class: Google::Apis::ContainerV1beta1::SetNodePoolSizeRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::SetNodePoolSizeRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
SetNodePoolSizeRequest sets the size of a node pool.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#name ⇒ String
The name (project, location, cluster, node pool id) of the node pool to set size.
-
#node_count ⇒ Fixnum
Required.
-
#node_pool_id ⇒ String
Deprecated.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetNodePoolSizeRequest
constructor
A new instance of SetNodePoolSizeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetNodePoolSizeRequest
Returns a new instance of SetNodePoolSizeRequest.
10352 10353 10354 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10352 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster to update. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
10319 10320 10321 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10319 def cluster_id @cluster_id end |
#name ⇒ String
The name (project, location, cluster, node pool id) of the node pool to set
size. Specified in the format projects/*/locations/*/clusters/*/nodePools/*.
Corresponds to the JSON property name
10325 10326 10327 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10325 def name @name end |
#node_count ⇒ Fixnum
Required. The desired node count for the pool.
Corresponds to the JSON property nodeCount
10330 10331 10332 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10330 def node_count @node_count end |
#node_pool_id ⇒ String
Deprecated. The name of the node pool to update. This field has been
deprecated and replaced by the name field.
Corresponds to the JSON property nodePoolId
10336 10337 10338 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10336 def node_pool_id @node_pool_id end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
10343 10344 10345 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10343 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
10350 10351 10352 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10350 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10357 10358 10359 10360 10361 10362 10363 10364 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10357 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @name = args[:name] if args.key?(:name) @node_count = args[:node_count] if args.key?(:node_count) @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |