Class: Google::Apis::ContainerV1beta1::SetNodePoolSizeRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

SetNodePoolSizeRequest sets the size of a node pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetNodePoolSizeRequest

Returns a new instance of SetNodePoolSizeRequest.



10333
10334
10335
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10333

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to update. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


10300
10301
10302
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10300

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster, node pool id) of the node pool to set size. Specified in the format projects/*/locations/*/clusters/*/nodePools/*. Corresponds to the JSON property name

Returns:

  • (String)


10306
10307
10308
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10306

def name
  @name
end

#node_countFixnum

Required. The desired node count for the pool. Corresponds to the JSON property nodeCount

Returns:

  • (Fixnum)


10311
10312
10313
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10311

def node_count
  @node_count
end

#node_pool_idString

Deprecated. The name of the node pool to update. This field has been deprecated and replaced by the name field. Corresponds to the JSON property nodePoolId

Returns:

  • (String)


10317
10318
10319
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10317

def node_pool_id
  @node_pool_id
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


10324
10325
10326
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10324

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


10331
10332
10333
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10331

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10338
10339
10340
10341
10342
10343
10344
10345
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10338

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @node_count = args[:node_count] if args.key?(:node_count)
  @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end