Class: Google::Apis::ContainerV1beta1::ShieldedInstanceConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

A set of Shielded Instance options.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ShieldedInstanceConfig

Returns a new instance of ShieldedInstanceConfig.



10371
10372
10373
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10371

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_integrity_monitoringBoolean Also known as: enable_integrity_monitoring?

Defines whether the instance has integrity monitoring enabled. Enables monitoring and attestation of the boot integrity of the instance. The attestation is performed against the integrity policy baseline. This baseline is initially derived from the implicitly trusted boot image when the instance is created. Corresponds to the JSON property enableIntegrityMonitoring

Returns:

  • (Boolean)


10359
10360
10361
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10359

def enable_integrity_monitoring
  @enable_integrity_monitoring
end

#enable_secure_bootBoolean Also known as: enable_secure_boot?

Defines whether the instance has Secure Boot enabled. Secure Boot helps ensure that the system only runs authentic software by verifying the digital signature of all boot components, and halting the boot process if signature verification fails. Corresponds to the JSON property enableSecureBoot

Returns:

  • (Boolean)


10368
10369
10370
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10368

def enable_secure_boot
  @enable_secure_boot
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10376
10377
10378
10379
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10376

def update!(**args)
  @enable_integrity_monitoring = args[:enable_integrity_monitoring] if args.key?(:enable_integrity_monitoring)
  @enable_secure_boot = args[:enable_secure_boot] if args.key?(:enable_secure_boot)
end