Class: Google::Apis::ContainerV1beta1::ShieldedInstanceConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::ShieldedInstanceConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
A set of Shielded Instance options.
Instance Attribute Summary collapse
-
#enable_integrity_monitoring ⇒ Boolean
(also: #enable_integrity_monitoring?)
Defines whether the instance has integrity monitoring enabled.
-
#enable_secure_boot ⇒ Boolean
(also: #enable_secure_boot?)
Defines whether the instance has Secure Boot enabled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ShieldedInstanceConfig
constructor
A new instance of ShieldedInstanceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ShieldedInstanceConfig
Returns a new instance of ShieldedInstanceConfig.
9752 9753 9754 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9752 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_integrity_monitoring ⇒ Boolean Also known as: enable_integrity_monitoring?
Defines whether the instance has integrity monitoring enabled. Enables
monitoring and attestation of the boot integrity of the instance. The
attestation is performed against the integrity policy baseline. This baseline
is initially derived from the implicitly trusted boot image when the instance
is created.
Corresponds to the JSON property enableIntegrityMonitoring
9740 9741 9742 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9740 def enable_integrity_monitoring @enable_integrity_monitoring end |
#enable_secure_boot ⇒ Boolean Also known as: enable_secure_boot?
Defines whether the instance has Secure Boot enabled. Secure Boot helps ensure
that the system only runs authentic software by verifying the digital
signature of all boot components, and halting the boot process if signature
verification fails.
Corresponds to the JSON property enableSecureBoot
9749 9750 9751 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9749 def enable_secure_boot @enable_secure_boot end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9757 9758 9759 9760 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 9757 def update!(**args) @enable_integrity_monitoring = args[:enable_integrity_monitoring] if args.key?(:enable_integrity_monitoring) @enable_secure_boot = args[:enable_secure_boot] if args.key?(:enable_secure_boot) end |