Class: Google::Apis::ContainerV1beta1::StartIpRotationRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::StartIpRotationRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
StartIPRotationRequest creates a new IP for the cluster and then performs a node upgrade on each node pool to point to the new IP.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#name ⇒ String
The name (project, location, cluster name) of the cluster to start IP rotation.
-
#project_id ⇒ String
Deprecated.
-
#rotate_credentials ⇒ Boolean
(also: #rotate_credentials?)
Whether to rotate credentials during IP rotation.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StartIpRotationRequest
constructor
A new instance of StartIpRotationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StartIpRotationRequest
Returns a new instance of StartIpRotationRequest.
10667 10668 10669 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10667 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster. This field has been deprecated and
replaced by the name field.
Corresponds to the JSON property clusterId
10639 10640 10641 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10639 def cluster_id @cluster_id end |
#name ⇒ String
The name (project, location, cluster name) of the cluster to start IP rotation.
Specified in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
10645 10646 10647 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10645 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
10652 10653 10654 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10652 def project_id @project_id end |
#rotate_credentials ⇒ Boolean Also known as: rotate_credentials?
Whether to rotate credentials during IP rotation.
Corresponds to the JSON property rotateCredentials
10657 10658 10659 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10657 def rotate_credentials @rotate_credentials end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
10665 10666 10667 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10665 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10672 10673 10674 10675 10676 10677 10678 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10672 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @rotate_credentials = args[:rotate_credentials] if args.key?(:rotate_credentials) @zone = args[:zone] if args.key?(:zone) end |