Class: Google::Apis::ContainerV1beta1::StartIpRotationRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

StartIPRotationRequest creates a new IP for the cluster and then performs a node upgrade on each node pool to point to the new IP.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StartIpRotationRequest

Returns a new instance of StartIpRotationRequest.



10539
10540
10541
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10539

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


10511
10512
10513
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10511

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster name) of the cluster to start IP rotation. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


10517
10518
10519
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10517

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


10524
10525
10526
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10524

def project_id
  @project_id
end

#rotate_credentialsBoolean Also known as: rotate_credentials?

Whether to rotate credentials during IP rotation. Corresponds to the JSON property rotateCredentials

Returns:

  • (Boolean)


10529
10530
10531
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10529

def rotate_credentials
  @rotate_credentials
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


10537
10538
10539
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10537

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10544
10545
10546
10547
10548
10549
10550
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10544

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @rotate_credentials = args[:rotate_credentials] if args.key?(:rotate_credentials)
  @zone = args[:zone] if args.key?(:zone)
end