Class: Google::Apis::ContainerV1beta1::StatusCondition
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::StatusCondition
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
StatusCondition describes why a cluster or a node pool has a certain status (e. g., ERROR or DEGRADED).
Instance Attribute Summary collapse
-
#canonical_code ⇒ String
Canonical code of the condition.
-
#code ⇒ String
Machine-friendly representation of the condition Deprecated.
-
#message ⇒ String
Human-friendly representation of the condition Corresponds to the JSON property
message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StatusCondition
constructor
A new instance of StatusCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StatusCondition
Returns a new instance of StatusCondition.
10761 10762 10763 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10761 def initialize(**args) update!(**args) end |
Instance Attribute Details
#canonical_code ⇒ String
Canonical code of the condition.
Corresponds to the JSON property canonicalCode
10748 10749 10750 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10748 def canonical_code @canonical_code end |
#code ⇒ String
Machine-friendly representation of the condition Deprecated. Use
canonical_code instead.
Corresponds to the JSON property code
10754 10755 10756 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10754 def code @code end |
#message ⇒ String
Human-friendly representation of the condition
Corresponds to the JSON property message
10759 10760 10761 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10759 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10766 10767 10768 10769 10770 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10766 def update!(**args) @canonical_code = args[:canonical_code] if args.key?(:canonical_code) @code = args[:code] if args.key?(:code) @message = args[:message] if args.key?(:message) end |