Class: Google::Apis::ContainerV1beta1::UpdateMasterRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

UpdateMasterRequest updates the master of the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateMasterRequest

Returns a new instance of UpdateMasterRequest.



11018
11019
11020
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11018

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


10985
10986
10987
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10985

def cluster_id
  @cluster_id
end

#master_versionString

Required. The Kubernetes version to change the master to. Users may specify either explicit versions offered by Kubernetes Engine or version aliases, which have the following behavior: - "latest": picks the highest valid Kubernetes version - "1.X": picks the highest valid patch+gke.N patch in the 1. X version - "1.X.Y": picks the highest valid gke.N patch in the 1.X.Y version - "1.X.Y-gke.N": picks an explicit Kubernetes version - "-": picks the default Kubernetes version Corresponds to the JSON property masterVersion

Returns:

  • (String)


10996
10997
10998
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10996

def master_version
  @master_version
end

#nameString

The name (project, location, cluster) of the cluster to update. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


11002
11003
11004
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11002

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


11009
11010
11011
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11009

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


11016
11017
11018
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11016

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11023
11024
11025
11026
11027
11028
11029
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11023

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @master_version = args[:master_version] if args.key?(:master_version)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end