Class: Google::Apis::ContainerV1beta1::UpdateMasterRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

UpdateMasterRequest updates the master of the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateMasterRequest

Returns a new instance of UpdateMasterRequest.



10112
10113
10114
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10112

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


10079
10080
10081
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10079

def cluster_id
  @cluster_id
end

#master_versionString

Required. The Kubernetes version to change the master to. Users may specify either explicit versions offered by Kubernetes Engine or version aliases, which have the following behavior: - "latest": picks the highest valid Kubernetes version - "1.X": picks the highest valid patch+gke.N patch in the 1. X version - "1.X.Y": picks the highest valid gke.N patch in the 1.X.Y version - "1.X.Y-gke.N": picks an explicit Kubernetes version - "-": picks the default Kubernetes version Corresponds to the JSON property masterVersion

Returns:

  • (String)


10090
10091
10092
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10090

def master_version
  @master_version
end

#nameString

The name (project, location, cluster) of the cluster to update. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


10096
10097
10098
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10096

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


10103
10104
10105
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10103

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


10110
10111
10112
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10110

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10117
10118
10119
10120
10121
10122
10123
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10117

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @master_version = args[:master_version] if args.key?(:master_version)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end