Class: Google::Apis::ContainerV1beta1::UpdateNodePoolRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

SetNodePoolVersionRequest updates the version of a node pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateNodePoolRequest

Returns a new instance of UpdateNodePoolRequest.



10582
10583
10584
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10582

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acceleratorsArray<Google::Apis::ContainerV1beta1::AcceleratorConfig>

A list of hardware accelerators to be attached to each node. See https://cloud. google.com/compute/docs/gpus for more information about support for GPUs. Corresponds to the JSON property accelerators



10318
10319
10320
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10318

def accelerators
  @accelerators
end

#boot_diskGoogle::Apis::ContainerV1beta1::BootDisk

BootDisk specifies the boot disk configuration for nodepools. Corresponds to the JSON property bootDisk



10323
10324
10325
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10323

def boot_disk
  @boot_disk
end

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


10329
10330
10331
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10329

def cluster_id
  @cluster_id
end

#confidential_nodesGoogle::Apis::ContainerV1beta1::ConfidentialNodes

ConfidentialNodes is configuration for the confidential nodes feature, which makes nodes run on confidential VMs. Corresponds to the JSON property confidentialNodes



10335
10336
10337
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10335

def confidential_nodes
  @confidential_nodes
end

#consolidation_delayString

Consolidation delay defines duration after which the Cluster Autoscaler can scale down underutilized nodes. If not set, nodes are scaled down by default behavior, i.e. according to the chosen autoscaling profile. Corresponds to the JSON property consolidationDelay

Returns:

  • (String)


10342
10343
10344
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10342

def consolidation_delay
  @consolidation_delay
end

#containerd_configGoogle::Apis::ContainerV1beta1::ContainerdConfig

ContainerdConfig contains configuration to customize containerd. Corresponds to the JSON property containerdConfig



10347
10348
10349
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10347

def containerd_config
  @containerd_config
end

#disk_size_gbFixnum

Optional. The desired disk size for nodes in the node pool. Initiates an upgrade operation that migrates the nodes in the node pool to the specified disk size. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


10354
10355
10356
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10354

def disk_size_gb
  @disk_size_gb
end

#disk_typeString

Optional. The desired disk type for nodes in the node pool. Initiates an upgrade operation that migrates the nodes in the node pool to the specified disk type. Corresponds to the JSON property diskType

Returns:

  • (String)


10361
10362
10363
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10361

def disk_type
  @disk_type
end

#etagString

The current etag of the node pool. If an etag is provided and does not match the current etag of the node pool, update will be blocked and an ABORTED error will be returned. Corresponds to the JSON property etag

Returns:

  • (String)


10368
10369
10370
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10368

def etag
  @etag
end

#fast_socketGoogle::Apis::ContainerV1beta1::FastSocket

Configuration of Fast Socket feature. Corresponds to the JSON property fastSocket



10373
10374
10375
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10373

def fast_socket
  @fast_socket
end

#flex_startBoolean Also known as: flex_start?

Flex Start flag for enabling Flex Start VM. Corresponds to the JSON property flexStart

Returns:

  • (Boolean)


10378
10379
10380
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10378

def flex_start
  @flex_start
end

#gcfs_configGoogle::Apis::ContainerV1beta1::GcfsConfig

GcfsConfig contains configurations of Google Container File System. Corresponds to the JSON property gcfsConfig



10384
10385
10386
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10384

def gcfs_config
  @gcfs_config
end

#gvnicGoogle::Apis::ContainerV1beta1::VirtualNic

Configuration of gVNIC feature. Corresponds to the JSON property gvnic



10389
10390
10391
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10389

def gvnic
  @gvnic
end

#image_typeString

Required. The desired image type for the node pool. Please see https://cloud. google.com/kubernetes-engine/docs/concepts/node-images for available image types. Corresponds to the JSON property imageType

Returns:

  • (String)


10396
10397
10398
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10396

def image_type
  @image_type
end

#kubelet_configGoogle::Apis::ContainerV1beta1::NodeKubeletConfig

Node kubelet configs. Corresponds to the JSON property kubeletConfig



10401
10402
10403
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10401

def kubelet_config
  @kubelet_config
end

#labelsGoogle::Apis::ContainerV1beta1::NodeLabels

Collection of node-level Kubernetes labels. Corresponds to the JSON property labels



10407
10408
10409
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10407

def labels
  @labels
end

#linux_node_configGoogle::Apis::ContainerV1beta1::LinuxNodeConfig

Parameters that can be configured on Linux nodes. Corresponds to the JSON property linuxNodeConfig



10412
10413
10414
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10412

def linux_node_config
  @linux_node_config
end

#locationsArray<String>

The desired list of Google Compute Engine zones in which the node pool's nodes should be located. Changing the locations for a node pool will result in nodes being either created or removed from the node pool, depending on whether locations are being added or removed. Warning: It is recommended to update node pool locations in a standalone API call. Do not combine a location update with changes to other fields (such as tags, labels, taints, etc.) in the same request. Otherwise, the API performs a structural modification where changes to other fields will only apply to newly created nodes and will not be applied to existing nodes in the node pool. To ensure all nodes are updated consistently, use a separate API call for location changes. Corresponds to the JSON property locations

Returns:

  • (Array<String>)


10427
10428
10429
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10427

def locations
  @locations
end

#logging_configGoogle::Apis::ContainerV1beta1::NodePoolLoggingConfig

NodePoolLoggingConfig specifies logging configuration for nodepools. Corresponds to the JSON property loggingConfig



10432
10433
10434
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10432

def logging_config
  @logging_config
end

#machine_typeString

Optional. The desired machine type for nodes in the node pool. Initiates an upgrade operation that migrates the nodes in the node pool to the specified machine type. Corresponds to the JSON property machineType

Returns:

  • (String)


10439
10440
10441
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10439

def machine_type
  @machine_type
end

#max_run_durationString

The maximum duration for the nodes to exist. If unspecified, the nodes can exist indefinitely. Corresponds to the JSON property maxRunDuration

Returns:

  • (String)


10445
10446
10447
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10445

def max_run_duration
  @max_run_duration
end

#nameString

The name (project, location, cluster, node pool) of the node pool to update. Specified in the format projects/*/locations/*/clusters/*/nodePools/*. Corresponds to the JSON property name

Returns:

  • (String)


10451
10452
10453
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10451

def name
  @name
end

#node_drain_configGoogle::Apis::ContainerV1beta1::NodeDrainConfig

NodeDrainConfig contains the node drain related configurations for this nodepool. Corresponds to the JSON property nodeDrainConfig



10457
10458
10459
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10457

def node_drain_config
  @node_drain_config
end

#node_network_configGoogle::Apis::ContainerV1beta1::NodeNetworkConfig

Parameters for node pool-level network config. Corresponds to the JSON property nodeNetworkConfig



10462
10463
10464
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10462

def node_network_config
  @node_network_config
end

#node_pool_idString

Deprecated. The name of the node pool to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property nodePoolId

Returns:

  • (String)


10468
10469
10470
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10468

def node_pool_id
  @node_pool_id
end

#node_versionString

Required. The Kubernetes version to change the nodes to (typically an upgrade). Users may specify either explicit versions offered by Kubernetes Engine or version aliases, which have the following behavior: - "latest": picks the highest valid Kubernetes version - "1.X": picks the highest valid patch+gke.N patch in the 1.X version - "1.X.Y": picks the highest valid gke.N patch in the 1.X.Y version - "1.X.Y-gke.N": picks an explicit Kubernetes version - "-": picks the Kubernetes master version Corresponds to the JSON property nodeVersion

Returns:

  • (String)


10479
10480
10481
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10479

def node_version
  @node_version
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


10486
10487
10488
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10486

def project_id
  @project_id
end

#queued_provisioningGoogle::Apis::ContainerV1beta1::QueuedProvisioning

QueuedProvisioning defines the queued provisioning used by the node pool. Corresponds to the JSON property queuedProvisioning



10491
10492
10493
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10491

def queued_provisioning
  @queued_provisioning
end

#resource_labelsGoogle::Apis::ContainerV1beta1::ResourceLabels

Collection of Resource Manager labels. Corresponds to the JSON property resourceLabels



10497
10498
10499
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10497

def resource_labels
  @resource_labels
end

#resource_manager_tagsGoogle::Apis::ContainerV1beta1::ResourceManagerTags

A map of resource manager tag keys and values to be attached to the nodes for managing Compute Engine firewalls using Network Firewall Policies. Tags must be according to specifications in https://cloud.google.com/vpc/docs/tags- firewalls-overview#specifications. A maximum of 5 tag key-value pairs can be specified. Existing tags will be replaced with new values. Corresponds to the JSON property resourceManagerTags



10506
10507
10508
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10506

def resource_manager_tags
  @resource_manager_tags
end

#storage_poolsArray<String>

List of Storage Pools where boot disks are provisioned. Existing Storage Pools will be replaced with storage-pools. Corresponds to the JSON property storagePools

Returns:

  • (Array<String>)


10512
10513
10514
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10512

def storage_pools
  @storage_pools
end

#tagsGoogle::Apis::ContainerV1beta1::NetworkTags

Collection of Compute Engine network tags that can be applied to a node's underlying VM instance. (See tags field in NodeConfig). Corresponds to the JSON property tags



10519
10520
10521
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10519

def tags
  @tags
end

#taintsGoogle::Apis::ContainerV1beta1::NodeTaints

Collection of Kubernetes node taints. Corresponds to the JSON property taints



10525
10526
10527
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10525

def taints
  @taints
end

#upgrade_settingsGoogle::Apis::ContainerV1beta1::UpgradeSettings

These upgrade settings control the level of parallelism and the level of disruption caused by an upgrade. maxUnavailable controls the number of nodes that can be simultaneously unavailable. maxSurge controls the number of additional nodes that can be added to the node pool temporarily for the time of the upgrade to increase the number of available nodes. (maxUnavailable + maxSurge) determines the level of parallelism (how many nodes are being upgraded at the same time). Note: upgrades inevitably introduce some disruption since workloads need to be moved from old nodes to new, upgraded ones. Even if maxUnavailable=0, this holds true. (Disruption stays within the limits of PodDisruptionBudget, if it is configured.) Consider a hypothetical node pool with 5 nodes having maxSurge=2, maxUnavailable=1. This means the upgrade process upgrades 3 nodes simultaneously. It creates 2 additional ( upgraded) nodes, then it brings down 3 old (not yet upgraded) nodes at the same time. This ensures that there are always at least 4 nodes available. These upgrade settings configure the upgrade strategy for the node pool. Use strategy to switch between the strategies applied to the node pool. If the strategy is SURGE, use max_surge and max_unavailable to control the level of parallelism and the level of disruption caused by upgrade. 1. maxSurge controls the number of additional nodes that can be added to the node pool temporarily for the time of the upgrade to increase the number of available nodes. 2. maxUnavailable controls the number of nodes that can be simultaneously unavailable. 3. (maxUnavailable + maxSurge) determines the level of parallelism (how many nodes are being upgraded at the same time). If the strategy is BLUE_GREEN, use blue_green_settings to configure the blue- green upgrade related settings. 1. standard_rollout_policy is the default policy. The policy is used to control the way blue pool gets drained. The draining is executed in the batch mode. The batch size could be specified as either percentage of the node pool size or the number of nodes. batch_soak_duration is the soak time after each batch gets drained. 2. node_pool_soak_duration is the soak time after all blue nodes are drained. After this period, the blue pool nodes will be deleted. Corresponds to the JSON property upgradeSettings



10560
10561
10562
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10560

def upgrade_settings
  @upgrade_settings
end

#windows_node_configGoogle::Apis::ContainerV1beta1::WindowsNodeConfig

Parameters that can be configured on Windows nodes. Windows Node Config that define the parameters that will be used to configure the Windows node pool settings. Corresponds to the JSON property windowsNodeConfig



10567
10568
10569
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10567

def windows_node_config
  @windows_node_config
end

#workload_metadata_configGoogle::Apis::ContainerV1beta1::WorkloadMetadataConfig

WorkloadMetadataConfig defines the metadata configuration to expose to workloads on the node pool. Corresponds to the JSON property workloadMetadataConfig



10573
10574
10575
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10573

def 
  @workload_metadata_config
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


10580
10581
10582
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10580

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10587
10588
10589
10590
10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
10601
10602
10603
10604
10605
10606
10607
10608
10609
10610
10611
10612
10613
10614
10615
10616
10617
10618
10619
10620
10621
10622
10623
10624
10625
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10587

def update!(**args)
  @accelerators = args[:accelerators] if args.key?(:accelerators)
  @boot_disk = args[:boot_disk] if args.key?(:boot_disk)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @confidential_nodes = args[:confidential_nodes] if args.key?(:confidential_nodes)
  @consolidation_delay = args[:consolidation_delay] if args.key?(:consolidation_delay)
  @containerd_config = args[:containerd_config] if args.key?(:containerd_config)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @disk_type = args[:disk_type] if args.key?(:disk_type)
  @etag = args[:etag] if args.key?(:etag)
  @fast_socket = args[:fast_socket] if args.key?(:fast_socket)
  @flex_start = args[:flex_start] if args.key?(:flex_start)
  @gcfs_config = args[:gcfs_config] if args.key?(:gcfs_config)
  @gvnic = args[:gvnic] if args.key?(:gvnic)
  @image_type = args[:image_type] if args.key?(:image_type)
  @kubelet_config = args[:kubelet_config] if args.key?(:kubelet_config)
  @labels = args[:labels] if args.key?(:labels)
  @linux_node_config = args[:linux_node_config] if args.key?(:linux_node_config)
  @locations = args[:locations] if args.key?(:locations)
  @logging_config = args[:logging_config] if args.key?(:logging_config)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @max_run_duration = args[:max_run_duration] if args.key?(:max_run_duration)
  @name = args[:name] if args.key?(:name)
  @node_drain_config = args[:node_drain_config] if args.key?(:node_drain_config)
  @node_network_config = args[:node_network_config] if args.key?(:node_network_config)
  @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id)
  @node_version = args[:node_version] if args.key?(:node_version)
  @project_id = args[:project_id] if args.key?(:project_id)
  @queued_provisioning = args[:queued_provisioning] if args.key?(:queued_provisioning)
  @resource_labels = args[:resource_labels] if args.key?(:resource_labels)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
  @storage_pools = args[:storage_pools] if args.key?(:storage_pools)
  @tags = args[:tags] if args.key?(:tags)
  @taints = args[:taints] if args.key?(:taints)
  @upgrade_settings = args[:upgrade_settings] if args.key?(:upgrade_settings)
  @windows_node_config = args[:windows_node_config] if args.key?(:windows_node_config)
  @workload_metadata_config = args[:workload_metadata_config] if args.key?(:workload_metadata_config)
  @zone = args[:zone] if args.key?(:zone)
end