Class: Google::Apis::ContainerV1beta1::UpgradeInfoEvent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

UpgradeInfoEvent is a notification sent to customers about the upgrade information of a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeInfoEvent

Returns a new instance of UpgradeInfoEvent.



11631
11632
11633
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11631

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_emulated_versionString

The current emulated version before the upgrade. Corresponds to the JSON property currentEmulatedVersion

Returns:

  • (String)


11557
11558
11559
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11557

def current_emulated_version
  @current_emulated_version
end

#current_versionString

The current version before the upgrade. Corresponds to the JSON property currentVersion

Returns:

  • (String)


11562
11563
11564
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11562

def current_version
  @current_version
end

#descriptionString

A brief description of the event. Corresponds to the JSON property description

Returns:

  • (String)


11567
11568
11569
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11567

def description
  @description
end

#disruption_eventGoogle::Apis::ContainerV1beta1::DisruptionEvent

DisruptionEvent is a notification sent to customers about the disruption event of a resource. Corresponds to the JSON property disruptionEvent



11573
11574
11575
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11573

def disruption_event
  @disruption_event
end

#end_timeString

The time when the operation ended. Corresponds to the JSON property endTime

Returns:

  • (String)


11578
11579
11580
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11578

def end_time
  @end_time
end

#event_typeString

The type of the event. Corresponds to the JSON property eventType

Returns:

  • (String)


11583
11584
11585
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11583

def event_type
  @event_type
end

#extended_support_end_timeString

The end of extended support timestamp. Corresponds to the JSON property extendedSupportEndTime

Returns:

  • (String)


11588
11589
11590
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11588

def extended_support_end_time
  @extended_support_end_time
end

#operationString

The operation associated with this upgrade. Corresponds to the JSON property operation

Returns:

  • (String)


11593
11594
11595
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11593

def operation
  @operation
end

#resourceString

Optional relative path to the resource. For example in node pool upgrades, the relative path of the node pool. Corresponds to the JSON property resource

Returns:

  • (String)


11599
11600
11601
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11599

def resource
  @resource
end

#resource_typeString

The resource type associated with the upgrade. Corresponds to the JSON property resourceType

Returns:

  • (String)


11604
11605
11606
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11604

def resource_type
  @resource_type
end

#standard_support_end_timeString

The end of standard support timestamp. Corresponds to the JSON property standardSupportEndTime

Returns:

  • (String)


11609
11610
11611
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11609

def standard_support_end_time
  @standard_support_end_time
end

#start_timeString

The time when the operation was started. Corresponds to the JSON property startTime

Returns:

  • (String)


11614
11615
11616
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11614

def start_time
  @start_time
end

#stateString

Output only. The state of the upgrade. Corresponds to the JSON property state

Returns:

  • (String)


11619
11620
11621
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11619

def state
  @state
end

#target_emulated_versionString

The target emulated version for the upgrade. Corresponds to the JSON property targetEmulatedVersion

Returns:

  • (String)


11624
11625
11626
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11624

def target_emulated_version
  @target_emulated_version
end

#target_versionString

The target version for the upgrade. Corresponds to the JSON property targetVersion

Returns:

  • (String)


11629
11630
11631
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11629

def target_version
  @target_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11636
11637
11638
11639
11640
11641
11642
11643
11644
11645
11646
11647
11648
11649
11650
11651
11652
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11636

def update!(**args)
  @current_emulated_version = args[:current_emulated_version] if args.key?(:current_emulated_version)
  @current_version = args[:current_version] if args.key?(:current_version)
  @description = args[:description] if args.key?(:description)
  @disruption_event = args[:disruption_event] if args.key?(:disruption_event)
  @end_time = args[:end_time] if args.key?(:end_time)
  @event_type = args[:event_type] if args.key?(:event_type)
  @extended_support_end_time = args[:extended_support_end_time] if args.key?(:extended_support_end_time)
  @operation = args[:operation] if args.key?(:operation)
  @resource = args[:resource] if args.key?(:resource)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @standard_support_end_time = args[:standard_support_end_time] if args.key?(:standard_support_end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @target_emulated_version = args[:target_emulated_version] if args.key?(:target_emulated_version)
  @target_version = args[:target_version] if args.key?(:target_version)
end