Class: Google::Apis::ContainerV1beta1::UpgradeInfoEvent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

UpgradeInfoEvent is a notification sent to customers about the upgrade information of a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeInfoEvent

Returns a new instance of UpgradeInfoEvent.



10883
10884
10885
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10883

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_emulated_versionString

The current emulated version before the upgrade. Corresponds to the JSON property currentEmulatedVersion

Returns:

  • (String)


10809
10810
10811
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10809

def current_emulated_version
  @current_emulated_version
end

#current_versionString

The current version before the upgrade. Corresponds to the JSON property currentVersion

Returns:

  • (String)


10814
10815
10816
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10814

def current_version
  @current_version
end

#descriptionString

A brief description of the event. Corresponds to the JSON property description

Returns:

  • (String)


10819
10820
10821
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10819

def description
  @description
end

#disruption_eventGoogle::Apis::ContainerV1beta1::DisruptionEvent

DisruptionEvent is a notification sent to customers about the disruption event of a resource. Corresponds to the JSON property disruptionEvent



10825
10826
10827
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10825

def disruption_event
  @disruption_event
end

#end_timeString

The time when the operation ended. Corresponds to the JSON property endTime

Returns:

  • (String)


10830
10831
10832
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10830

def end_time
  @end_time
end

#event_typeString

The type of the event. Corresponds to the JSON property eventType

Returns:

  • (String)


10835
10836
10837
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10835

def event_type
  @event_type
end

#extended_support_end_timeString

The end of extended support timestamp. Corresponds to the JSON property extendedSupportEndTime

Returns:

  • (String)


10840
10841
10842
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10840

def extended_support_end_time
  @extended_support_end_time
end

#operationString

The operation associated with this upgrade. Corresponds to the JSON property operation

Returns:

  • (String)


10845
10846
10847
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10845

def operation
  @operation
end

#resourceString

Optional relative path to the resource. For example in node pool upgrades, the relative path of the node pool. Corresponds to the JSON property resource

Returns:

  • (String)


10851
10852
10853
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10851

def resource
  @resource
end

#resource_typeString

The resource type associated with the upgrade. Corresponds to the JSON property resourceType

Returns:

  • (String)


10856
10857
10858
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10856

def resource_type
  @resource_type
end

#standard_support_end_timeString

The end of standard support timestamp. Corresponds to the JSON property standardSupportEndTime

Returns:

  • (String)


10861
10862
10863
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10861

def standard_support_end_time
  @standard_support_end_time
end

#start_timeString

The time when the operation was started. Corresponds to the JSON property startTime

Returns:

  • (String)


10866
10867
10868
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10866

def start_time
  @start_time
end

#stateString

Output only. The state of the upgrade. Corresponds to the JSON property state

Returns:

  • (String)


10871
10872
10873
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10871

def state
  @state
end

#target_emulated_versionString

The target emulated version for the upgrade. Corresponds to the JSON property targetEmulatedVersion

Returns:

  • (String)


10876
10877
10878
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10876

def target_emulated_version
  @target_emulated_version
end

#target_versionString

The target version for the upgrade. Corresponds to the JSON property targetVersion

Returns:

  • (String)


10881
10882
10883
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10881

def target_version
  @target_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10888
10889
10890
10891
10892
10893
10894
10895
10896
10897
10898
10899
10900
10901
10902
10903
10904
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10888

def update!(**args)
  @current_emulated_version = args[:current_emulated_version] if args.key?(:current_emulated_version)
  @current_version = args[:current_version] if args.key?(:current_version)
  @description = args[:description] if args.key?(:description)
  @disruption_event = args[:disruption_event] if args.key?(:disruption_event)
  @end_time = args[:end_time] if args.key?(:end_time)
  @event_type = args[:event_type] if args.key?(:event_type)
  @extended_support_end_time = args[:extended_support_end_time] if args.key?(:extended_support_end_time)
  @operation = args[:operation] if args.key?(:operation)
  @resource = args[:resource] if args.key?(:resource)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @standard_support_end_time = args[:standard_support_end_time] if args.key?(:standard_support_end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @target_emulated_version = args[:target_emulated_version] if args.key?(:target_emulated_version)
  @target_version = args[:target_version] if args.key?(:target_version)
end