Class: Google::Apis::ContainerV1beta1::UpgradeInfoEvent
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::UpgradeInfoEvent
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
UpgradeInfoEvent is a notification sent to customers about the upgrade information of a resource.
Instance Attribute Summary collapse
-
#current_emulated_version ⇒ String
The current emulated version before the upgrade.
-
#current_version ⇒ String
The current version before the upgrade.
-
#description ⇒ String
A brief description of the event.
-
#disruption_event ⇒ Google::Apis::ContainerV1beta1::DisruptionEvent
DisruptionEvent is a notification sent to customers about the disruption event of a resource.
-
#end_time ⇒ String
The time when the operation ended.
-
#event_type ⇒ String
The type of the event.
-
#extended_support_end_time ⇒ String
The end of extended support timestamp.
-
#operation ⇒ String
The operation associated with this upgrade.
-
#resource ⇒ String
Optional relative path to the resource.
-
#resource_type ⇒ String
The resource type associated with the upgrade.
-
#standard_support_end_time ⇒ String
The end of standard support timestamp.
-
#start_time ⇒ String
The time when the operation was started.
-
#state ⇒ String
Output only.
-
#target_emulated_version ⇒ String
The target emulated version for the upgrade.
-
#target_version ⇒ String
The target version for the upgrade.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpgradeInfoEvent
constructor
A new instance of UpgradeInfoEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpgradeInfoEvent
Returns a new instance of UpgradeInfoEvent.
10883 10884 10885 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10883 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_emulated_version ⇒ String
The current emulated version before the upgrade.
Corresponds to the JSON property currentEmulatedVersion
10809 10810 10811 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10809 def current_emulated_version @current_emulated_version end |
#current_version ⇒ String
The current version before the upgrade.
Corresponds to the JSON property currentVersion
10814 10815 10816 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10814 def current_version @current_version end |
#description ⇒ String
A brief description of the event.
Corresponds to the JSON property description
10819 10820 10821 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10819 def description @description end |
#disruption_event ⇒ Google::Apis::ContainerV1beta1::DisruptionEvent
DisruptionEvent is a notification sent to customers about the disruption event
of a resource.
Corresponds to the JSON property disruptionEvent
10825 10826 10827 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10825 def disruption_event @disruption_event end |
#end_time ⇒ String
The time when the operation ended.
Corresponds to the JSON property endTime
10830 10831 10832 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10830 def end_time @end_time end |
#event_type ⇒ String
The type of the event.
Corresponds to the JSON property eventType
10835 10836 10837 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10835 def event_type @event_type end |
#extended_support_end_time ⇒ String
The end of extended support timestamp.
Corresponds to the JSON property extendedSupportEndTime
10840 10841 10842 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10840 def extended_support_end_time @extended_support_end_time end |
#operation ⇒ String
The operation associated with this upgrade.
Corresponds to the JSON property operation
10845 10846 10847 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10845 def operation @operation end |
#resource ⇒ String
Optional relative path to the resource. For example in node pool upgrades, the
relative path of the node pool.
Corresponds to the JSON property resource
10851 10852 10853 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10851 def resource @resource end |
#resource_type ⇒ String
The resource type associated with the upgrade.
Corresponds to the JSON property resourceType
10856 10857 10858 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10856 def resource_type @resource_type end |
#standard_support_end_time ⇒ String
The end of standard support timestamp.
Corresponds to the JSON property standardSupportEndTime
10861 10862 10863 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10861 def standard_support_end_time @standard_support_end_time end |
#start_time ⇒ String
The time when the operation was started.
Corresponds to the JSON property startTime
10866 10867 10868 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10866 def start_time @start_time end |
#state ⇒ String
Output only. The state of the upgrade.
Corresponds to the JSON property state
10871 10872 10873 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10871 def state @state end |
#target_emulated_version ⇒ String
The target emulated version for the upgrade.
Corresponds to the JSON property targetEmulatedVersion
10876 10877 10878 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10876 def target_emulated_version @target_emulated_version end |
#target_version ⇒ String
The target version for the upgrade.
Corresponds to the JSON property targetVersion
10881 10882 10883 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10881 def target_version @target_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10888 10889 10890 10891 10892 10893 10894 10895 10896 10897 10898 10899 10900 10901 10902 10903 10904 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10888 def update!(**args) @current_emulated_version = args[:current_emulated_version] if args.key?(:current_emulated_version) @current_version = args[:current_version] if args.key?(:current_version) @description = args[:description] if args.key?(:description) @disruption_event = args[:disruption_event] if args.key?(:disruption_event) @end_time = args[:end_time] if args.key?(:end_time) @event_type = args[:event_type] if args.key?(:event_type) @extended_support_end_time = args[:extended_support_end_time] if args.key?(:extended_support_end_time) @operation = args[:operation] if args.key?(:operation) @resource = args[:resource] if args.key?(:resource) @resource_type = args[:resource_type] if args.key?(:resource_type) @standard_support_end_time = args[:standard_support_end_time] if args.key?(:standard_support_end_time) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @target_emulated_version = args[:target_emulated_version] if args.key?(:target_emulated_version) @target_version = args[:target_version] if args.key?(:target_version) end |