Class: Google::Apis::ContainerV1beta1::UpgradeInfoEvent
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::UpgradeInfoEvent
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
UpgradeInfoEvent is a notification sent to customers about the upgrade information of a resource.
Instance Attribute Summary collapse
-
#current_emulated_version ⇒ String
The current emulated version before the upgrade.
-
#current_version ⇒ String
The current version before the upgrade.
-
#description ⇒ String
A brief description of the event.
-
#disruption_event ⇒ Google::Apis::ContainerV1beta1::DisruptionEvent
DisruptionEvent is a notification sent to customers about the disruption event of a resource.
-
#end_time ⇒ String
The time when the operation ended.
-
#event_type ⇒ String
The type of the event.
-
#extended_support_end_time ⇒ String
The end of extended support timestamp.
-
#operation ⇒ String
The operation associated with this upgrade.
-
#resource ⇒ String
Optional relative path to the resource.
-
#resource_type ⇒ String
The resource type associated with the upgrade.
-
#standard_support_end_time ⇒ String
The end of standard support timestamp.
-
#start_time ⇒ String
The time when the operation was started.
-
#state ⇒ String
Output only.
-
#target_emulated_version ⇒ String
The target emulated version for the upgrade.
-
#target_version ⇒ String
The target version for the upgrade.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpgradeInfoEvent
constructor
A new instance of UpgradeInfoEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpgradeInfoEvent
Returns a new instance of UpgradeInfoEvent.
10691 10692 10693 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10691 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_emulated_version ⇒ String
The current emulated version before the upgrade.
Corresponds to the JSON property currentEmulatedVersion
10617 10618 10619 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10617 def current_emulated_version @current_emulated_version end |
#current_version ⇒ String
The current version before the upgrade.
Corresponds to the JSON property currentVersion
10622 10623 10624 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10622 def current_version @current_version end |
#description ⇒ String
A brief description of the event.
Corresponds to the JSON property description
10627 10628 10629 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10627 def description @description end |
#disruption_event ⇒ Google::Apis::ContainerV1beta1::DisruptionEvent
DisruptionEvent is a notification sent to customers about the disruption event
of a resource.
Corresponds to the JSON property disruptionEvent
10633 10634 10635 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10633 def disruption_event @disruption_event end |
#end_time ⇒ String
The time when the operation ended.
Corresponds to the JSON property endTime
10638 10639 10640 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10638 def end_time @end_time end |
#event_type ⇒ String
The type of the event.
Corresponds to the JSON property eventType
10643 10644 10645 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10643 def event_type @event_type end |
#extended_support_end_time ⇒ String
The end of extended support timestamp.
Corresponds to the JSON property extendedSupportEndTime
10648 10649 10650 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10648 def extended_support_end_time @extended_support_end_time end |
#operation ⇒ String
The operation associated with this upgrade.
Corresponds to the JSON property operation
10653 10654 10655 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10653 def operation @operation end |
#resource ⇒ String
Optional relative path to the resource. For example in node pool upgrades, the
relative path of the node pool.
Corresponds to the JSON property resource
10659 10660 10661 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10659 def resource @resource end |
#resource_type ⇒ String
The resource type associated with the upgrade.
Corresponds to the JSON property resourceType
10664 10665 10666 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10664 def resource_type @resource_type end |
#standard_support_end_time ⇒ String
The end of standard support timestamp.
Corresponds to the JSON property standardSupportEndTime
10669 10670 10671 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10669 def standard_support_end_time @standard_support_end_time end |
#start_time ⇒ String
The time when the operation was started.
Corresponds to the JSON property startTime
10674 10675 10676 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10674 def start_time @start_time end |
#state ⇒ String
Output only. The state of the upgrade.
Corresponds to the JSON property state
10679 10680 10681 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10679 def state @state end |
#target_emulated_version ⇒ String
The target emulated version for the upgrade.
Corresponds to the JSON property targetEmulatedVersion
10684 10685 10686 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10684 def target_emulated_version @target_emulated_version end |
#target_version ⇒ String
The target version for the upgrade.
Corresponds to the JSON property targetVersion
10689 10690 10691 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10689 def target_version @target_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10696 10697 10698 10699 10700 10701 10702 10703 10704 10705 10706 10707 10708 10709 10710 10711 10712 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 10696 def update!(**args) @current_emulated_version = args[:current_emulated_version] if args.key?(:current_emulated_version) @current_version = args[:current_version] if args.key?(:current_version) @description = args[:description] if args.key?(:description) @disruption_event = args[:disruption_event] if args.key?(:disruption_event) @end_time = args[:end_time] if args.key?(:end_time) @event_type = args[:event_type] if args.key?(:event_type) @extended_support_end_time = args[:extended_support_end_time] if args.key?(:extended_support_end_time) @operation = args[:operation] if args.key?(:operation) @resource = args[:resource] if args.key?(:resource) @resource_type = args[:resource_type] if args.key?(:resource_type) @standard_support_end_time = args[:standard_support_end_time] if args.key?(:standard_support_end_time) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @target_emulated_version = args[:target_emulated_version] if args.key?(:target_emulated_version) @target_version = args[:target_version] if args.key?(:target_version) end |