Class: Google::Apis::ContainerV1beta1::UsableSubnetworkSecondaryRange

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Secondary IP range of a usable subnetwork.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsableSubnetworkSecondaryRange

Returns a new instance of UsableSubnetworkSecondaryRange.



11792
11793
11794
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11792

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_cidr_rangeString

The range of IP addresses belonging to this subnetwork secondary range. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


11779
11780
11781
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11779

def ip_cidr_range
  @ip_cidr_range
end

#range_nameString

The name associated with this subnetwork secondary range, used when adding an alias IP range to a VM instance. Corresponds to the JSON property rangeName

Returns:

  • (String)


11785
11786
11787
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11785

def range_name
  @range_name
end

#statusString

This field is to determine the status of the secondary range programmably. Corresponds to the JSON property status

Returns:

  • (String)


11790
11791
11792
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11790

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11797
11798
11799
11800
11801
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11797

def update!(**args)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @range_name = args[:range_name] if args.key?(:range_name)
  @status = args[:status] if args.key?(:status)
end