Class: Google::Apis::ContainerV1beta1::UserManagedKeysConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

UserManagedKeysConfig holds the resource address to Keys which are used for signing certs and token that are used for communication within cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserManagedKeysConfig

Returns a new instance of UserManagedKeysConfig.



11865
11866
11867
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11865

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregation_caString

The Certificate Authority Service caPool to use for the aggregation CA in this cluster. Corresponds to the JSON property aggregationCa

Returns:

  • (String)


11813
11814
11815
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11813

def aggregation_ca
  @aggregation_ca
end

#cluster_caString

The Certificate Authority Service caPool to use for the cluster CA in this cluster. Corresponds to the JSON property clusterCa

Returns:

  • (String)


11819
11820
11821
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11819

def cluster_ca
  @cluster_ca
end

#control_plane_disk_encryption_keyString

The Cloud KMS cryptoKey to use for Confidential Hyperdisk on the control plane nodes. Corresponds to the JSON property controlPlaneDiskEncryptionKey

Returns:

  • (String)


11825
11826
11827
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11825

def control_plane_disk_encryption_key
  @control_plane_disk_encryption_key
end

#control_plane_disk_encryption_key_versionsArray<String>

Output only. All of the versions of the Cloud KMS cryptoKey that are used by Confidential Hyperdisks on the control plane nodes. Corresponds to the JSON property controlPlaneDiskEncryptionKeyVersions

Returns:

  • (Array<String>)


11831
11832
11833
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11831

def control_plane_disk_encryption_key_versions
  @control_plane_disk_encryption_key_versions
end

#etcd_api_caString

Resource path of the Certificate Authority Service caPool to use for the etcd API CA in this cluster. Corresponds to the JSON property etcdApiCa

Returns:

  • (String)


11837
11838
11839
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11837

def etcd_api_ca
  @etcd_api_ca
end

#etcd_peer_caString

Resource path of the Certificate Authority Service caPool to use for the etcd peer CA in this cluster. Corresponds to the JSON property etcdPeerCa

Returns:

  • (String)


11843
11844
11845
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11843

def etcd_peer_ca
  @etcd_peer_ca
end

#gkeops_etcd_backup_encryption_keyString

Resource path of the Cloud KMS cryptoKey to use for encryption of internal etcd backups. Corresponds to the JSON property gkeopsEtcdBackupEncryptionKey

Returns:

  • (String)


11849
11850
11851
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11849

def gkeops_etcd_backup_encryption_key
  @gkeops_etcd_backup_encryption_key
end

#service_account_signing_keysArray<String>

The Cloud KMS cryptoKeyVersions to use for signing service account JWTs issued by this cluster. Format: projects/project/locations/location/keyRings/ keyring/cryptoKeys/cryptoKey/cryptoKeyVersions/cryptoKeyVersion` Corresponds to the JSON propertyserviceAccountSigningKeys`

Returns:

  • (Array<String>)


11856
11857
11858
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11856

def 
  @service_account_signing_keys
end

#service_account_verification_keysArray<String>

The Cloud KMS cryptoKeyVersions to use for verifying service account JWTs issued by this cluster. Format: projects/project/locations/location/ keyRings/keyring/cryptoKeys/cryptoKey/cryptoKeyVersions/cryptoKeyVersion` Corresponds to the JSON propertyserviceAccountVerificationKeys`

Returns:

  • (Array<String>)


11863
11864
11865
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11863

def 
  @service_account_verification_keys
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11870
11871
11872
11873
11874
11875
11876
11877
11878
11879
11880
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11870

def update!(**args)
  @aggregation_ca = args[:aggregation_ca] if args.key?(:aggregation_ca)
  @cluster_ca = args[:cluster_ca] if args.key?(:cluster_ca)
  @control_plane_disk_encryption_key = args[:control_plane_disk_encryption_key] if args.key?(:control_plane_disk_encryption_key)
  @control_plane_disk_encryption_key_versions = args[:control_plane_disk_encryption_key_versions] if args.key?(:control_plane_disk_encryption_key_versions)
  @etcd_api_ca = args[:etcd_api_ca] if args.key?(:etcd_api_ca)
  @etcd_peer_ca = args[:etcd_peer_ca] if args.key?(:etcd_peer_ca)
  @gkeops_etcd_backup_encryption_key = args[:gkeops_etcd_backup_encryption_key] if args.key?(:gkeops_etcd_backup_encryption_key)
  @service_account_signing_keys = args[:service_account_signing_keys] if args.key?(:service_account_signing_keys)
  @service_account_verification_keys = args[:service_account_verification_keys] if args.key?(:service_account_verification_keys)
end