Class: Google::Apis::ContainerV1beta1::UserManagedKeysConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1beta1::UserManagedKeysConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb
Overview
UserManagedKeysConfig holds the resource address to Keys which are used for signing certs and token that are used for communication within cluster.
Instance Attribute Summary collapse
-
#aggregation_ca ⇒ String
The Certificate Authority Service caPool to use for the aggregation CA in this cluster.
-
#cluster_ca ⇒ String
The Certificate Authority Service caPool to use for the cluster CA in this cluster.
-
#control_plane_disk_encryption_key ⇒ String
The Cloud KMS cryptoKey to use for Confidential Hyperdisk on the control plane nodes.
-
#control_plane_disk_encryption_key_versions ⇒ Array<String>
Output only.
-
#etcd_api_ca ⇒ String
Resource path of the Certificate Authority Service caPool to use for the etcd API CA in this cluster.
-
#etcd_peer_ca ⇒ String
Resource path of the Certificate Authority Service caPool to use for the etcd peer CA in this cluster.
-
#gkeops_etcd_backup_encryption_key ⇒ String
Resource path of the Cloud KMS cryptoKey to use for encryption of internal etcd backups.
-
#service_account_signing_keys ⇒ Array<String>
The Cloud KMS cryptoKeyVersions to use for signing service account JWTs issued by this cluster.
-
#service_account_verification_keys ⇒ Array<String>
The Cloud KMS cryptoKeyVersions to use for verifying service account JWTs issued by this cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserManagedKeysConfig
constructor
A new instance of UserManagedKeysConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserManagedKeysConfig
Returns a new instance of UserManagedKeysConfig.
11840 11841 11842 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11840 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregation_ca ⇒ String
The Certificate Authority Service caPool to use for the aggregation CA in this
cluster.
Corresponds to the JSON property aggregationCa
11788 11789 11790 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11788 def aggregation_ca @aggregation_ca end |
#cluster_ca ⇒ String
The Certificate Authority Service caPool to use for the cluster CA in this
cluster.
Corresponds to the JSON property clusterCa
11794 11795 11796 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11794 def cluster_ca @cluster_ca end |
#control_plane_disk_encryption_key ⇒ String
The Cloud KMS cryptoKey to use for Confidential Hyperdisk on the control plane
nodes.
Corresponds to the JSON property controlPlaneDiskEncryptionKey
11800 11801 11802 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11800 def control_plane_disk_encryption_key @control_plane_disk_encryption_key end |
#control_plane_disk_encryption_key_versions ⇒ Array<String>
Output only. All of the versions of the Cloud KMS cryptoKey that are used by
Confidential Hyperdisks on the control plane nodes.
Corresponds to the JSON property controlPlaneDiskEncryptionKeyVersions
11806 11807 11808 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11806 def control_plane_disk_encryption_key_versions @control_plane_disk_encryption_key_versions end |
#etcd_api_ca ⇒ String
Resource path of the Certificate Authority Service caPool to use for the etcd
API CA in this cluster.
Corresponds to the JSON property etcdApiCa
11812 11813 11814 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11812 def etcd_api_ca @etcd_api_ca end |
#etcd_peer_ca ⇒ String
Resource path of the Certificate Authority Service caPool to use for the etcd
peer CA in this cluster.
Corresponds to the JSON property etcdPeerCa
11818 11819 11820 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11818 def etcd_peer_ca @etcd_peer_ca end |
#gkeops_etcd_backup_encryption_key ⇒ String
Resource path of the Cloud KMS cryptoKey to use for encryption of internal
etcd backups.
Corresponds to the JSON property gkeopsEtcdBackupEncryptionKey
11824 11825 11826 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11824 def gkeops_etcd_backup_encryption_key @gkeops_etcd_backup_encryption_key end |
#service_account_signing_keys ⇒ Array<String>
The Cloud KMS cryptoKeyVersions to use for signing service account JWTs issued
by this cluster. Format: projects/project/locations/location/keyRings/
keyring/cryptoKeys/cryptoKey/cryptoKeyVersions/cryptoKeyVersion`
Corresponds to the JSON propertyserviceAccountSigningKeys`
11831 11832 11833 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11831 def service_account_signing_keys @service_account_signing_keys end |
#service_account_verification_keys ⇒ Array<String>
The Cloud KMS cryptoKeyVersions to use for verifying service account JWTs
issued by this cluster. Format: projects/project/locations/location/
keyRings/keyring/cryptoKeys/cryptoKey/cryptoKeyVersions/cryptoKeyVersion`
Corresponds to the JSON propertyserviceAccountVerificationKeys`
11838 11839 11840 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11838 def service_account_verification_keys @service_account_verification_keys end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11845 11846 11847 11848 11849 11850 11851 11852 11853 11854 11855 |
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11845 def update!(**args) @aggregation_ca = args[:aggregation_ca] if args.key?(:aggregation_ca) @cluster_ca = args[:cluster_ca] if args.key?(:cluster_ca) @control_plane_disk_encryption_key = args[:control_plane_disk_encryption_key] if args.key?(:control_plane_disk_encryption_key) @control_plane_disk_encryption_key_versions = args[:control_plane_disk_encryption_key_versions] if args.key?(:control_plane_disk_encryption_key_versions) @etcd_api_ca = args[:etcd_api_ca] if args.key?(:etcd_api_ca) @etcd_peer_ca = args[:etcd_peer_ca] if args.key?(:etcd_peer_ca) @gkeops_etcd_backup_encryption_key = args[:gkeops_etcd_backup_encryption_key] if args.key?(:gkeops_etcd_backup_encryption_key) @service_account_signing_keys = args[:service_account_signing_keys] if args.key?(:service_account_signing_keys) @service_account_verification_keys = args[:service_account_verification_keys] if args.key?(:service_account_verification_keys) end |