Class: Google::Apis::ContainerV1beta1::WorkloadAltsConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Configuration for direct-path (via ALTS) with workload identity. This feature is not officially supported for external customers in Kubernetes Engine when using Workload Identity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadAltsConfig

Returns a new instance of WorkloadAltsConfig.



11268
11269
11270
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11268

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_altsBoolean Also known as: enable_alts?

enable_alts controls whether the alts handshaker should be enabled or not for direct-path. Requires Workload Identity (workload_pool must be non-empty). Corresponds to the JSON property enableAlts

Returns:

  • (Boolean)


11265
11266
11267
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11265

def enable_alts
  @enable_alts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11273
11274
11275
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11273

def update!(**args)
  @enable_alts = args[:enable_alts] if args.key?(:enable_alts)
end