Class: Google::Apis::ContainerV1beta1::WorkloadAltsConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Configuration for direct-path (via ALTS) with workload identity. This feature is not officially supported for external customers in Kubernetes Engine when using Workload Identity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadAltsConfig

Returns a new instance of WorkloadAltsConfig.



11076
11077
11078
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11076

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_altsBoolean Also known as: enable_alts?

enable_alts controls whether the alts handshaker should be enabled or not for direct-path. Requires Workload Identity (workload_pool must be non-empty). Corresponds to the JSON property enableAlts

Returns:

  • (Boolean)


11073
11074
11075
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11073

def enable_alts
  @enable_alts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11081
11082
11083
# File 'lib/google/apis/container_v1beta1/classes.rb', line 11081

def update!(**args)
  @enable_alts = args[:enable_alts] if args.key?(:enable_alts)
end