Class: Google::Apis::ContainerV1beta1::WorkloadCertificates

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1beta1/classes.rb,
lib/google/apis/container_v1beta1/representations.rb,
lib/google/apis/container_v1beta1/representations.rb

Overview

Configuration for issuance of mTLS keys and certificates to Kubernetes pods.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadCertificates

Returns a new instance of WorkloadCertificates.



12040
12041
12042
# File 'lib/google/apis/container_v1beta1/classes.rb', line 12040

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_certificatesBoolean Also known as: enable_certificates?

enable_certificates controls issuance of workload mTLS certificates. If set, the GKE Workload Identity Certificates controller and node agent will be deployed in the cluster, which can then be configured by creating a WorkloadCertificateConfig Custom Resource. Requires Workload Identity ( workload_pool must be non-empty). Corresponds to the JSON property enableCertificates

Returns:

  • (Boolean)


12037
12038
12039
# File 'lib/google/apis/container_v1beta1/classes.rb', line 12037

def enable_certificates
  @enable_certificates
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12045
12046
12047
# File 'lib/google/apis/container_v1beta1/classes.rb', line 12045

def update!(**args)
  @enable_certificates = args[:enable_certificates] if args.key?(:enable_certificates)
end